@@ -10,8 +10,8 @@ export OMP_PROC_BIND=false
 # increase the OpenMP stack size
 export OMP_STACKSIZE=512M
 
-# set the soft limit of the stack size equal to the hard limit
-ulimit -Ss unlimited
+# increase the regular stack size
+ulimit -Ss 524288
 
 # Elk executable file
 ~/elk/src/elk
