@@ -12,11 +12,10 @@ integer ist,jst
 complex(8), intent(in) :: sem(nstsv,nstsv,0:nwfm)
 real(8), intent(in) :: wr(nwplot)
 complex(8), intent(out) :: ser(nstsv,nstsv,nwplot)
-! allocatable arrays
-complex(8), allocatable :: zm(:),zwr(:),zr(:)
-allocate(zm(0:nwfm),zwr(nwplot),zr(nwplot))
-zm(:)=sem(ist,jst,:)
-zwr(:)=wr(:)
+! automatic arrays
+complex(8) zm(0:nwfm),zwr(nwplot),zr(nwplot)
+zm(0:nwfm)=sem(ist,jst,0:nwfm)
+zwr(1:nwplot)=wr(1:nwplot)
 select case(actype)
 case(1)
 ! fit a multipole model
@@ -30,7 +29,6 @@ case default
   write(*,*)
   stop
 end select
-ser(ist,jst,:)=zr(:)
-deallocate(zm,zwr,zr)
+ser(ist,jst,1:nwplot)=zr(1:nwplot)
 end subroutine
 
