@@ -19,7 +19,7 @@ if ((abs(fsmtype) == 1).or.(abs(fsmtype) == 3)) then
       npc=npcmt(is)
       bsqmt(1:npc,ias,idm,1)=bsqmt(1:npc,ias,idm,1)+t1
     end do
-    bsqir(1:ngtot,idm,1)=bsqir(1:ngtot,idm,1)+t1*cfunir(1:ngtot)
+    bsqir(1:ngtot,idm,1)=bsqir(1:ngtot,idm,1)+t1
   end do
 end if
 ! add the muffin-tin fields
