@@ -65,9 +65,9 @@ real(8) dv,dvp,ze,beta,t1
 real(8), allocatable :: vn(:),vh(:),ex(:),ec(:),vx(:),vc(:),vrp(:)
 real(8), allocatable :: ri(:),wpr(:,:),fr1(:),fr2(:),gr1(:),gr2(:)
 real(8), allocatable :: grho(:),g2rho(:),g3rho(:)
-if (nst <= 0) then
+if (nst < 1) then
   write(*,*)
-  write(*,'("Error(atom): invalid nst : ",I8)') nst
+  write(*,'("Error(atom): nst < 1 : ",I8)') nst
   write(*,*)
   stop
 end if
