@@ -41,13 +41,6 @@ real(8) rfmt(npcmtmax)
 real(8), allocatable :: rvfmt(:,:,:),rvfir(:,:)
 complex(8), allocatable :: zrhomt(:,:),zrhoir(:)
 complex(8), allocatable :: zvclmt(:,:),zvclir(:)
-if (.not.ncmag) then
-  write(*,*)
-  write(*,'("Error(bdipole): non-collinear magnetism required for inclusion of &
-   &the dipole field")')
-  write(*,*)
-  stop
-end if
 ! prefactor for the spin dipole magnetic field
 cb=gfacte/(4.d0*solsc)
 ! compute the gauge invariant current density if required
