@@ -31,7 +31,6 @@ do ipph=1,3
   end do
 end do
 isph=0; iaph=0; iasph=0; ipph=0
-write(*,*)
 write(*,'("Info(bectask): nothing more to do")')
 10 continue
 ! broadcast to all other MPI processes
@@ -39,7 +38,7 @@ call mpi_bcast(isph,1,mpi_integer,0,mpicom,ierror)
 call mpi_bcast(iaph,1,mpi_integer,0,mpicom,ierror)
 call mpi_bcast(iasph,1,mpi_integer,0,mpicom,ierror)
 call mpi_bcast(ipph,1,mpi_integer,0,mpicom,ierror)
-if (isph.eq.0) then
+if (isph == 0) then
   fext='.OUT'
 else
   call becfext(isph,iaph,ipph,fext)
