@@ -10,13 +10,12 @@ implicit none
 integer, intent(in) :: nd,n(nd),sgn
 complex(4), intent(inout) :: c(*)
 ! local variables
-! local variables
 integer status,p
 real(4) t1
 type(DFTI_DESCRIPTOR), pointer :: handle
 ! interface to the Intel MKL advanced Discreet Fourier Transform (DFT) routines
 ! (with thanks to Torbjorn Bjorkman)
-p=product(n(:))
+p=product(n(1:nd))
 t1=1.e0/real(p)
 status=DftiCreateDescriptor(handle,DFTI_SINGLE,DFTI_COMPLEX,nd,n)
 status=DftiSetValue(handle,DFTI_FORWARD_SCALE,t1)
@@ -42,7 +41,7 @@ real(4) t1
 type(DFTI_DESCRIPTOR), pointer :: handle
 ! automatic arrays
 integer strides(0:nd)
-p=product(n(:))
+p=product(n(1:nd))
 t1=1.e0/real(p)
 status=DftiCreateDescriptor(handle,DFTI_SINGLE,DFTI_REAL,nd,n)
 status=DftiSetValue(handle,DFTI_CONJUGATE_EVEN_STORAGE,DFTI_COMPLEX_COMPLEX)
@@ -67,3 +66,4 @@ else
 end if
 status=DftiFreeDescriptor(handle)
 end subroutine
+
