@@ -23,16 +23,16 @@ implicit none
 integer is,ias
 real(8) t1
 ! external functions
-real(8), external :: rfmtint,ddot
+real(8), external :: rfmtint
 ! find the muffin-tin charges
 chgmttot=0.d0
 do ias=1,natmtot
   is=idxis(ias)
-  chgmt(ias)=rfmtint(nrmt(is),nrmti(is),wrmt(:,is),rhomt(:,ias))
+  chgmt(ias)=rfmtint(nrmt(is),nrmti(is),wr2mt(:,is),rhomt(:,ias))
   chgmttot=chgmttot+chgmt(ias)
 end do
 ! find the interstitial charge
-t1=ddot(ngtot,rhoir,1,cfunir,1)
+t1=dot_product(rhoir(1:ngtot),cfunir(1:ngtot))
 chgir=t1*omega/dble(ngtot)
 ! total calculated charge
 chgcalc=chgmttot+chgir
