@@ -6,16 +6,15 @@
 subroutine checkstop
 use modmain
 use modmpi
+use moddelf
 implicit none
 ! check for STOP file (only MPI master process)
 if (mp_mpi) then
   inquire(file='STOP',exist=tstop)
   if (tstop) then
-    write(*,*)
     write(*,'("Info(checkstop): STOP file exists")')
 ! delete the STOP file
-    open(50,file='STOP')
-    close(50,status='DELETE')
+    call delfile('STOP')
   end if
 end if
 ! broadcast tstop from master process to all other processes
