@@ -27,7 +27,7 @@ integer, intent(in) :: m1,m2,m3
 ! external functions
 real(8), external :: wigner3j
 if ((j1 < 0).or.(j2 < 0).or.(j3 < 0).or.(abs(m1) > j1).or.(abs(m2) > j2) &
- .or.(abs(m2) > j2).or.(abs(m3) > j3)) then
+ .or.(abs(m3) > j3)) then
   write(*,*)
   write(*,'("Error(clebgor): non-physical arguments :")')
   write(*,'("j1 = ",I8," j2 = ",I8," j3 = ",I8)') j1,j2,j3
