@@ -20,7 +20,6 @@ complex(8), intent(inout) :: dh(*)
 integer io,jo,i
 integer l0,l1,l2,l3
 integer lm1,lm3,lma,lmb
-real(8) t1
 complex(8) z1
 ! automatic arrays
 complex(8) y1(ngp),a1(lmoapw(is),ngpq),b1(lmoapw(is),ngp)
@@ -30,7 +29,6 @@ do l1=0,lmaxapw
   do lm1=l1**2+1,(l1+1)**2
     do io=1,apword(l1,is)
       i=i+1
-      t1=apwfr(nrmt(is),1,io,l1,ias)
       y1(1:ngp)=0.d0
       do l3=0,lmaxapw
         if (mod(l1+l3,2) == 0) then; l0=0; else; l0=1; end if
@@ -41,7 +39,7 @@ do l1=0,lmaxapw
               lma=l2**2+1; lmb=lma+2*l2
               z1=z1+sum(gntyyy(lma:lmb,lm3,lm1)*dhaa(lma:lmb,jo,l3,io,l1,ias))
             end do
-            if (abs(dble(z1))+abs(aimag(z1)) > 1.d-14) then
+            if (abs(dble(z1))+abs(aimag(z1)) > 1.d-12) then
               call zaxpy(ngp,z1,apwalm(:,jo,lm3),1,y1,1)
             end if
           end do
@@ -58,9 +56,7 @@ do l1=0,lmaxapw
                 lma=l2**2+1; lmb=lma+2*l2
                 z1=z1+sum(gntyry(lma:lmb,lm3,lm1)*haa(lma:lmb,jo,l3,io,l1,ias))
               end do
-! kinetic surface contribution
-              if (lm1 == lm3) z1=z1+t1*apwdfr(jo,l1,ias)
-              if (abs(dble(z1))+abs(aimag(z1)) > 1.d-14) then
+              if (abs(dble(z1))+abs(aimag(z1)) > 1.d-12) then
                 call zaxpy(ngp,z1,dapwalm(:,jo,lm3),1,y1,1)
                 call zaxpy(ngp,z1,apwalm(:,jo,lm3),1,y2,1)
               end if
@@ -75,9 +71,9 @@ do l1=0,lmaxapw
     end do
   end do
 end do
-call zmctm(lmoapw(is),ngpq,ngp,a1,b1,ld,dh)
+call zmmab(lmoapw(is),ngpq,ngp,a1,b1,ld,dh)
 if (ias == iasph) then
-  call zmctm(lmoapw(is),ngpq,ngp,a2,b2,ld,dh)
+  call zmmab(lmoapw(is),ngpq,ngp,a2,b2,ld,dh)
 end if
 end subroutine
 
