@@ -12,10 +12,9 @@ integer, intent(in) :: ngp,ngpq
 integer, intent(in) :: igpig(ngkmax),igpqig(ngkmax)
 real(8), intent(in) :: vgpc(3,ngkmax),vgpqc(3,ngkmax)
 integer, intent(in) :: ld
-complex(8), intent(inout) :: dh(ld,*)
+complex(8), intent(out) :: dh(ld,*)
 ! local variables
-integer j1,j2,j3
-integer ig,i,j
+integer j1,j2,j3,ig,i,j
 real(8) v1,v2,v3,t1
 do j=1,ngp
   ig=igpig(j)
@@ -24,8 +23,12 @@ do j=1,ngp
   do i=1,ngpq
     ig=igpqig(i)
     ig=ivgig(ivg(1,ig)-j1,ivg(2,ig)-j2,ivg(3,ig)-j3)
-    t1=vgpqc(1,i)*v1+vgpqc(2,i)*v2+vgpqc(3,i)*v3
-    dh(i,j)=dh(i,j)+dvsig(ig)+t1*dcfunig(ig)
+    if (ig <= ngvc) then
+      t1=vgpqc(1,i)*v1+vgpqc(2,i)*v2+vgpqc(3,i)*v3
+      dh(i,j)=dvsig(ig)+t1*dcfunig(ig)
+    else
+      dh(i,j)=0.d0
+    end if
   end do
 end do
 end subroutine
