@@ -12,11 +12,12 @@ complex(8), intent(out) :: dxx(n,n),dwx(n,n)
 real(8), intent(out) :: xn(n)
 ! local variables
 integer i
+real(8), external :: dznrm2
 ! normal bosonic density matrix XX†
 call zgemm('N','C',n,n,n,(1.d0,0.d0),x,n,x,n,(0.d0,0.d0),dxx,n)
 ! store the X-norm
 do i=1,n
-  xn(i)=dot_product(x(:,i),x(:,i))
+  xn(i)=dznrm2(n,x(:,i),1)**2
 end do
 ! anomalous density matrix -WX†
 call zgemm('N','C',n,n,n,(-1.d0,0.d0),w,n,x,n,(0.d0,0.d0),dwx,n)
