@@ -14,24 +14,19 @@ complex(8), intent(in) :: dapwalmq(ngkmax,apwordmax,lmmaxapw)
 integer, intent(in) :: ld
 complex(8), intent(inout) :: od(ld,*)
 ! local variables
-integer ilo,io,l,lm
-integer i0,j0,i,j
+integer ilo,io,l,lm,i,j,k
 real(8) t1
 if (ias /= iasph) return
 do ilo=1,nlorb(is)
   l=lorbl(ilo,is)
   do lm=l**2+1,(l+1)**2
-    i=idxlo(lm,ilo,ias)
-    i0=ngpq+i
-    j0=ngp+i
+    k=idxlo(lm,ilo,ias)
+    i=ngpq+k
+    j=ngp+k
     do io=1,apword(l,is)
       t1=oalo(io,ilo,ias)
-      do i=1,ngpq
-        od(i,j0)=od(i,j0)+t1*conjg(dapwalmq(i,io,lm))
-      end do
-      do j=1,ngp
-        od(i0,j)=od(i0,j)+t1*dapwalm(j,io,lm)
-      end do
+      od(1:ngpq,j)=od(1:ngpq,j)+t1*conjg(dapwalmq(1:ngpq,io,lm))
+      od(i,1:ngp)=od(i,1:ngp)+t1*dapwalm(1:ngp,io,lm)
     end do
   end do
 end do
