@@ -76,7 +76,7 @@ else
 end if
 allocate(bc(lmmax,nspinor,natmtot,nstsv,nkptnr))
 allocate(sc(nspinor,nstsv,nkptnr))
-! generate unitary matrices which convert the (l,m) basis into the irreducible
+! generate unitary matrices which convert the Yₗₘ basis into the irreducible
 ! representation basis of the symmetry group at each atomic site
 if (lmirep) then
   allocate(elm(lmmax,natmtot))
@@ -117,7 +117,7 @@ allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
 allocate(evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv))
 allocate(dmat(lmmax,nspinor,lmmax,nspinor,nstsv))
 allocate(sdmat(nspinor,nspinor,nstsv),a(lmmax,lmmax))
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do ik=1,nkptnr
 ! equivalent reduced k-point
   jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
@@ -254,6 +254,8 @@ do ispn=1,nsd
   write(50,*)
 end do
 close(50)
+! skip the partial DOS if required
+if (.not.tpdos) goto 10
 !---------------------!
 !     partial DOS     !
 !---------------------!
@@ -267,7 +269,7 @@ do is=1,nspecies
 !$OMP PRIVATE(f,g,lm,ik,jk,ist) &
 !$OMP NUM_THREADS(nthd)
       allocate(f(nstsv,nkptnr),g(nwplot))
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
       do l=0,lmaxdos
         do lm=l**2+1,(l+1)**2
           do ik=1,nkptnr
@@ -358,6 +360,7 @@ do ispn=1,nsd
   write(50,*)
 end do
 close(50)
+10 continue
 ! write the total DOS to test file
 call writetest(10,'total DOS',nv=nwplot*nsd,tol=2.d-2,rva=dt)
 deallocate(bc,sc,w,e,dt,dp)
