@@ -35,13 +35,13 @@ do ist=1,nstsv
   idx(nst)=ist
 end do
 ! generate the wavefunctions
-allocate(wfmt(npcmtmax,natmtot,nspinor,nst),wfir(ngtot,nspinor,nst))
-call genwfsv(.false.,.false.,nst,idx,ngridg,igfft,ngp,igpig,apwalm,evecfv, &
- evecsv,wfmt,ngtot,wfir)
+allocate(wfmt(npcmtmax,natmtot,nspinor,nst),wfir(ngtc,nspinor,nst))
+call genwfsv(.false.,.false.,nst,idx,ngdgc,igfc,ngp,igpig,apwalm,evecfv,evecsv,&
+ wfmt,ngtc,wfir)
 ! generate the wavefunction derivatives
-allocate(dwfmt(npcmtmax,natmtot,nspinor,nst),dwfir(ngtot,nspinor,nst))
+allocate(dwfmt(npcmtmax,natmtot,nspinor,nst),dwfir(ngtc,nspinor,nst))
 call gendwfsv(.false.,.false.,nst,idx,ngp,ngpq,igpqig,apwalmq,dapwalm,evecfv, &
- devecfv,evecsv,devecsv,dwfmt,ngtot,dwfir)
+ devecfv,evecsv,devecsv,dwfmt,ngtc,dwfir)
 ! loop over occupied states
 do ist=1,nst
   jst=idx(ist)
@@ -93,25 +93,25 @@ do ist=1,nst
   if (spinpol) then
 ! spin-polarised
     if (ncmag) then
-      call drmk1(ngtot,wo,wfir(:,1,jst),wfir(:,2,jst),dwfir(:,1,jst), &
+      call drmk1(ngtc,wo,wfir(:,1,jst),wfir(:,2,jst),dwfir(:,1,jst), &
        dwfir(:,2,jst),drhoir,dmagir,dmagir(:,2),dmagir(:,3))
       if (tphq0) then
-        call drmk01(ngtot,dwo,wfir(:,1,jst),wfir(:,2,jst),drhoir,dmagir, &
+        call drmk01(ngtc,dwo,wfir(:,1,jst),wfir(:,2,jst),drhoir,dmagir, &
          dmagir(:,2),dmagir(:,3))
       end if
     else
 ! collinear
-      call drmk2(ngtot,wo,wfir(:,1,jst),wfir(:,2,jst),dwfir(:,1,jst), &
+      call drmk2(ngtc,wo,wfir(:,1,jst),wfir(:,2,jst),dwfir(:,1,jst), &
        dwfir(:,2,jst),drhoir,dmagir)
       if (tphq0) then
-        call drmk02(ngtot,dwo,wfir(:,1,jst),wfir(:,2,jst),drhoir,dmagir)
+        call drmk02(ngtc,dwo,wfir(:,1,jst),wfir(:,2,jst),drhoir,dmagir)
       end if
     end if
   else
 ! spin-unpolarised
-    call drmk3(ngtot,wo,wfir(:,1,jst),dwfir(:,1,jst),drhoir)
+    call drmk3(ngtc,wo,wfir(:,1,jst),dwfir(:,1,jst),drhoir)
     if (tphq0) then
-      call drmk03(ngtot,dwo,wfir(:,1,jst),drhoir)
+      call drmk03(ngtc,dwo,wfir(:,1,jst),drhoir)
     end if
   end if
 !$OMP END CRITICAL(drhomagk_2)
@@ -147,7 +147,7 @@ do i=1,n
   z6=z2*z3
   dmag1(i)=dmag1(i)+wo*(z5+z6)
   z5=z5-z6
-  dmag2(i)=dmag2(i)+wo*cmplx(aimag(z5),-dble(z5),8)
+  dmag2(i)=dmag2(i)+wo*zmi*z5
 end do
 end subroutine
 
@@ -174,8 +174,6 @@ do i=1,n
   dmag2(i)=dmag2(i)+dwo*2.d0*aimag(z1)
   dmag3(i)=dmag3(i)+dwo*(t1-t2)
 end do
-!******* speed up: see rhomagk
-
 end subroutine
 
 pure subroutine drmk2(n,wo,wf1,wf2,dwf1,dwf2,drho,dmag)
@@ -222,7 +220,7 @@ integer, intent(in) :: n
 real(8), intent(in) :: wo
 complex(8), intent(in) :: wf(n),dwf(n)
 complex(8), intent(inout) :: drho(n)
-drho(:)=drho(:)+wo*conjg(wf(:))*dwf(:)
+drho(1:n)=drho(1:n)+wo*conjg(wf(1:n))*dwf(1:n)
 end subroutine
 
 pure subroutine drmk03(n,dwo,wf,drho)
@@ -232,7 +230,7 @@ integer, intent(in) :: n
 real(8), intent(in) :: dwo
 complex(8), intent(in) :: wf(n)
 complex(8), intent(inout) :: drho(n)
-drho(:)=drho(:)+dwo*(dble(wf(:))**2+aimag(wf(:))**2)
+drho(1:n)=drho(1:n)+dwo*(dble(wf(1:n))**2+aimag(wf(1:n))**2)
 end subroutine
 
 end subroutine
