@@ -3,13 +3,13 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine dynev(dynp,w,ev)
+subroutine dynev(dq,wq,ev)
 use modmain
 use modphonon
 implicit none
 ! arguments
-complex(8), intent(in) :: dynp(nbph,nbph)
-real(8), intent(out) :: w(nbph)
+complex(8), intent(in) :: dq(nbph,nbph)
+real(8), intent(out) :: wq(nbph)
 complex(8), intent(out) :: ev(nbph,nbph)
 ! local variables
 integer is,ia,js,ja
@@ -35,7 +35,7 @@ do is=1,nspecies
             j=j+1
             if (i <= j) then
 ! use Hermitian average of dynamical matrix
-              ev(i,j)=0.5d0*t1*(dynp(i,j)+conjg(dynp(j,i)))
+              ev(i,j)=0.5d0*t1*(dq(i,j)+conjg(dq(j,i)))
             end if
           end do
         end do
@@ -44,12 +44,12 @@ do is=1,nspecies
   end do
 end do
 ! find the eigenvalues and eigenvectors of the dynamical matrix
-call eveqnzh(nbph,nbph,ev,w)
+call eveqnzh(nbph,nbph,ev,wq)
 do i=1,nbph
-  if (w(i) >= 0.d0) then
-    w(i)=sqrt(w(i))
+  if (wq(i) >= 0.d0) then
+    wq(i)=sqrt(wq(i))
   else
-    w(i)=-sqrt(abs(w(i)))
+    wq(i)=-sqrt(abs(wq(i)))
   end if
 end do
 end subroutine
