@@ -14,8 +14,7 @@ real(8), intent(out) :: dr(nbph,nbph,nqptnr)
 integer intr(2,3),iq,n
 integer isym,lspl,ir
 integer i1,i2,i3,j1,j2,j3
-real(8) v1(3),v2(3),v3(3)
-real(8) s(3,3),t1
+real(8) v1(3),v2(3),s(3,3),t1
 complex(8) z1
 ! automatic arrays
 complex(8) dqs(nbph,nbph)
@@ -31,17 +30,16 @@ do j1=0,ngridq(1)-1
       v1(3)=dble(j3)/dble(ngridq(3))
       iq=ivqiq(j1,j2,j3)
 ! map v1 to the first Brillouin zone
-      v2(:)=v1(:)
-      call vecfbz(epslat,bvec,v2)
+      call vecfbz(epslat,bvec,v1)
 ! rotate and add the dynamical matrix of the reduced q-point with all symmetries
       n=0
       dqs(:,:)=0.d0
       do isym=1,nsymcrys
         lspl=lsplsymc(isym)
         s(:,:)=dble(symlat(:,:,lspl))
-        call r3mtv(s,vql(:,iq),v3)
-        call vecfbz(epslat,bvec,v3)
-        t1=abs(v2(1)-v3(1))+abs(v2(2)-v3(2))+abs(v2(3)-v3(3))
+        call r3mtv(s,vql(:,iq),v2)
+        call vecfbz(epslat,bvec,v2)
+        t1=abs(v1(1)-v2(1))+abs(v1(2)-v2(2))+abs(v1(3)-v2(3))
         if (t1 < epslat) then
           call dynsymapp(isym,vql(:,iq),dq(:,:,iq),dqs)
           n=n+1
