@@ -47,10 +47,6 @@ else
   call dynfext(iqph,isph,iaph,ipph,fext)
 end if
 ! set the q = 0 flag
-if (iqph == 1) then
-  tphq0=.true.
-else
-  tphq0=.false.
-end if
+tphq0=(iqph == 1)
 end subroutine
 
