@@ -14,22 +14,22 @@ real(8), intent(in) :: wr(nwplot)
 complex(8), intent(in) :: sem(nstsv,nstsv,0:nwfm)
 real(8), intent(out) :: sf(nwplot)
 ! local variables
-integer ist,jst,iw
-integer nthd
+integer ist,jst,iw,nthd
 real(8) w,e,sm,t1
 complex(8) z1
 ! allocatable arrays
 complex(8), allocatable :: ser(:,:,:),gs(:),g(:,:)
 allocate(ser(nstsv,nstsv,nwplot))
-ser(:,:,:)=0.d0
+ser(1:nstsv,1:nstsv,1:nwplot)=0.d0
 call holdthd(nstsv,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(ist) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do jst=1,nstsv
   do ist=1,nstsv
     if (tsediag.and.(ist /= jst)) cycle
-! perform analytic continuation from the imaginary to the real axis
+! perform numerical analytic continuation from the imaginary to the real axis
     call acgwse(ist,jst,sem,wr,ser)
   end do
 end do
@@ -42,27 +42,27 @@ call holdthd(nwplot,nthd)
 !$OMP PRIVATE(e,t1,z1,sm) &
 !$OMP NUM_THREADS(nthd)
 allocate(gs(nstsv),g(nstsv,nstsv))
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do iw=1,nwplot
   w=wr(iw)
-! compute the diagonal matrix G_s
+! compute the diagonal matrix Gₛ
   do ist=1,nstsv
     e=evalsv(ist,ik)-efermi
     t1=sign(swidth,e)
     gs(ist)=1.d0/cmplx(w-e,t1,8)
   end do
-! compute 1 - G_s Σ
+! compute 1 - Gₛ Σ
   do ist=1,nstsv
     z1=-gs(ist)
-    g(ist,:)=z1*ser(ist,:,iw)
+    g(ist,1:nstsv)=z1*ser(ist,1:nstsv,iw)
     g(ist,ist)=g(ist,ist)+1.d0
   end do
 ! invert this matrix
   call zminv(nstsv,g)
-! compute G = (1 - G_s Σ)⁻¹ G_s
+! compute G = (1 - Gₛ Σ)⁻¹ Gₛ
   do jst=1,nstsv
     z1=gs(jst)
-    g(:,jst)=g(:,jst)*z1
+    g(1:nstsv,jst)=g(1:nstsv,jst)*z1
   end do
 ! determine the spectral function
   sm=0.d0
