@@ -79,7 +79,8 @@ do ias=1,natmtot
   call rfshtip(nrcmt(is),nrcmti(is),gwf2mt(:,ias))
 end do
 ! symmetrise the wavefunction gradient squared
-call symrf(nrcmt,nrcmti,npcmt,ngdgc,ngtc,ngvc,igfc,npmtmax,gwf2mt,gwf2ir)
+call symrf(nrcmt,nrcmti,npcmt,ngdgc,ngtc,ngvc,nfgrzc,igfc,igrzfc,npmtmax, &
+ gwf2mt,gwf2ir)
 ! convert back to spherical coordinates
 do ias=1,natmtot
   is=idxis(ias)
@@ -131,7 +132,7 @@ do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
     if (ig <= ngvc) then
-      zfft2(ifg)=vgc(i,ig)*cmplx(-aimag(zfft1(ifg)),dble(zfft1(ifg)),8)
+      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
     else
       zfft2(ifg)=0.d0
     end if
