@@ -12,7 +12,7 @@ real(8) t1
 ! allocatable arrays
 real(4), allocatable :: emds(:,:)
 t1=sum(abs(vkloff(:)))
-if (t1.gt.epslat) then
+if (t1 > epslat) then
   write(*,*)
   write(*,'("Error(emdplot): use vkloff = 0 for the ground-state run")')
   write(*,*)
