@@ -16,8 +16,7 @@ real(8) v1(3),t1
 ! allocatable arrays
 real(8), allocatable :: vpl(:,:)
 ! external functions
-real(8) rfhkintp
-external rfhkintp
+real(8), external :: rfhkintp
 ! total number of plot points
 np=np3d(1)*np3d(2)*np3d(3)
 ! generate the 3D plotting points
@@ -42,6 +41,5 @@ end do
 call freethd(nthd)
 close(50)
 deallocate(vpl)
-return
 end subroutine
 
