@@ -103,9 +103,9 @@ end do
 !     Coulomb potential energy     !
 !----------------------------------!
 engyvcl=rfinp(rhomt,rhoir,vclmt,vclir)
-!-----------------------!
-!     Madelung term     !
-!-----------------------!
+!-------------------------!
+!     Madelung energy     !
+!-------------------------!
 engymad=0.d0
 do ias=1,natmtot
   is=idxis(ias)
@@ -226,11 +226,12 @@ else
   engykn=evalsum-engyvcl-engyvxc-sm
   deallocate(rfmt)
 end if
-! add vector potential constant term (1/2c²)A²Q if required
+! remove vector potential energy term if required
 if (tafield) then
-  sm=sum(afieldc(:)**2)
-  engykn=engykn+(0.5d0/solsc**2)*sm*chgval
+  engykn=engykn+(0.5d0/solsc)*dot_product(afieldc(:),jtot(:))
 end if
+! remove spin-dependent vector potential energy term if required
+if (tafsp.and.tlast) call energyafsp
 !-------------------------------!
 !     entropic contribution     !
 !-------------------------------!
