@@ -25,19 +25,13 @@ engyx=rfinp(rhomt,rhoir,exmt,exir)
 engyc=rfinp(rhomt,rhoir,ecmt,ecir)
 ! vector potential contributions to energy
 ca=-1.d0/solsc
-! coupling term -1/c A(t)·J(t)
-engya=ca*dot_product(afieldt(:,itimes),jtot(:))
-! constant term 1/2c² A(t)²Q
+! coupling term -1/c A(t)⋅J(t)
+engya=ca*dot_product(afieldt(1:3,itimes),jtot(1:3))
+! constant term 1/2c² A²(t)Q where Q is the 'dynamic' charge
 ca=0.5d0/solsc**2
-t1=sum(afieldt(:,itimes)**2)
-t2=sum(chgstot(:))/3.d0
+t1=sum(afieldt(1:3,itimes)**2)
+t2=sum(chgstot(1:3))/3.d0
 engya=engya+ca*t1*(chgtot-t2)
-! electric field contribution 1/2 E(t)²
-t1=sum(efieldt(:)**2)
-engya=engya+0.5d0*t1
-! mass term
-t2=ca*(afindpm(0)/afindpm(2))
-engya=engya+t1*t2
 ! total energy
 engytot=engykn+0.5d0*engyvcl+engymad+engyx+engyc+engya
 end subroutine
