@@ -12,13 +12,11 @@ real(8), intent(in) :: x
 integer i
 real(8) sum
 ! external functions
-real(8) eveos
-external eveos
+real(8), external :: eveos
 sum=0.d0
 do i=1,nevpt
   sum=sum+(eveos(etype,x,vpt(i))-ept(i))**2
 end do
 fmin_nm=sum
-return
 end function
 
