@@ -16,15 +16,14 @@ integer i,j,il,iu
 ! Nelder-Mead parmeters
 real(8), parameter :: alpha=1.d0,gamma=2.d0
 real(8), parameter :: beta=0.5d0,sigma=0.5d0
-real(8) fr,fe,fc,sum,t1
+real(8) fr,fe,fc,sm,t1
 ! automatic arrays
 real(8) f(n+1),xm(n),xr(n),xe(n),xc(n)
 ! external functions
-real(8) fmin_nm
-external fmin_nm
-if (n < 0) then
+real(8), external :: fmin_nm
+if (n < 1) then
   write(*,*)
-  write(*,'("Error(minf_nm): n <= 0 : ",I8)') n
+  write(*,'("Error(minf_nm): n < 1 : ",I8)') n
   write(*,*)
   stop
 end if
@@ -48,14 +47,14 @@ if ((f(iu)-f(il)) < eps) return
 ! compute the mean of the n lowest vertices
 t1=1.d0/dble(n)
 do i=1,n
-  sum=0.d0
+  sm=0.d0
   do j=1,iu-1
-    sum=sum+x(i,j)
+    sm=sm+x(i,j)
   end do
   do j=iu+1,n+1
-    sum=sum+x(i,j)
+    sm=sm+x(i,j)
   end do
-  xm(i)=t1*sum
+  xm(i)=t1*sm
 end do
 xr(:)=xm(:)+alpha*(xm(:)-x(:,iu))
 fr=fmin_nm(xr)
@@ -100,6 +99,5 @@ do j=il+1,n+1
   f(j)=fmin_nm(x(1,j))
 end do
 goto 10
-return
 end subroutine
 
