@@ -25,7 +25,7 @@ do ik=1,nkpt
   call getevaluv(ik,evaluv(:,ik))
 ! negate eigenvalues corresponding to V-norm > 1/2
   do ist=1,nstsv
-    if (vnorm(ist,ik).gt.0.5d0) evaluv(ist,ik)=-evaluv(ist,ik)
+    if (vnorm(ist,ik) > 0.5d0) evaluv(ist,ik)=-evaluv(ist,ik)
   end do
 ! arrange in ascending order
   w(:)=evaluv(:,ik)
@@ -63,12 +63,12 @@ do ik=1,nkpt
   call vecfbz(epslat,bvec,v)
   do ist=1,nstsv
     vn=vnorm(ist,ik)
-    if ((vn.gt.0.d0).and.(vn.lt.1.d0)) then
+    if ((vn > 0.d0).and.(vn < 1.d0)) then
       t1=-(vn*log(vn)+(1.d0-vn)*log(1.d0-vn))
     else
       t1=0.d0
     end if
-    if (t1.lt.1.d-4) cycle
+    if (t1 < 1.d-4) cycle
     write(50,'(5G18.10)') evaluv(ist,ik),t1,v
   end do
 end do
