@@ -13,11 +13,11 @@ integer iq,ik,ig,iw
 integer n,nthd
 ! automatic arrays
 integer(omp_lock_kind) lock(nwrf)
+real(8) vgqc(3,ngrf),gqc(ngrf),gclgq(ngrf)
 ! allocatable arrays
-real(8), allocatable :: vgqc(:,:),gqc(:),gclgq(:),jlgqr(:,:,:)
+real(8), allocatable :: jlgqr(:,:,:)
 complex(8), allocatable :: ylmgq(:,:),sfacgq(:,:),epsi(:,:,:)
 ! allocate local arrays
-allocate(vgqc(3,ngrf),gqc(ngrf),gclgq(ngrf))
 allocate(jlgqr(njcmax,nspecies,ngrf))
 allocate(ylmgq(lmmaxo,ngrf),sfacgq(ngrf,natmtot))
 allocate(epsi(ngrf,ngrf,nwrf))
@@ -36,11 +36,12 @@ do iq=1,nqpt
 ! generate the regularised Coulomb Green's function in G+q-space
   call gengclgq(.true.,iq,ngrf,gqc,gclgq)
 ! use the symmetric form
-  gclgq(:)=sqrt(gclgq(:))
+  gclgq(1:ngrf)=sqrt(gclgq(1:ngrf))
 ! zero the response function (stored in epsi)
-  epsi(:,:,:)=0.d0
+  epsi(1:ngrf,1:ngrf,1:nwrf)=0.d0
   call holdthd(nkptnr/np_mpi,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
   do ik=1,nkptnr
 ! distribute among MPI processes
@@ -57,15 +58,16 @@ do iq=1,nqpt
      ierror)
   end if
 ! negate and add δ(G,G')
-  epsi(:,:,:)=-epsi(:,:,:)
+  epsi(1:ngrf,1:ngrf,1:nwrf)=-epsi(1:ngrf,1:ngrf,1:nwrf)
   do ig=1,ngrf
-    epsi(ig,ig,:)=epsi(ig,ig,:)+1.d0
+    epsi(ig,ig,1:nwrf)=epsi(ig,ig,1:nwrf)+1.d0
   end do
 !-------------------------------------!
 !     invert epsilon over G-space     !
 !-------------------------------------!
   call holdthd(nwrf,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
   do iw=1,nwrf
     call zminv(ngrf,epsi(:,:,iw))
@@ -80,8 +82,7 @@ end do
 do iw=1,nwrf
   call omp_destroy_lock(lock(iw))
 end do
-deallocate(vgqc,gqc,gclgq,jlgqr)
-deallocate(ylmgq,sfacgq,epsi)
+deallocate(jlgqr,ylmgq,sfacgq,epsi)
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
 end subroutine
