@@ -6,7 +6,7 @@
 !BOP
 ! !ROUTINE: eulerrot
 ! !INTERFACE:
-subroutine eulerrot(ang,rot)
+pure subroutine eulerrot(ang,rot)
 ! !INPUT/OUTPUT PARAMETERS:
 !   ang : Euler angles (alpha, beta, gamma) (in,real(3))
 !   rot : rotation matrix (out,real(3,3))
@@ -26,18 +26,18 @@ real(8), intent(in) :: ang(3)
 real(8), intent(out) :: rot(3,3)
 ! local variables
 real(8) sa,sb,sg,ca,cb,cg
-sa=sin(ang(1)); sb=sin(ang(2)); sg=sin(ang(3))
-ca=cos(ang(1)); cb=cos(ang(2)); cg=cos(ang(3))
+sa=sin(ang(1)); ca=cos(ang(1))
+sb=sin(ang(2)); cb=cos(ang(2))
+sg=sin(ang(3)); cg=cos(ang(3))
 rot(1,1)=cg*cb*ca-sg*sa
-rot(1,2)=cg*cb*sa+sg*ca
-rot(1,3)=-cg*sb
 rot(2,1)=-sg*cb*ca-cg*sa
-rot(2,2)=-sg*cb*sa+cg*ca
-rot(2,3)=sg*sb
 rot(3,1)=sb*ca
+rot(1,2)=cg*cb*sa+sg*ca
+rot(2,2)=-sg*cb*sa+cg*ca
 rot(3,2)=sb*sa
+rot(1,3)=-cg*sb
+rot(2,3)=sg*sb
 rot(3,3)=cb
-return
 end subroutine
 !EOC
 
