@@ -6,10 +6,11 @@
 !BOP
 ! !ROUTINE: eveqnfvr
 ! !INTERFACE:
-subroutine eveqnfvr(nmatp,ngp,vpc,h,o,evalfv,evecfv)
+subroutine eveqnfvr(nmatp,ngp,vpc,h_,o_,evalfv,evecfv)
 ! !USES:
 use modmain
 use modomp
+use, intrinsic :: iso_c_binding
 ! !INPUT/OUTPUT PARAMETERS:
 !   nmatp  : order of overlap and Hamiltonian matrices (in,integer)
 !   ngp    : number of G+p-vectors (in,integer)
@@ -35,12 +36,12 @@ implicit none
 ! arguments
 integer, intent(in) :: nmatp,ngp
 real(8), intent(in) :: vpc(3)
-complex(8), intent(in) :: h(*),o(*)
+real(8), target :: h_(*),o_(*)
 real(8), intent(out) :: evalfv(nstfv)
 complex(8), intent(out) :: evecfv(nmatmax,nstfv)
 ! local variables
-integer is,ia,ja,jas
-integer ilo,i,j,k,l,m
+integer is,ia,ja,jas,ilo
+integer n2,i,j,k,l,m
 integer i1,i2,j1,j2
 integer k1,k2,k3,k4
 integer l1,l2,m1,m2
@@ -53,11 +54,19 @@ complex(8) z1
 logical tr(nlotot),tp(nlotot)
 integer idx(nlotot),s(nlotot)
 integer iwork(5*nmatp),ifail(nmatp)
-real(8) w(nmatp),work(8*nmatp)
+real(8) w(nmatp)
 complex(8) zp(nlotot)
-! allocatable arrays
-real(8), allocatable :: rh(:),ro(:),rv(:,:)
+! allocatable arrays and pointers
+real(8), allocatable :: rh(:)
+real(8), pointer, contiguous :: ro(:),rv(:,:)
+complex(8), pointer, contiguous :: h(:),o(:)
 call timesec(ts0)
+! reuse already allocated memory
+n2=nmatp**2
+call c_f_pointer(c_loc(h_),h,shape=[n2])
+call c_f_pointer(c_loc(o_),o,shape=[n2])
+call c_f_pointer(c_loc(h_),ro,shape=[n2])
+call c_f_pointer(c_loc(h_(n2+1)),rv,shape=[nmatp,nstfv])
 tp(1:nlotot)=.false.
 i=0
 do is=1,nspecies
@@ -128,13 +137,13 @@ end do
 !---------------------------------!
 !     real Hamiltonian matrix     !
 !---------------------------------!
-allocate(rh(nmatp**2))
-! <APW|H|APW>
+allocate(rh(n2))
+! ⟨APW|H|APW⟩
 do j=1,ngp
   k=(j-1)*nmatp+1
   rh(k:k+j-1)=dble(h(k:k+j-1))
 end do
-! <APW|H|lo>
+! ⟨APW|H|lo⟩
 do m1=1,nlotot
   j1=(ngp+m1-1)*nmatp
   j2=(ngp+idx(m1)-1)*nmatp
@@ -153,7 +162,7 @@ do m1=1,nlotot
     end if
   end if
 end do
-! <lo|H|lo>
+! ⟨lo|H|lo⟩
 do m1=1,nlotot
   m2=idx(m1)
   do l1=1,m1
@@ -176,13 +185,12 @@ end do
 !-----------------------------!
 !     real overlap matrix     !
 !-----------------------------!
-allocate(ro(nmatp**2))
-! <APW|O|APW>
+! ⟨APW|O|APW⟩
 do j=1,ngp
   k=(j-1)*nmatp+1
   ro(k:k+j-1)=dble(o(k:k+j-1))
 end do
-! <APW|O|lo>
+! ⟨APW|O|lo⟩
 do m1=1,nlotot
   j1=(ngp+m1-1)*nmatp
   j2=(ngp+idx(m1)-1)*nmatp
@@ -201,7 +209,7 @@ do m1=1,nlotot
     end if
   end if
 end do
-! <lo|O|lo>
+! ⟨lo|O|lo⟩
 do m1=1,nlotot
   m2=idx(m1)
   do l1=1,m1
@@ -222,13 +230,12 @@ do m1=1,nlotot
   end do
 end do
 ! solve the generalised eigenvalue problem for real symmetric matrices
-allocate(rv(nmatp,nstfv))
 ! enable MKL parallelism
 call holdthd(maxthdmkl,nthd)
 nts=mkl_set_num_threads_local(nthd)
-! diagonalise the matrix
+! diagonalise the matrix (use o_ as the work array)
 call dsygvx(1,'V','I','U',nmatp,rh,nmatp,ro,nmatp,vl,vu,1,nstfv,evaltol,m,w, &
- rv,nmatp,work,8*nmatp,iwork,ifail,info)
+ rv,nmatp,o_,n2,iwork,ifail,info)
 nts=mkl_set_num_threads_local(0)
 call freethd(nthd)
 if (info /= 0) then
@@ -257,8 +264,8 @@ do j=1,nstfv
       evecfv(i1,j)=evecfv(i1,j)+t1
       evecfv(i2,j)=evecfv(i2,j)+s(l1)*t1
     else
-      evecfv(i1,j)=evecfv(i1,j)-cmplx(0.d0,t1,8)
-      evecfv(i2,j)=evecfv(i2,j)-cmplx(0.d0,s(l1)*t1,8)
+      evecfv(i1,j)%im=evecfv(i1,j)%im-t1
+      evecfv(i2,j)%im=evecfv(i2,j)%im-s(l1)*t1
     end if
   end do
   do l1=1,nlotot
@@ -268,7 +275,7 @@ do j=1,nstfv
     end if
   end do
 end do
-deallocate(rh,ro,rv)
+deallocate(rh)
 call timesec(ts1)
 !$OMP ATOMIC
 timefv=timefv+ts1-ts0
