@@ -13,20 +13,29 @@ complex(8), intent(in) :: h(*),o(*)
 real(8), intent(out) :: evalfv(nstfv)
 complex(8), intent(out) :: evecfv(nmatmax,nstfv)
 ! local variables
-integer m,info,nthd,nts
+integer nb,lwork,nts
+integer m,info,nthd
 real(8) vl,vu
 real(8) ts0,ts1
 ! automatic arrays
 integer iwork(5*nmatp),ifail(nmatp)
 real(8) w(nmatp),rwork(7*nmatp)
-complex(8) work(2*nmatp)
+! allocatable arrays
+complex(8), allocatable :: work(:)
+! external functions
+integer, external :: ilaenv
 call timesec(ts0)
+! find the optimal blocksize for allocating the work array
+nb=ilaenv(1,'ZHETRD','U',nmatp,-1,-1,-1)
+nb=max(nb,1)
+lwork=(nb+1)*nmatp
+allocate(work(lwork))
 ! enable MKL parallelism
 call holdthd(maxthdmkl,nthd)
 nts=mkl_set_num_threads_local(nthd)
 ! diagonalise the matrix
 call zhegvx(1,'V','I','U',nmatp,h,nmatp,o,nmatp,vl,vu,1,nstfv,evaltol,m,w, &
- evecfv,nmatmax,work,2*nmatp,rwork,iwork,ifail,info)
+ evecfv,nmatmax,work,lwork,rwork,iwork,ifail,info)
 nts=mkl_set_num_threads_local(0)
 call freethd(nthd)
 if (info /= 0) then
@@ -43,6 +52,7 @@ if (info /= 0) then
   stop
 end if
 evalfv(1:nstfv)=w(1:nstfv)
+deallocate(work)
 call timesec(ts1)
 !$OMP ATOMIC
 timefv=timefv+ts1-ts0
