@@ -9,8 +9,8 @@ use modomp
 implicit none
 ! arguments
 integer, intent(in) :: ikp
-real(8), intent(in) :: vmt(npcmtmax,natmtot),vir(ngtot)
-real(8), intent(in) :: bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag)
+real(8), intent(in) :: vmt(npcmtmax,natmtot),vir(ngtc)
+real(8), intent(in) :: bmt(npcmtmax,natmtot,ndmag),bir(ngtc,ndmag)
 complex(8), intent(inout) :: evecsvp(nstsv,nstsv)
 ! local variables
 integer ik,jk,nst
@@ -90,7 +90,7 @@ do ik=1,nkptnr
   vc(:)=vkc(:,ikp)-vkc(:,ik)
   do ig=1,ngvc
 ! determine the G+q-vectors
-    vgqc(:,ig)=vgc(:,ig)+vc(:)
+    vgqc(1:3,ig)=vgc(1:3,ig)+vc(1:3)
 ! G+q-vector length
     gqc(ig)=sqrt(vgqc(1,ig)**2+vgqc(2,ig)**2+vgqc(3,ig)**2)
 ! spherical harmonics for G+q-vectors
@@ -126,14 +126,14 @@ do ik=1,nkptnr
   do ist3=1,nst
     jst3=idx(ist3)
 ! calculate the complex overlap densities for all states (T. McQueen)
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
     do ist1=1,nstsv
       call gencrho(.true.,.true.,ngtc,wfmt2(:,:,:,ist3),wfir2(:,:,ist3), &
        wfmt1(:,:,:,ist1),wfir1(:,:,ist1),crhomt(:,:,ist1),crhoir(:,ist1))
     end do
 !$OMP END DO
     t1=wqptnr*occsv(jst3,jk)/occmax
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
     do ist2=1,nstsv
 ! calculate the Coulomb potential
       call gencvclmt(nrcmt,nrcmti,nrcmtmax,rlcmt,wprcmt,npcmtmax, &
