@@ -53,17 +53,9 @@ ca=-1.d0/solsc
 if (tafield) a(1:3)=ca*afieldc(1:3)
 if (tafsp) asp(1:3,1:3)=ca*afspc(1:3,1:3)
 ! check if the off-diagonal spin block of the Hamiltonian is required
-if (spinpol.and.(ncmag.or.spinorb)) then
-  todsb=.true.
-else
-  todsb=.false.
-end if
+todsb=(spinpol.and.(ncmag.or.spinorb))
 ! special case of spin-orbit coupling and collinear magnetism
-if (spinorb.and.cmagz) then
-  socz=.true.
-else
-  socz=.false.
-end if
+socz=(spinorb.and.cmagz)
 ld=lmmaxdm*nspinor
 call holdthd(nstfv,nthd)
 ! zero the second-variational Hamiltonian (stored in the eigenvector array)
