@@ -56,7 +56,7 @@ a(:,:)=dw(:,:)-ex(:,:)
 x(:)=fy(:)
 call zgemv('T',n,n,(1.d0,0.d0),a,n,x,1,(0.d0,0.d0),fy,1)
 do i=1,n
-  if (w(i).gt.1.d-6) then
+  if (w(i) > 1.d-6) then
     fy(i)=fy(i)/w(i)
   else
     fy(i)=0.d0
