@@ -13,11 +13,12 @@ complex(8), intent(out) :: w(n)
 ! local variables
 integer lwork,info
 integer nthd,nts
+! automatic arrays
+real(8) rwork(2*n)
 ! allocatable arrays
-real(8), allocatable :: rwork(:)
 complex(8), allocatable :: vr(:,:),work(:)
 lwork=2*n
-allocate(rwork(2*n),vr(n,n),work(lwork))
+allocate(vr(n,n),work(lwork))
 ! enable MKL parallelism
 call holdthd(maxthdmkl,nthd)
 nts=mkl_set_num_threads_local(nthd)
@@ -34,6 +35,6 @@ if (info /= 0) then
 end if
 ! copy right eigenvectors to output array
 a(1:n,1:n)=vr(1:n,1:n)
-deallocate(rwork,vr,work)
+deallocate(vr,work)
 end subroutine
 
