@@ -12,21 +12,24 @@ integer, intent(in) :: n,ld
 complex(8), intent(inout) :: a(ld,n)
 real(8), intent(out) :: w(n)
 ! local variables
-integer lrwork,lwork,info
-integer nthd,nts
+integer nb,lwork,lrwork
+integer nts,info,nthd
 ! automatic arrays
-integer iwork(5*n+3)
+integer iwork(3+5*n)
 ! allocatable arrays
 real(8), allocatable :: rwork(:)
 complex(8), allocatable :: work(:)
-! use the divide-and-conquer LAPACK routine zheevd
-lrwork=2*n**2+5*n+1
-lwork=n**2+2*n
-allocate(rwork(lrwork),work(lwork))
+! external functions
+integer, external :: ilaenv
+! find the optimal blocksize for allocating the work array
+nb=ilaenv(1,'ZHETRD','U',n,-1,-1,-1)
+lwork=max(2*n+n**2,(nb+1)*n)
+lrwork=1+5*n+2*n**2
+allocate(work(lwork),rwork(lrwork))
 ! enable MKL parallelism
 call holdthd(maxthdmkl,nthd)
 nts=mkl_set_num_threads_local(nthd)
-call zheevd('V','U',n,a,ld,w,work,lwork,rwork,lrwork,iwork,5*n+3,info)
+call zheevd('V','U',n,a,ld,w,work,lwork,rwork,lrwork,iwork,3+5*n,info)
 nts=mkl_set_num_threads_local(0)
 call freethd(nthd)
 if (info /= 0) then
