@@ -26,7 +26,7 @@ engyx=0.d0
 call holdthd(nkpt/np_mpi,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi) /= lp_mpi) cycle
@@ -65,7 +65,7 @@ do is=1,nspecies
 ! calculate the Coulomb potential
                 call cpotclmt(nrc,nrci,nrcmtmax,rlcmt(:,:,is),wprcmt(:,:,is), &
                  crhomt,cvclmt)
-                z1=zcfmtinp(nrc,nrci,wrcmt(:,is),crhomt,cvclmt)
+                z1=zcfmtinp(nrc,nrci,wr2cmt(:,is),crhomt,cvclmt)
                 engyx=engyx-0.5d0*dble(z1)
               end do
 ! end loop over ist
@@ -87,7 +87,7 @@ implicit none
 integer, intent(in) :: n
 complex(4), intent(in) :: wf11(n),wf12(n),wf21(n),wf22(n)
 complex(4), intent(out) :: crho(n)
-crho(:)=conjg(wf11(:))*wf21(:)+conjg(wf12(:))*wf22(:)
+crho(1:n)=conjg(wf11(1:n))*wf21(1:n)+conjg(wf12(1:n))*wf22(1:n)
 end subroutine
 
 end subroutine
