@@ -71,7 +71,7 @@ do ik=1,nkptnr
   vc(:)=vkc(:,ikp)-vkc(:,ik)
   do ig=1,ngvc
 ! determine the G+q-vectors
-    vgqc(:,ig)=vgc(:,ig)+vc(:)
+    vgqc(1:3,ig)=vgc(1:3,ig)+vc(1:3)
 ! G+q-vector length
     gqc(ig)=sqrt(vgqc(1,ig)**2+vgqc(2,ig)**2+vgqc(3,ig)**2)
 ! spherical harmonics for G+q-vectors
@@ -110,7 +110,7 @@ do ik=1,nkptnr
       call gencvclmt(nrcmt,nrcmti,nrcmtmax,rlcmt,wprcmt,npcmtmax,crhomt,cvclmt)
       call cpotcoul(nrcmt,nrcmti,npcmt,nrcmtmax,rlcmt,ngdgc,igfc,ngvc,gqc, &
        gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,crhoir,npcmtmax,cvclmt,cvclir)
-      cvclir(:)=cvclir(:)*cfrc(:)
+      cvclir(1:ngtc)=cvclir(1:ngtc)*cfrc(1:ngtc)
       z1=zcfinp(crhomt,crhoir,cvclmt,cvclir)
       ex=ex-0.5d0*occmax*wkpt(ikp)*wqptnr*dble(z1)
     end do
@@ -149,7 +149,7 @@ do is=1,nspecies
 ! calculate the Coulomb potential
             call cpotclmt(nrc,nrci,nrcmtmax,rlcmt(:,:,is),wprcmt(:,:,is), &
              crhomt(:,ias),cvclmt(:,ias))
-            z1=zcfmtinp(nrc,nrci,wrcmt(:,is),crhomt(:,ias),cvclmt(:,ias))
+            z1=zcfmtinp(nrc,nrci,wr2cmt(:,is),crhomt(:,ias),cvclmt(:,ias))
             ex=ex-occmax*wkpt(ikp)*dble(z1)
           end do
 ! end loop over m
@@ -175,7 +175,7 @@ implicit none
 integer, intent(in) :: n
 complex(4), intent(in) :: wf1(n),wf2(n)
 complex(4), intent(out) :: crho(n)
-crho(:)=conjg(wf1(:))*wf2(:)
+crho(1:n)=conjg(wf1(1:n))*wf2(1:n)
 end subroutine
 
 pure subroutine crho2(n,wf11,wf12,wf21,wf22,crho)
@@ -183,7 +183,7 @@ implicit none
 integer, intent(in) :: n
 complex(4), intent(in) :: wf11(n),wf12(n),wf21(n),wf22(n)
 complex(4), intent(out) :: crho(n)
-crho(:)=conjg(wf11(:))*wf21(:)+conjg(wf12(:))*wf22(:)
+crho(1:n)=conjg(wf11(1:n))*wf21(1:n)+conjg(wf12(1:n))*wf22(1:n)
 end subroutine
 
 end subroutine
