@@ -24,22 +24,22 @@ integer, intent(in) :: n,d
 ! local variables
 integer i
 ! external functions
-real(8), external :: factnm
-if (d.eq.1) then
-  factr=factnm(n,1)
+real(8), external :: factn
+if (d == 1) then
+  factr=factn(n)
   return
 end if
-if ((n.lt.0).or.(d.lt.0)) then
+if ((n < 0).or.(d < 0)) then
   factr=0.d0
   return
 end if
-if (n.lt.d) then
+if (n < d) then
   factr=dble(n+1)
   do i=n+2,d
     factr=factr*dble(i)
   end do
   factr=1.d0/factr
-else if (n.eq.d) then
+else if (n == d) then
   factr=1.d0
 else
   factr=dble(d+1)
