@@ -35,9 +35,9 @@ integer i
 real(8) sm,dx
 ! automatic arrays
 real(8) cf(3,n)
-if (n <= 0) then
+if (n < 1) then
   write(*,*)
-  write(*,'("Error(fderiv): invalid number of points : ",I8)') n
+  write(*,'("Error(fderiv): n < 1 : ",I8)') n
   write(*,*)
   stop
 end if
