@@ -8,14 +8,15 @@ use modmain
 use modomp
 implicit none
 ! local variables
-integer ik,nst,ist
+integer ik,ist,np,nfp,i
 integer ist0,ist1,jst0,jst1
-integer i1,i2,i3,nf,f
-integer np,i,nthd
-real(8) e0,e1,prd,v(3)
+integer l,i1,i2,i3,nthd
+real(8) e0,e1,v(3),x,fn
 ! allocatable arrays
 real(8), allocatable :: evalfv(:,:),vpc(:,:)
 complex(8), allocatable :: evecfv(:,:,:),evecsv(:,:)
+! external functions
+real(8), external :: sdelta
 ! initialise universal variables
 call init0
 ! no k-point reduction for the collinear case
@@ -38,9 +39,8 @@ call holdthd(nkpt,nthd)
 !$OMP PRIVATE(evalfv,evecfv,evecsv) &
 !$OMP NUM_THREADS(nthd)
 allocate(evalfv(nstfv,nspnfv))
-allocate(evecfv(nmatmax,nstfv,nspnfv))
-allocate(evecsv(nstsv,nstsv))
-!$OMP DO
+allocate(evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv))
+!$OMP DO SCHEDULE(DYNAMIC)
 do ik=1,nkpt
 !$OMP CRITICAL(fermisurf_)
   write(*,'("Info(fermisurf): ",I6," of ",I6," k-points")') ik,nkpt
@@ -70,13 +70,13 @@ do i=1,np
 end do
 ! number of files to plot (2 for collinear magnetism, 1 otherwise)
 if (ndmag == 1) then
-  nf=2
+  nfp=2
 else
-  nf=1
+  nfp=1
 end if
-do f=1,nf
-  if (nf == 2) then
-    if (f == 1) then
+do l=1,nfp
+  if (nfp == 2) then
+    if (l == 1) then
       open(50,file='FERMISURF_UP.OUT',form='FORMATTED',action='WRITE')
       jst0=1; jst1=nstfv
     else
@@ -87,18 +87,21 @@ do f=1,nf
     open(50,file='FERMISURF.OUT',form='FORMATTED',action='WRITE')
     jst0=1; jst1=nstsv
   end if
+  if ((task == 100).or.(task == 101)) then
 ! find the range of eigenvalues which contribute to the Fermi surface (Lars)
-  ist0=jst1; ist1=jst0
-  do ist=jst0,jst1
-    e0=minval(evalsv(ist,:)); e1=maxval(evalsv(ist,:))
+    ist0=jst1; ist1=jst0
+    do ist=jst0,jst1
+      e0=minval(evalsv(ist,:)); e1=maxval(evalsv(ist,:))
 ! determine if the band crosses the Fermi energy
-    if ((e0 < efermi).and.(e1 > efermi)) then
-      ist0=min(ist0,ist); ist1=max(ist1,ist)
-    end if
-  end do
-  nst=ist1-ist0+1
-  if (task == 100) then
-! write product of eigenstates minus the Fermi energy
+      if ((e0 < efermi).and.(e1 > efermi)) then
+        ist0=min(ist0,ist); ist1=max(ist1,ist)
+      end if
+    end do
+  else
+! use all eigenvalues
+    ist0=jst0; ist1=jst1
+  end if
+  if ((task == 100).or.(task == 103)) then
     write(50,'(3I6," : grid size")') np3d(:)
     i=0
     do i3=0,ngridk(3)-1
@@ -106,21 +109,41 @@ do f=1,nf
         do i1=0,ngridk(1)-1
           i=i+1
           ik=ivkik(i1,i2,i3)
-          prd=product(evalsv(ist0:ist1,ik)-efermi)
-          write(50,'(4G18.10)') vpc(:,i),prd
+          if (task == 100) then
+! write product of eigenstates minus the Fermi energy
+            fn=product(evalsv(ist0:ist1,ik)-efermi)
+          else
+! write single smooth delta function at the Fermi energy
+            fn=0.d0
+            do ist=ist0,ist1
+              x=(evalsv(ist,ik)-efermi)/swidth
+              fn=fn+sdelta(stype,x)/swidth
+            end do
+          end if
+          write(50,'(4G18.10)') vpc(:,i),fn
         end do
       end do
     end do
   else
-! write the eigenvalues minus the Fermi energy separately
-    write(50,'(4I6," : grid size, number of states")') np3d(:),nst
+    write(50,'(4I6," : grid size, number of states")') np3d(:),ist1-ist0+1
     i=0
     do i3=0,ngridk(3)-1
       do i2=0,ngridk(2)-1
         do i1=0,ngridk(1)-1
           i=i+1
           ik=ivkik(i1,i2,i3)
-          write(50,'(3G18.10,40F14.8)') vpc(:,i),evalsv(ist0:ist1,ik)-efermi
+          write(50,'(3G18.10)',advance='NO') vpc(:,i)
+          do ist=ist0,ist1
+            if (task == 101) then
+! write the eigenvalues minus the Fermi energy separately
+              write(50,'(F14.8)',advance='NO') evalsv(ist,ik)-efermi
+            else
+! write separate smooth delta functions at the Fermi energy
+              x=(evalsv(ist,ik)-efermi)/swidth
+              write(50,'(F14.8)',advance='NO') sdelta(stype,x)/swidth
+            end if
+          end do
+          write(50,*)
         end do
       end do
     end do
@@ -137,8 +160,12 @@ else
 end if
 if (task == 100) then
   write(*,'(" in terms of the product of eigenvalues minus the Fermi energy")')
-else
+else if (task == 101) then
   write(*,'(" in terms of separate eigenvalues minus the Fermi energy")')
+else if (task == 103) then
+  write(*,'(" in terms of a smooth delta function at the Fermi energy")')
+else
+  write(*,'(" in terms of separate delta functions at the Fermi energy")')
 end if
 deallocate(vpc)
 ! restore original parameters
