@@ -107,9 +107,9 @@ do jspn=1,nspnfv
           t1=vgc(l,ig)
           z1=-ffacg(ig,is)*conjg(sfacg(ig,ias))
           z2=t1*(dp(i,j)*z1+h(i,j))
-          dlh(i,j)=cmplx(-aimag(z2),dble(z2),8)
+          dlh(i,j)=zi*z2
           z2=t1*(z1+o(i,j))
-          dlo(i,j)=cmplx(-aimag(z2),dble(z2),8)
+          dlo(i,j)=zi*z2
         end do
       end do
 ! APW-local-orbital contribution
@@ -117,15 +117,16 @@ do jspn=1,nspnfv
         do i=1,n
           t1=vgkc(l,i,jspn,ik)
           z1=t1*h(i,j)
-          dlh(i,j)=cmplx(-aimag(z1),dble(z1),8)
+          dlh(i,j)=zi*z1
           z1=t1*o(i,j)
-          dlo(i,j)=cmplx(-aimag(z1),dble(z1),8)
+          dlo(i,j)=zi*z1
         end do
       end do
 ! compute the force matrix elements in the first-variational basis
       call holdthd(nstfv,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(vh,vo,t1,ist,z1,z2) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
       do jst=1,nstfv
         call zhemv('U',nm,zone,dlh,nmatmax,evecfv(:,jst,jspn),1,zzero,vh,1)
