@@ -25,13 +25,14 @@ integer, intent(in) :: m,n
 real(8), intent(inout) :: f(n)
 ! local variables
 integer i,j
-! automatic arrays
-real(8) g(n)
+real(8) f1,f2,f3
 do i=1,m
+  f1=f(1); f2=f(2)
   do j=2,n-1
-    g(j)=0.3333333333333333333d0*(f(j-1)+f(j)+f(j+1))
+    f3=f(j+1)
+    f(j)=0.3333333333333333333d0*(f1+f2+f3)
+    f1=f2; f2=f3
   end do
-  f(2:n-1)=g(2:n-1)
 end do
 end subroutine
 !EOC
