@@ -23,9 +23,9 @@ implicit none
 integer, intent(in) :: x,y
 ! local variables
 integer a,b,c
-if ((x <= 0).or.(y <= 0)) then
+if ((x < 1).or.(y < 1)) then
   write(*,*)
-  write(*,'("Error(gcd): x <= 0 or y <= 0 : ",2I8)') x,y
+  write(*,'("Error(gcd): x < 1 or y < 1 : ",2I8)') x,y
   write(*,*)
   stop
 end if
