@@ -32,7 +32,6 @@ integer nr,nri,iro,ir
 integer i0,i1,nn,l,io,jo
 real(8) e,t1
 ! automatic arrays
-logical done(natmmax)
 real(8) vr(nrmtmax),fr(nrmtmax)
 real(8) p0(nrmtmax,apwordmax),p1(nrmtmax),p1s(apwordmax)
 real(8) q0(nrmtmax),q1(nrmtmax),ep0(nrmtmax,apwordmax)
@@ -41,10 +40,10 @@ do is=1,nspecies
   nr=nrmt(is)
   nri=nrmti(is)
   iro=nri+1
-  done(:)=.false.
 ! loop over atoms
   do ia=1,natoms(is)
-    if (done(ia)) cycle
+! perform calculation for only the first equivalent atom
+    if (.not.tfeqat(ia,is)) cycle
     ias=idxas(ia,is)
 ! use spherical part of potential
     i1=lmmaxi*(nri-1)+1
@@ -55,7 +54,7 @@ do is=1,nspecies
     do l=0,lmaxapw
       do io=1,apword(l,is)
 ! linearisation energy accounting for energy derivative
-        e=apwe(io,l,ias)+dble(apwdm(io,l,is))*deapwlo
+        e=apwe(io,l,ias)+dble(apwdm(io,l,is))*deapw
 ! integrate the radial Schrodinger equation
         call rschrodint(solsc,l,e,nr,rlmt(:,1,is),vr,nn,p0(:,io),p1,q0,q1)
 ! multiply by the linearisation energy
@@ -76,22 +75,24 @@ do is=1,nspecies
           ep0(1:nr,io)=ep0(1:nr,io)+t1*ep0(1:nr,jo)
         end do
 ! normalise radial functions again
-        fr(1:nr)=p0(1:nr,io)**2
-        t1=abs(dot_product(wrmt(1:nr,is),fr(1:nr)))
-        if (t1 < 1.d-25) then
-          write(*,*)
-          write(*,'("Error(genapwfr): degenerate APW radial functions")')
-          write(*,'(" for species ",I4)') is
-          write(*,'(" atom ",I4)') ia
-          write(*,'(" angular momentum ",I4)') l
-          write(*,'(" and order ",I4)') io
-          write(*,*)
-          stop
+        if (io > 1) then
+          fr(1:nr)=p0(1:nr,io)**2
+          t1=abs(dot_product(wrmt(1:nr,is),fr(1:nr)))
+          if (t1 < 1.d-25) then
+            write(*,*)
+            write(*,'("Error(genapwfr): degenerate APW radial functions")')
+            write(*,'(" for species ",I4)') is
+            write(*,'(" atom ",I4)') ia
+            write(*,'(" angular momentum ",I4)') l
+            write(*,'(" and order ",I4)') io
+            write(*,*)
+            stop
+          end if
+          t1=1.d0/sqrt(t1)
+          p0(1:nr,io)=t1*p0(1:nr,io)
+          p1s(io)=t1*p1s(io)
+          ep0(1:nr,io)=t1*ep0(1:nr,io)
         end if
-        t1=1.d0/sqrt(t1)
-        p0(1:nr,io)=t1*p0(1:nr,io)
-        p1s(io)=t1*p1s(io)
-        ep0(1:nr,io)=t1*ep0(1:nr,io)
 ! divide by r and store in global array
         do ir=1,nr
           t1=rlmt(ir,-1,is)
@@ -102,10 +103,9 @@ do is=1,nspecies
         apwdfr(io,l,ias)=(p1s(io)*rmt(is)-p0(nr,io))/2.d0
       end do
     end do
-    done(ia)=.true.
 ! copy to equivalent atoms
     do ja=1,natoms(is)
-      if ((.not.done(ja)).and.(eqatoms(ia,ja,is))) then
+      if (eqatoms(ia,ja,is).and.(ia /= ja)) then
         jas=idxas(ja,is)
         do l=0,lmaxapw
           do io=1,apword(l,is)
@@ -113,7 +113,6 @@ do is=1,nspecies
             apwdfr(io,l,jas)=apwdfr(io,l,ias)
           end do
         end do
-        done(ja)=.true.
       end if
     end do
 ! end loop over atoms and species
