@@ -9,27 +9,25 @@ implicit none
 ! local variables
 integer nthd
 call holdthd(2,nthd)
-!$OMP PARALLEL SECTIONS DEFAULT(SHARED) &
+!$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP NUM_THREADS(nthd)
+!$OMP SECTIONS
 !$OMP SECTION
 ! generate the APW radial functions
 call genapwfr
 !$OMP SECTION
 ! generate the local-orbital radial functions
 call genlofr
-!$OMP END PARALLEL SECTIONS
-call freethd(nthd)
-call holdthd(2,nthd)
-!$OMP PARALLEL SECTIONS DEFAULT(SHARED) &
-!$OMP NUM_THREADS(nthd)
+!$OMP END SECTIONS
+!$OMP SECTIONS
 !$OMP SECTION
 ! compute the overlap radial integrals
 call olprad
 !$OMP SECTION
 ! compute the Hamiltonian radial integrals
 call hmlrad
-!$OMP END PARALLEL SECTIONS
+!$OMP END SECTIONS
+!$OMP END PARALLEL
 call freethd(nthd)
-return
 end subroutine
 
