@@ -53,10 +53,10 @@ do is=1,nspecies
 end do
 ! allocate global characteristic function arrays
 if (allocated(cfunig)) deallocate(cfunig)
-allocate(cfunig(ngtot))
+allocate(cfunig(ngvec))
 if (allocated(cfunir)) deallocate(cfunir)
 allocate(cfunir(ngtot))
-cfunig(1:ngtot)=zfft(igfft(1:ngtot))
+cfunig(1:ngvec)=zfft(igfft(1:ngvec))
 ! Fourier transform to real-space
 call zfftifc(3,ngridg,1,zfft)
 cfunir(1:ngtot)=dble(zfft(1:ngtot))
