@@ -28,8 +28,7 @@ if (ncmag) then
 ! x-component: up-dn + dn-up
     cmag(i,1)=c1+c2
 ! y-component: i*(dn-up - up-dn)
-    c1=c2-c1
-    cmag(i,2)=cmplx(-aimag(c1),real(c1),4)
+    cmag(i,2)=ci*(c2-c1)
     c1=conjg(c11)*c21
     c2=conjg(c12)*c22
 ! z-component: up-up - dn-dn
