@@ -10,11 +10,12 @@ implicit none
 ! allocatable arrays
 complex(8), allocatable :: zfft(:)
 allocate(zfft(ngtot))
-zfft(:)=dvsir(:)*cfunir(:)+vsir(:)*dcfunir(:)
+zfft(1:ngtot)=dvsir(1:ngtot)*cfunir(1:ngtot)
+zfft(1:ngtot)=zfft(1:ngtot)+vsir(1:ngtot)*dcfunir(1:ngtot)
 ! Fourier transform to G+q-space
 call zfftifc(3,ngridg,-1,zfft)
 ! store in global array
-dvsig(1:ngvec)=zfft(igfft(1:ngvec))
+dvsig(1:ngvc)=zfft(igfft(1:ngvc))
 deallocate(zfft)
 end subroutine
 
