@@ -9,9 +9,8 @@ use modmain
 implicit none
 ! arguments
 logical, intent(in) :: tsh,tgp
-integer, intent(in) :: nst,idx(nst)
-integer, intent(in) :: ngp(nspnfv),ngpq(nspnfv)
-integer, intent(in) :: igpqig(ngkmax,nspnfv)
+integer, intent(in) :: nst,idx(*)
+integer, intent(in) :: ngp(nspnfv),ngpq(nspnfv),igpqig(ngkmax,nspnfv)
 complex(8), intent(in) :: apwalmq(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv)
 complex(8), intent(in) :: dapwalm(ngkmax,apwordmax,lmmaxapw,nspnfv)
 complex(8), intent(in) :: evecfv(nmatmax,nstfv,nspnfv)
@@ -24,7 +23,7 @@ complex(8), intent(out) :: dwfir(ld,nspinor,nst)
 integer ist,ispn,jspn
 integer is,ia,ias,nrc,nrci
 integer npc,igp,ifg,i,j,k
-real(8) t1
+real(8) t0
 complex(8) z1
 ! automatic arrays
 logical done(nstfv),ddone(nstfv)
@@ -106,10 +105,10 @@ if (.not.tsh) deallocate(wfmt2)
 !-----------------------------------------------!
 !     interstitial wavefunction derivatives     !
 !-----------------------------------------------!
-t1=1.d0/sqrt(omega)
+t0=1.d0/sqrt(omega)
 do j=1,nst
   k=idx(j)
-  dwfir(:,:,j)=0.d0
+  dwfir(1:ld,1:nspinor,j)=0.d0
   if (tevecsv) then
     i=0
     do ispn=1,nspinor
@@ -117,15 +116,16 @@ do j=1,nst
       do ist=1,nstfv
         i=i+1
         z1=devecsv(i,k)
+!***** check if tq0 is needed here
         if (abs(dble(z1))+abs(aimag(z1)) > epsocc) then
           if (tgp) then
             do igp=1,ngp(jspn)
               dwfir(igp,ispn,j)=dwfir(igp,ispn,j)+z1*evecfv(igp,ist,jspn)
             end do
           else
-            z1=t1*z1
+            z1=t0*z1
             do igp=1,ngp(jspn)
-              ifg=igfft(igpqig(igp,jspn))
+              ifg=igfc(igpqig(igp,jspn))
               dwfir(ifg,ispn,j)=dwfir(ifg,ispn,j)+z1*evecfv(igp,ist,jspn)
             end do
           end if
@@ -137,9 +137,9 @@ do j=1,nst
               dwfir(igp,ispn,j)=dwfir(igp,ispn,j)+z1*devecfv(igp,ist,jspn)
             end do
           else
-            z1=t1*z1
+            z1=t0*z1
             do igp=1,ngpq(jspn)
-              ifg=igfft(igpqig(igp,jspn))
+              ifg=igfc(igpqig(igp,jspn))
               dwfir(ifg,ispn,j)=dwfir(ifg,ispn,j)+z1*devecfv(igp,ist,jspn)
             end do
           end if
@@ -153,14 +153,14 @@ do j=1,nst
       end do
     else
       do igp=1,ngpq(1)
-        ifg=igfft(igpqig(igp,1))
-        dwfir(ifg,1,j)=t1*devecfv(igp,k,1)
+        ifg=igfc(igpqig(igp,1))
+        dwfir(ifg,1,j)=t0*devecfv(igp,k,1)
       end do
     end if
   end if
   if (.not.tgp) then
     do ispn=1,nspinor
-      call zfftifc(3,ngridg,1,dwfir(:,ispn,j))
+      call zfftifc(3,ngdgc,1,dwfir(:,ispn,j))
     end do
   end if
 end do
