@@ -8,20 +8,19 @@ use modmain
 use modtddft
 implicit none
 ! local variables
-integer np,it,i,j
+integer, parameter :: npm=8
+integer np,it,i
 real(8) t0
 ! automatic arrays
-real(8) ya(4)
+real(8) ya(npm)
 ! external functions
 real(8), external :: polynm
 ! determine the electric field at the current time step
 t0=-1.d0/solsc
-np=min(4,itimes)
+np=min(npm,itimes)
 it=itimes-np+1
 do i=1,3
-  do j=1,np
-    ya(j)=afieldt(i,it+j-1)
-  end do
+  ya(1:np)=afieldt(i,it:itimes)
   efieldt(i)=t0*polynm(1,np,times(it),ya,times(itimes))
 end do
 end subroutine
