@@ -11,7 +11,7 @@ implicit none
 integer, intent(in) :: iq,ik
 real(8), intent(in) :: de
 complex(8), intent(in) :: a(nbph,nbph)
-complex(8), intent(in) :: dvmt(npcmtmax,natmtot,nbph),dvir(ngtot,nbph)
+complex(8), intent(in) :: dvmt(npcmtmax,natmtot,nbph),dvir(ngtc,nbph)
 complex(8), intent(out) :: ephmat(nstsv,nstsv,nbph)
 ! local variables
 integer jk,jkq,isym,ld
@@ -32,7 +32,7 @@ complex(4), allocatable :: wfir1(:),wfir2(:)
 ! equivalent reduced k-point
 jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
 ! k+q-vector in lattice coordinates
-vpql(:)=vkl(:,ik)+vql(:,iq)
+vpql(1:3)=vkl(1:3,ik)+vql(1:3,iq)
 ! find reduced k-point index corresponding to k+q
 call findkpt(vpql,isym,jkq)
 ! index to states in energy window around Fermi energy
@@ -58,7 +58,7 @@ allocate(wfmtq(npcmtmax,natmtot,nspinor,nstq),wfgpq(ngkmax,nspinor,nstq))
 call genwfsvp_sp(.false.,.true.,nstq,idxq,ngridg,igfft,vpql,ngpq,igpqig,wfmtq, &
  ngkmax,wfgpq)
 ! zero the electron-phonon coupling matrix elements
-ephmat(:,:,:)=0.d0
+ephmat(1:nstsv,1:nstsv,1:nbph)=0.d0
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
@@ -87,25 +87,25 @@ deallocate(wfmt,wfmtq)
 !---------------------------!
 !     interstitial part     !
 !---------------------------!
-allocate(wfir1(ngtot),wfir2(ngtot))
+allocate(wfir1(ngtc),wfir2(ngtc))
 do j=1,nst
   jst=idx(j)
   do ispn=1,nspinor
     jspn=jspnfv(ispn)
     nq=ngpq(jspn)
 ! Fourier transform wavefunction to real-space
-    wfir1(:)=0.e0
+    wfir1(1:ngtc)=0.e0
     do igp=1,ngp(jspn)
-      wfir1(igfft(igpig(igp,jspn)))=wfgp(igp,ispn,j)
+      wfir1(igfc(igpig(igp,jspn)))=wfgp(igp,ispn,j)
     end do
-    call cfftifc(3,ngridg,1,wfir1)
+    call cfftifc(3,ngdgc,1,wfir1)
     do l=1,nbph
 ! apply potential derivative to wavefunction
-      wfir2(:)=dvir(:,l)*wfir1(:)
+      wfir2(1:ngtc)=dvir(1:ngtc,l)*wfir1(1:ngtc)
 ! Fourier transform to G+p+q-space
-      call cfftifc(3,ngridg,-1,wfir2)
+      call cfftifc(3,ngdgc,-1,wfir2)
       do igp=1,nq
-        c(igp)=wfir2(igfft(igpqig(igp,jspn)))
+        c(igp)=wfir2(igfc(igpqig(igp,jspn)))
       end do
       do i=1,nstq
         ist=idxq(i)
@@ -123,7 +123,7 @@ do i=1,nstq
   ist=idxq(i)
   do j=1,nst
     jst=idx(j)
-    x(:)=ephmat(ist,jst,:)
+    x(1:nbph)=ephmat(ist,jst,1:nbph)
     call zgemv('T',nbph,nbph,zone,a,nbph,x,1,zzero,ephmat(ist,jst,1),ld)
   end do
 end do
