@@ -25,7 +25,7 @@ complex(8), allocatable :: apwalm1(:,:,:,:),apwalm2(:,:,:,:)
 complex(8), allocatable :: evecfv1(:,:),evecfv2(:,:)
 complex(8), allocatable :: evecsv1(:,:),evecsv2(:,:)
 complex(8), allocatable :: wfmt1(:),wfmt2(:,:)
-complex(8), allocatable :: zfir(:),x(:),em(:,:)
+complex(8), allocatable :: zfir(:),z(:),em(:,:)
 ! external functions
 complex(8), external :: zfmtinp,zdotc
 ! check if q-vector is zero
@@ -49,7 +49,7 @@ if (tevecsv) then
   allocate(evecsv1(nstsv,nstsv),evecsv2(nstsv,nstsv))
 end if
 allocate(wfmt1(npcmtmax),wfmt2(npcmtmax,nstfv))
-allocate(zfir(ngtot),x(ngkmax),em(nstfv,nstfv))
+allocate(zfir(ngtot),z(ngkmax),em(nstfv,nstfv))
 ! p-vector in Cartesian coordinates
 call r3mv(bvec,vpl,vpc)
 ! generate the G+p-vectors
@@ -97,7 +97,8 @@ do is=1,nspecies
 ! calculate the wavefunction for k-point p
       call wfmtfv(ias,ngp,apwalm1(:,:,:,ias),evecfv1(:,jst),wfmt1)
       do ist=1,nstfv
-        em(ist,jst)=em(ist,jst)+zfmtinp(nrc,nrci,wrcmt(:,is),wfmt2(:,ist),wfmt1)
+        em(ist,jst)=em(ist,jst)+zfmtinp(nrc,nrci,wr2cmt(:,is),wfmt2(:,ist), &
+         wfmt1)
       end do
     end do
 ! end loops over atoms and species
@@ -122,11 +123,11 @@ do jst=1,nstfv
 ! store as wavefunction with G+p+q index
   do igp=1,ngpq
     ifg=igfft(igpqig(igp))
-    x(igp)=zfir(ifg)
+    z(igp)=zfir(ifg)
   end do
 ! add to the first-variational matrix elements
   do ist=1,nstfv
-    em(ist,jst)=em(ist,jst)+zdotc(ngpq,evecfv2(:,ist),1,x,1)
+    em(ist,jst)=em(ist,jst)+zdotc(ngpq,evecfv2(:,ist),1,z,1)
   end do
 end do
 !-------------------------------------------!
@@ -160,6 +161,6 @@ deallocate(igpig,igpqig,vgpl,vgpc,gpc)
 deallocate(vgpql,vgpqc,gpqc,sfacgp,sfacgpq)
 deallocate(apwalm1,apwalm2,evecfv1,evecfv2)
 if (tevecsv) deallocate(evecsv1,evecsv2)
-deallocate(wfmt1,wfmt2,zfir,x,em)
+deallocate(wfmt1,wfmt2,zfir,z,em)
 end subroutine
 
