@@ -22,11 +22,7 @@ complex(8) z1
 ! automatic arrays
 complex(8) ylm(lmmaxo),zfmt(npcmtmax)
 do ig=1,ngp
-  do l=0,lmaxo
-    z1=fourpi*zil(mod(l,4))
-    lma=l**2+1; lmb=lma+2*l
-    ylm(lma:lmb)=z1*conjg(ylmgp(lma:lmb,ig))
-  end do
+  ylm(1:lmmaxo)=conjg(ylmgp(1:lmmaxo,ig))
   do is=1,nspecies
     nrc=nrcmt(is)
     nrci=nrcmti(is)
