@@ -18,20 +18,20 @@ do ik=1,nkptnr
   vkql(1:3,ik)=vkl(1:3,ik)+vql(1:3,iq)
   vkqc(1:3,ik)=vkc(1:3,ik)+vqc(1:3,iq)
   do jspn=1,nspnfv
-    vl(:)=vkql(:,ik)
-    vc(:)=vkqc(:,ik)
+    vl(1:3)=vkql(1:3,ik)
+    vc(1:3)=vkqc(1:3,ik)
 ! spin-spiral case
     if (spinsprl) then
       if (jspn == 1) then
-        vl(:)=vl(:)+0.5d0*vqlss(:)
-        vc(:)=vc(:)+0.5d0*vqcss(:)
+        vl(1:3)=vl(1:3)+0.5d0*vqlss(1:3)
+        vc(1:3)=vc(1:3)+0.5d0*vqcss(1:3)
       else
-        vl(:)=vl(:)-0.5d0*vqlss(:)
-        vc(:)=vc(:)-0.5d0*vqcss(:)
+        vl(1:3)=vl(1:3)-0.5d0*vqlss(1:3)
+        vc(1:3)=vc(1:3)-0.5d0*vqcss(1:3)
       end if
     end if
 ! generate the G+k+q-vectors
-    call gengkvec(ngvec,ivg,vgc,vl,vc,gkmax,ngkmax,ngkq(jspn,ik), &
+    call gengkvec(ngvc,ivg,vgc,vl,vc,gkmax,ngkmax,ngkq(jspn,ik), &
      igkqig(:,jspn,ik),vgkql(:,:,jspn,ik),vgkqc(:,:,jspn,ik),gkqc(:,jspn,ik))
 ! generate structure factors for the G+k+q-vectors
     call gensfacgp(ngkq(jspn,ik),vgkqc(:,:,jspn,ik),ngkmax,sfacgkq(:,:,jspn,ik))
