@@ -53,14 +53,12 @@ do ig=1,ngv
 ! index to G-vector
     igkig(ngk)=ig
 ! G+k-vector in lattice coordinates
-    vgkl(:,ngk)=dble(ivg(:,ig))+vkl(:)
+    vgkl(1:3,ngk)=dble(ivg(1:3,ig))+vkl(1:3)
 ! G+k-vector in Cartesian coordinates
-    vgkc(1,ngk)=v1
-    vgkc(2,ngk)=v2
-    vgkc(3,ngk)=v3
+    vgkc(1,ngk)=v1; vgkc(2,ngk)=v2; vgkc(3,ngk)=v3
 ! length of G+k-vector
     gkc(ngk)=sqrt(t1)
-    if (ngk == ngkmax) exit
+    if (ngk == ngkmax) return
   end if
 end do
 end subroutine
