@@ -10,15 +10,13 @@ implicit none
 ! arguments
 integer, intent(in) :: iq
 ! local variables
-integer is,ig
-do ig=1,ngtot
+integer ig
+do ig=1,ngvec
 ! G+q-vector in Cartesian coordinates
   vgqc(1:3,ig)=vgc(1:3,ig)+vqc(1:3,iq)
 ! G+q-vector length
   gqc(ig)=sqrt(vgqc(1,ig)**2+vgqc(2,ig)**2+vgqc(3,ig)**2)
-end do
 ! spherical harmonics for G+q-vectors
-do ig=1,ngvec
   call genylmv(.true.,lmaxo,vgqc(:,ig),ylmgq(:,ig))
 end do
 ! compute the spherical Bessel functions j_l(|G+q|R_mt)
@@ -26,8 +24,6 @@ call genjlgprmt(lnpsd,ngvec,gqc,ngvec,jlgqrmt)
 ! structure factors for G+q
 call gensfacgp(ngvec,vgqc,ngvec,sfacgq)
 ! generate the smooth step function form factors for G+q
-do is=1,nspecies
-  call genffacgp(is,gqc,ffacgq(:,is))
-end do
+call genffacgp(ngvec,gqc,ngvec,ffacgq)
 end subroutine
 
