@@ -14,9 +14,7 @@ real(8) gk2
 gk2=2.d0*gkmax+epslat
 ngdgc(1:3)=int(gk2*sqrt(avec(1,1:3)**2+avec(2,1:3)**2+avec(3,1:3)**2)/pi)+1
 ! find next largest FFT-compatible grid size
-call nfftifc(npfftgc,ngdgc(1))
-call nfftifc(npfftgc,ngdgc(2))
-call nfftifc(npfftgc,ngdgc(3))
+call nfftifc(npfftgc,3,ngdgc)
 ! total number of points in coarse grid
 ngtc=ngdgc(1)*ngdgc(2)*ngdgc(3)
 ! find the number of vectors with |G| < 2 gkmax
