@@ -11,9 +11,11 @@ implicit none
 integer is,ias
 integer nr,nri,iro
 integer np,i0,i1
-! automatic arrays
-real(8) rfmt(npmtmax)
-complex(8) zrhomt(npmtmax),zvclmt(npmtmax)
+! allocatable arrays
+real(8), allocatable :: rfmt(:)
+complex(8), allocatable :: zrhomt(:),zvclmt(:)
+! allocate local arrays
+allocate(rfmt(npmtmax),zrhomt(npmtmax),zvclmt(npmtmax))
 ! allocate global array
 if (allocated(gvnsmt)) deallocate(gvnsmt)
 allocate(gvnsmt(npmtmax,3,natmtot))
@@ -41,5 +43,6 @@ do ias=1,natmtot
   call gradzfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),zvclmt,npmtmax, &
    gvnsmt(:,:,ias))
 end do
+deallocate(rfmt,zrhomt,zvclmt)
 end subroutine
 
