@@ -11,7 +11,7 @@ implicit none
 complex(8), intent(in) :: evecsv(nstsv,nstsv),pmat(nstsv,nstsv,3)
 complex(8), intent(inout) :: h(nstsv,nstsv)
 ! local variables
-integer i,j,l
+integer jst,i,j,l
 real(8) ca,v(3)
 complex(8) zm(2,2)
 ! allocatable arrays
@@ -35,6 +35,22 @@ do l=1,3
     end do
   end do
 end do
+! add effective magnetic field to Hamiltonian if required (E. Harris-Lee)
+if (tbaspat) then
+  call r3mtv(afspt(:,:,itimes),afieldt(:,itimes),v)
+  v(:)=(ca**2)*v(:)
+  zm(1,1)=v(3)
+  zm(1,2)=cmplx(v(1),-v(2),8)
+  zm(2,1)=cmplx(v(1),v(2),8)
+  zm(2,2)=-v(3)
+  do j=1,2
+    do i=1,2
+      do jst=1,nstsv
+        h(1:jst,jst)=h(1:jst,jst)+zm(i,j)*smat(1:jst,jst,i,j)
+      end do
+    end do
+  end do
+end if
 deallocate(smat)
 end subroutine
 
