@@ -34,7 +34,7 @@ end do
 nvbse=nvbse0+nvxbse
 ! number of conduction states for transitions
 ncbse=ncbse0+ncxbse
-if ((nvbse <= 0).or.(ncbse <= 0)) then
+if ((nvbse < 1).or.(ncbse < 1)) then
   write(*,*)
   write(*,'("Error(genidxbse): invalid number of valence or conduction &
    &transition states : ",2I8)') nvbse,ncbse
