@@ -31,13 +31,12 @@ do ias=1,natmtot
     l=lorbl(ilo,is)
     do m=-l,l
       i=i+1
-      lm=idxlm(l,m)
+      lm=l*(l+1)+m+1
       idxlo(lm,ilo,ias)=i
     end do
   end do
 end do
 nlotot=i
-return
 end subroutine
 !EOC
 
