@@ -22,7 +22,7 @@ do i=1,3
 end do
 jrir(1:ngtc,1:3)=0.d0
 ! current density cannot be computed if wavefunctions do not exist
-if (iscl <= 0) return
+if (iscl < 1) return
 ! initialise the OpenMP locks
 do ias=1,natmtot
   call omp_init_lock(lock(ias))
