@@ -28,7 +28,7 @@ if (tafieldt) then
 ! interstitial part
   do l=1,3
     t1=ca*afieldt(l,itimes)
-    jrir(:,l)=jrir(:,l)+t1*(rhoir(:)-rhosir(:,l))
+    jrir(1:ngtot,l)=jrir(1:ngtot,l)+t1*(rhoir(1:ngtot)-rhosir(1:ngtot,l))
   end do
 end if
 end subroutine
