@@ -16,6 +16,6 @@ do i=1,3
   jtot(i)=rfint(jrmt(:,:,i),jrir(:,i))
 end do
 ! total current magnitude
-jtotm=sqrt(jtot(1)**2+jtot(2)**2+jtot(3)**2)
+jtotm=norm2(jtot(1:3))
 end subroutine
 
