@@ -27,7 +27,7 @@ allocate(a(lmmax,lmmax),b(lmmax,lmmax))
 allocate(h(lmmax,lmmax))
 lwork=2*lmmax
 allocate(work(lwork))
-! construct (l,m) rotation matrix for each lattice symmetry
+! construct Yₗₘ rotation matrix for each lattice symmetry
 a(:,:)=0.d0
 do i=1,lmmax
   a(i,i)=1.d0
@@ -37,16 +37,15 @@ do isym=1,nsymlat
 end do
 ! set up pseudorandom symmetric matrix H
 h(:,:)=0.d0
-p=1
+p=0
 do l=0,lmax
-  n=2*l+1
+  n=2*l
   lm=l**2+1
-  do i=lm,lm+n-1
-    do j=i,lm+n-1
-! Park and Miller linear congruential generator
-      p=mod(p*171,30269)
-      h(i,j)=mod(p,lmmax)
-      h(j,i)=h(i,j)
+  do i=lm,lm+n
+    do j=i,lm+n
+      p=p+1
+      h(i,j)=p
+      h(j,i)=p
     end do
   end do
 end do
