@@ -32,22 +32,21 @@ integer i0,i1,nn,l,info
 integer ilo,jlo,io,jo
 real(8) e,t1
 ! automatic arrays
-logical done(natmmax)
 integer ipiv(nplorb)
 real(8) vr(nrmtmax),fr(nrmtmax)
 real(8) p0(nrmtmax,lorbordmax),p1(nrmtmax)
 real(8) q0(nrmtmax),q1(nrmtmax),ep0(nrmtmax,lorbordmax)
 real(8) p0c(nrmtmax,nlomax),ep0c(nrmtmax,nlomax)
-real(8) xa(nplorb),ya(nplorb),a(nplorb,nplorb),b(nplorb)
+real(8) ya(nplorb),a(nplorb,nplorb),b(nplorb)
 ! external functions
 real(8), external :: polynm
 do is=1,nspecies
   nr=nrmt(is)
   nri=nrmti(is)
   iro=nri+1
-  done(:)=.false.
   do ia=1,natoms(is)
-    if (done(ia)) cycle
+! perform calculation for only the first equivalent atom
+    if (.not.tfeqat(ia,is)) cycle
     ias=idxas(ia,is)
 ! use spherical part of potential
     i1=lmmaxi*(nri-1)+1
@@ -59,7 +58,7 @@ do is=1,nspecies
       l=lorbl(ilo,is)
       do jo=1,lorbord(ilo,is)
 ! linearisation energy accounting for energy derivative
-        e=lorbe(jo,ilo,ias)+dble(lorbdm(jo,ilo,is))*deapwlo
+        e=lorbe(jo,ilo,ias)+dble(lorbdm(jo,ilo,is))*delorb
 ! integrate the radial Schrodinger equation
         call rschrodint(solsc,l,e,nr,rlmt(:,1,is),vr,nn,p0(:,jo),p1,q0,q1)
         ep0(1:nr,jo)=e*p0(1:nr,jo)
@@ -72,16 +71,18 @@ do is=1,nspecies
 ! set up the matrix of radial derivatives
         do i=1,nplorb
           ir=nr-nplorb+i
-          xa(i)=rlmt(ir,1,is)
           ya(i)=p0(ir,jo)*rlmt(ir,-1,is)
         end do
-        do io=1,lorbord(ilo,is)
-          a(io,jo)=polynm(io-1,nplorb,xa,ya,rmt(is))
+        a(1,jo)=ya(nplorb)
+        ir=nr-nplorb+1
+        do io=2,lorbord(ilo,is)
+          a(io,jo)=polynm(io-1,nplorb,rlmt(ir,1,is),ya,rmt(is))
         end do
       end do
 ! set up the target vector
       b(1:nplorb)=0.d0
       b(lorbord(ilo,is))=1.d0
+! solve the linear system
       call dgesv(lorbord(ilo,is),1,a,nplorb,ipiv,b,nplorb,info)
       if (info /= 0) goto 10
 ! generate linear combination of radial functions
@@ -108,12 +109,14 @@ do is=1,nspecies
         end if
       end do
 ! normalise radial functions again
-      fr(1:nr)=p0c(1:nr,ilo)**2
-      t1=abs(dot_product(wrmt(1:nr,is),fr(1:nr)))
-      if (t1 < 1.d-25) goto 10
-      t1=1.d0/sqrt(t1)
-      p0c(1:nr,ilo)=t1*p0c(1:nr,ilo)
-      ep0c(1:nr,ilo)=t1*ep0c(1:nr,ilo)
+      if (ilo > 1) then
+        fr(1:nr)=p0c(1:nr,ilo)**2
+        t1=abs(dot_product(wrmt(1:nr,is),fr(1:nr)))
+        if (t1 < 1.d-25) goto 10
+        t1=1.d0/sqrt(t1)
+        p0c(1:nr,ilo)=t1*p0c(1:nr,ilo)
+        ep0c(1:nr,ilo)=t1*ep0c(1:nr,ilo)
+      end if
 ! divide by r and store in global array
       do ir=1,nr
         t1=rlmt(ir,-1,is)
@@ -121,15 +124,13 @@ do is=1,nspecies
         lofr(ir,2,ilo,ias)=t1*ep0c(ir,ilo)
       end do
     end do
-    done(ia)=.true.
 ! copy to equivalent atoms
     do ja=1,natoms(is)
-      if ((.not.done(ja)).and.(eqatoms(ia,ja,is))) then
+      if (eqatoms(ia,ja,is).and.(ia /= ja)) then
         jas=idxas(ja,is)
         do ilo=1,nlorb(is)
           lofr(1:nr,1:2,ilo,jas)=lofr(1:nr,1:2,ilo,ias)
         end do
-        done(ja)=.true.
       end if
     end do
 ! end loop over atoms and species
