@@ -3,21 +3,22 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-pure subroutine genmcph(w,ev,a)
+pure subroutine genmcph(wq,ev,a)
 use modmain
 use modphonon
 implicit none
 ! arguments
-real(8), intent(in) :: w(nbph)
+real(8), intent(in) :: wq(nbph)
 complex(8), intent(in) :: ev(nbph,nbph)
 complex(8), intent(out) :: a(nbph,nbph)
 ! local variables
 integer is,ia,ip,i,j
 real(8) t1
+! generate the matrix for converting between Cartesian and phonon coordinates
 do j=1,nbph
   i=0
   do is=1,nspecies
-    t1=2.d0*spmass(is)*w(j)
+    t1=2.d0*spmass(is)*wq(j)
     if (t1 > 1.d-8) then
       t1=1.d0/sqrt(t1)
     else
