@@ -6,7 +6,7 @@
 !BOP
 ! !ROUTINE: gensdmat
 ! !INTERFACE:
-subroutine gensdmat(evecsv,sdmat)
+pure subroutine gensdmat(evecsv,sdmat)
 ! !USES:
 use modmain
 ! !INPUT/OUTPUT PARAMETERS:
@@ -38,7 +38,6 @@ do j=1,nstsv
     end do
   end do
 end do
-return
 end subroutine
 !EOC
 
