@@ -55,7 +55,7 @@ end do
 ! rotate the spherical covering set if required
 if (trotsht) then
   do itp=1,lmmaxi
-    v(:)=vtp(:,itp)
+    v(1:3)=vtp(1:3,itp)
     call r3mv(rotsht,v,vtp(:,itp))
   end do
 end if
@@ -68,14 +68,14 @@ do itp=1,lmmaxi
 end do
 ! find the forward SHT arrays
 ! real
-rfshti(:,:)=rbshti(:,:)
+rfshti(1:lmmaxi,1:lmmaxi)=rbshti(1:lmmaxi,1:lmmaxi)
 call rminv(lmmaxi,rfshti)
 ! complex
-zfshti(:,:)=zbshti(:,:)
+zfshti(1:lmmaxi,1:lmmaxi)=zbshti(1:lmmaxi,1:lmmaxi)
 call zminv(lmmaxi,zfshti)
 ! make single-precision complex copies
-cbshti(:,:)=zbshti(:,:)
-cfshti(:,:)=zfshti(:,:)
+cbshti(1:lmmaxi,1:lmmaxi)=zbshti(1:lmmaxi,1:lmmaxi)
+cfshti(1:lmmaxi,1:lmmaxi)=zfshti(1:lmmaxi,1:lmmaxi)
 !--------------------------------!
 !     SHT matrices for lmaxo     !
 !--------------------------------!
@@ -103,7 +103,7 @@ end do
 ! rotate the spherical covering set if required
 if (trotsht) then
   do itp=1,lmmaxo
-    v(:)=vtp(:,itp)
+    v(1:3)=vtp(1:3,itp)
     call r3mv(rotsht,v,vtp(:,itp))
   end do
 end if
@@ -116,14 +116,31 @@ do itp=1,lmmaxo
 end do
 ! find the forward SHT arrays
 ! real
-rfshto(:,:)=rbshto(:,:)
+rfshto(1:lmmaxo,1:lmmaxo)=rbshto(1:lmmaxo,1:lmmaxo)
 call rminv(lmmaxo,rfshto)
 ! complex
-zfshto(:,:)=zbshto(:,:)
+zfshto(1:lmmaxo,1:lmmaxo)=zbshto(1:lmmaxo,1:lmmaxo)
 call zminv(lmmaxo,zfshto)
 ! make single-precision complex copies
-cbshto(:,:)=zbshto(:,:)
-cfshto(:,:)=zfshto(:,:)
+cbshto(1:lmmaxo,1:lmmaxo)=zbshto(1:lmmaxo,1:lmmaxo)
+cfshto(1:lmmaxo,1:lmmaxo)=zfshto(1:lmmaxo,1:lmmaxo)
+return
+
+contains
+
+pure subroutine sctovec(tp,v)
+implicit none
+! arguments
+real(8), intent(in) :: tp(2)
+real(8), intent(out) :: v(3)
+! local variables
+real(8) t1
+t1=sin(tp(1))
+v(1)=t1*cos(tp(2))
+v(2)=t1*sin(tp(2))
+v(3)=cos(tp(1))
+end subroutine
+
 end subroutine
 !EOC
 
