@@ -10,16 +10,16 @@ implicit none
 complex(8), intent(in) :: evecsv(nstsv,nstsv)
 complex(8), intent(out) :: smat(nstsv,nstsv,2,2)
 ! local variables
-integer ist,jst,n
+integer ist,jst,i
 ! external functions
 complex(8), external :: zdotc
-n=nstfv+1
+i=nstfv+1
 do jst=1,nstsv
   do ist=1,jst
     smat(ist,jst,1,1)=zdotc(nstfv,evecsv(1,ist),1,evecsv(1,jst),1)
-    smat(ist,jst,2,1)=zdotc(nstfv,evecsv(n,ist),1,evecsv(1,jst),1)
-    smat(ist,jst,1,2)=zdotc(nstfv,evecsv(1,ist),1,evecsv(n,jst),1)
-    smat(ist,jst,2,2)=zdotc(nstfv,evecsv(n,ist),1,evecsv(n,jst),1)
+    smat(ist,jst,2,1)=zdotc(nstfv,evecsv(i,ist),1,evecsv(1,jst),1)
+    smat(ist,jst,1,2)=zdotc(nstfv,evecsv(1,ist),1,evecsv(i,jst),1)
+    smat(ist,jst,2,2)=zdotc(nstfv,evecsv(i,ist),1,evecsv(i,jst),1)
   end do
 end do
 ! set the lower triangular parts
