@@ -20,9 +20,9 @@ character(64) symb,name
 ! allocatable arrays
 real(8), allocatable :: r(:),rho(:),vr(:),rwf(:,:,:)
 read(fnum,*,err=20) nz
-if (nz <= 0) then
+if (nz < 1) then
   write(*,*)
-  write(*,'("Error(genspecies): atomic number negative : ",I8)') nz
+  write(*,'("Error(genspecies): nz < 1 : ",I8)') nz
   write(*,*)
   stop
 end if
@@ -32,7 +32,7 @@ read(fnum,*,err=20) mass
 mass=mass*amu
 read(fnum,*,err=20) rm
 read(fnum,*,err=20) nst
-if ((nst <= 0).or.(nst > maxstsp)) then
+if ((nst < 1).or.(nst > maxstsp)) then
   write(*,*)
   write(*,'("Error(genspecies): nst out of range : ",I8)') nst
   write(*,'(" for species ",A)') trim(name)
