@@ -16,20 +16,21 @@ complex(8) z1
 real(8), allocatable :: fxcmt(:,:,:,:),fxcir(:,:,:)
 complex(8), allocatable :: fxcg(:)
 allocate(fxcmt(npmtmax,natmtot,4,4),fxcir(ngtot,4,4))
-allocate(fxcg(ngtot))
+allocate(fxcg(ngvec))
 ! generate the kernel f_xc in real-space
 call genspfxcr(.true.,fxcmt,fxcir)
 ! Fourier transform the kernel to G-space
 do i=1,4
   do j=i,4
-    call zftrf(ngtot,ivg,vgc,fxcmt(:,:,i,j),fxcir(:,i,j),fxcg)
+    call zftrf(ngvec,ivg,vgc,fxcmt(:,:,i,j),fxcir(:,i,j),fxcg)
     do ig=1,ngrf
       do jg=1,ngrf
-        iv(:)=ivg(:,ig)-ivg(:,jg)
+        iv(1:3)=ivg(1:3,ig)-ivg(1:3,jg)
         if ((iv(1) >= intgv(1,1)).and.(iv(1) <= intgv(2,1)).and. &
             (iv(2) >= intgv(1,2)).and.(iv(2) <= intgv(2,2)).and. &
             (iv(3) >= intgv(1,3)).and.(iv(3) <= intgv(2,3))) then
           kg=ivgig(iv(1),iv(2),iv(3))
+          if (kg > ngvec) cycle
           z1=fxcg(kg)
           fxc(ig,i,jg,j)=z1
           fxc(jg,j,ig,i)=conjg(z1)
