@@ -8,8 +8,7 @@ use modmain
 use modmpi
 implicit none
 ! local variables
-integer i
-real(8) et0,t1
+real(8) et0
 ! store original parameters
 avec0(:,:)=avec(:,:)
 tforce0=tforce
@@ -43,14 +42,10 @@ do istrain=1,nstrain
   stress(istrain)=(engytot-et0)/deltast
 end do
 10 continue
-istrain=0
 ! compute the maximum stress magnitude over all lattice vectors
-stressmax=0.d0
-do i=1,nstrain
-  t1=abs(stress(i))
-  if (t1 > stressmax) stressmax=t1
-end do
+stressmax=maxval(abs(stress(1:nstrain)))
 ! restore original parameters
+istrain=0
 avec(:,:)=avec0(:,:)
 tforce=tforce0
 end subroutine
