@@ -11,11 +11,13 @@ implicit none
 ! local variables
 integer ik,ispn,is,ias
 integer np,npi,npc,n,nthd
+! automatic arrays
+integer(omp_lock_kind) lock(natmtot)
 ! allocatable arrays
 real(8), allocatable :: rfmt(:,:),rfir(:)
 real(8), allocatable :: rvfmt(:,:,:),rvfir(:,:)
 ! tau cannot be computed if wavefunctions do not exist
-if (iscl <= 0) then
+if (iscl < 1) then
   taumt(:,:,:)=0.d0
   tauir(:,:)=0.d0
   return
@@ -28,6 +30,10 @@ do ispn=1,nspinor
   end do
 end do
 tauir(1:ngtc,1:nspinor)=0.d0
+! initialise the OpenMP locks
+do ias=1,natmtot
+  call omp_init_lock(lock(ias))
+end do
 call holdthd(nkpt/np_mpi,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP SCHEDULE(DYNAMIC) &
@@ -35,10 +41,14 @@ call holdthd(nkpt/np_mpi,nthd)
 do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi) /= lp_mpi) cycle
-  call gentauk(ik)
+  call gentauk(ik,lock)
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
+! destroy the OpenMP locks
+do ias=1,natmtot
+  call omp_destroy_lock(lock(ias))
+end do
 ! convert taumt to spherical harmonics
 do ispn=1,nspinor
   do ias=1,natmtot
