@@ -14,7 +14,7 @@ integer nr,nri,np,i,m
 ! allocatable arrays
 complex(4), allocatable :: wfcr(:,:)
 complex(8), allocatable :: zfmt(:),gzfmt(:,:)
-taucr(:,:,:)=0.d0
+taucr(1:npmtmax,1:natmtot,1:nspinor)=0.d0
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(wfcr,zfmt,gzfmt) &
@@ -22,7 +22,7 @@ call holdthd(natmtot,nthd)
 !$OMP PRIVATE(ist,m,ispn,jspn,i) &
 !$OMP NUM_THREADS(nthd)
 allocate(wfcr(npmtmax,2),zfmt(npmtmax),gzfmt(npmtmax,3))
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do ias=1,natmtot
   is=idxis(ias)
   ia=idxia(ias)
