@@ -9,7 +9,7 @@ use modtddft
 implicit none
 ! local variables
 integer its
-if (tstime.lt.dtimes) then
+if (tstime < dtimes) then
   write(*,*)
   write(*,'("Error(gentimes): tstime < dtimes : ",2G18.10)') tstime,dtimes
   write(*,*)
