@@ -11,8 +11,8 @@ implicit none
 ! arguments
 ! the potential and field are multiplied by the radial integration weights in
 ! the muffin-tin and by the characteristic function in the interstitial region
-real(8), intent(in) :: vmt(npcmtmax,natmtot),vir(ngtot)
-real(8), intent(in) :: bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag)
+real(8), intent(in) :: vmt(npcmtmax,natmtot),vir(ngtc)
+real(8), intent(in) :: bmt(npcmtmax,natmtot,ndmag),bir(ngtc,ndmag)
 integer, intent(in) :: ngp(nspnfv),igpig(ngkmax,nspnfv)
 complex(4), intent(in) :: wfmt(npcmtmax,natmtot,nspinor,nstsv)
 integer, intent(in) :: ld
@@ -25,7 +25,7 @@ integer npc,npc2,ipco
 integer n,igp,nthd
 ! automatic arrays
 complex(4) wfmt1(npcmtmax,2),wfmt2(npcmtmax,2)
-complex(4) wfir1(ngtot,nspinor),wfir2(ngtot,nspinor),c(ngkmax)
+complex(4) wfir1(ngtc,nspinor),wfir2(ngtc,nspinor),c(ngkmax)
 ! external functions
 real(4), external :: sdot
 complex(4), external :: cdotc
@@ -36,23 +36,23 @@ end do
 call holdthd(nstsv,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(wfmt1,wfmt2,wfir1,wfir2,c) &
-!$OMP PRIVATE(ias,is,nrc,nrci,nrco) &
-!$OMP PRIVATE(npc,npc2,ipco,ist,jst) &
-!$OMP PRIVATE(ispn,jspn,igp,n) &
+!$OMP PRIVATE(ist,jst,ias,is,nrc) &
+!$OMP PRIVATE(nrci,nrco,npc,npc2) &
+!$OMP PRIVATE(ipco,ispn,jspn,igp,n) &
 !$OMP NUM_THREADS(nthd)
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
-do ias=1,natmtot
-  is=idxis(ias)
-  nrc=nrcmt(is)
-  nrci=nrcmti(is)
-  nrco=nrc-nrci
-  npc=npcmt(is)
-  npc2=npc*2
-  ipco=npcmti(is)+1
-!$OMP DO
-  do jst=1,nstsv
+!$OMP DO SCHEDULE(DYNAMIC)
+do jst=1,nstsv
+  do ias=1,natmtot
+    is=idxis(ias)
+    nrc=nrcmt(is)
+    nrci=nrcmti(is)
+    nrco=nrc-nrci
+    npc=npcmt(is)
+    npc2=npc*2
+    ipco=npcmti(is)+1
 ! apply local potential and magnetic field to spinor wavefunction
     if (ncmag) then
 ! non-collinear case
@@ -69,8 +69,8 @@ do ias=1,natmtot
 ! multiply wavefunction by radial integration weights
         wfmt2(1:npc,1)=wfmt(1:npc,ias,1,jst)
         wfmt2(1:npc,2)=wfmt(1:npc,ias,2,jst)
-        call cfcmtwr(nrc,nrci,wrcmt(:,is),wfmt2(1,1))
-        call cfcmtwr(nrc,nrci,wrcmt(:,is),wfmt2(1,2))
+        call cfcmtwr(nrc,nrci,wr2cmt(:,is),wfmt2(1,1))
+        call cfcmtwr(nrc,nrci,wr2cmt(:,is),wfmt2(1,2))
         call cgemm('N','N',lmmaxi,nrci,lmmaxi,cone,vmatmti(1,1,1,1,ias), &
          lmmaxi,wfmt2(1,1),lmmaxi,cone,wfmt1(1,1),lmmaxi)
         call cgemm('N','N',lmmaxo,nrco,lmmaxo,cone,vmatmto(1,1,1,1,ias), &
@@ -101,38 +101,37 @@ do ias=1,natmtot
      +sdot(npc2,wfmt(1,ias,1,jst),1,wfmt1(1,1),1) &
      +sdot(npc2,wfmt(1,ias,2,jst),1,wfmt1(1,2),1)
   end do
-!$OMP END DO
 end do
+!$OMP END DO
 !---------------------------!
 !     interstitial part     !
 !---------------------------!
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do jst=1,nstsv
 ! Fourier transform wavefunction to real-space
   do ispn=1,nspinor
     jspn=jspnfv(ispn)
-    wfir1(:,ispn)=0.e0
+    wfir1(1:ngtc,ispn)=0.e0
     do igp=1,ngp(jspn)
-      wfir1(igfft(igpig(igp,jspn)),ispn)=wfgp(igp,ispn,jst)
+      wfir1(igfc(igpig(igp,jspn)),ispn)=wfgp(igp,ispn,jst)
     end do
-    call cfftifc(3,ngridg,1,wfir1(:,ispn))
+    call cfftifc(3,ngdgc,1,wfir1(:,ispn))
   end do
 ! apply local potential and magnetic field to spinor wavefunction
   if (ncmag) then
 ! non-collinear case
-    call vbmk1(ngtot,vir,bir,bir(:,2),bir(:,3),wfir1,wfir1(:,2),wfir2, &
-     wfir2(:,2))
+    call vbmk1(ngtc,vir,bir,bir(:,2),bir(:,3),wfir1,wfir1(:,2),wfir2,wfir2(:,2))
   else
 ! collinear case
-    call vbmk2(ngtot,vir,bir,wfir1,wfir1(:,2),wfir2,wfir2(:,2))
+    call vbmk2(ngtc,vir,bir,wfir1,wfir1(:,2),wfir2,wfir2(:,2))
   end if
   do ispn=1,nspinor
     jspn=jspnfv(ispn)
     n=ngp(jspn)
 ! Fourier transform to G+p-space
-    call cfftifc(3,ngridg,-1,wfir2(:,ispn))
+    call cfftifc(3,ngdgc,-1,wfir2(:,ispn))
     do igp=1,n
-      c(igp)=wfir2(igfft(igpig(igp,jspn)),ispn)
+      c(igp)=wfir2(igfc(igpig(igp,jspn)),ispn)
     end do
     do ist=1,jst-1
       vbmat(ist,jst)=vbmat(ist,jst)+cdotc(n,wfgp(1,ispn,ist),1,c,1)
