@@ -60,17 +60,17 @@ call genwfsv_sp(.false.,.false.,nstsv,[0],ngdgc,igfc,ngk(1,ikp),igkig(:,1,ikp),&
 ! start loop over reduced k-point set
 do ik=1,nkpt
 ! determine the q-vector
-  iv(:)=ivk(:,ik)-ivk(:,ikp)
-  iv(:)=modulo(iv(:),ngridk(:))
+  iv(1:3)=ivk(1:3,ik)-ivk(1:3,ikp)
+  iv(1:3)=modulo(iv(1:3),ngridk(1:3))
 ! check if the q-point is in user-defined set
-  iv(:)=iv(:)*ngridq(:)
-  if (any(mod(iv(:),ngridk(:)) /= 0)) cycle
-  iv(:)=iv(:)/ngridk(:)
+  iv(1:3)=iv(1:3)*ngridq(1:3)
+  if (any(mod(iv(1:3),ngridk(1:3)) /= 0)) cycle
+  iv(1:3)=iv(1:3)/ngridk(1:3)
   iq=ivqiq(iv(1),iv(2),iv(3))
-  vc(:)=vkc(:,ik)-vkc(:,ikp)
+  vc(1:3)=vkc(1:3,ik)-vkc(1:3,ikp)
   do ig=1,ngvc
 ! determine the G+q-vectors
-    vgqc(:,ig)=vgc(:,ig)+vc(:)
+    vgqc(1:3,ig)=vgc(1:3,ig)+vc(1:3)
 ! G+q-vector length
     gqc(ig)=sqrt(vgqc(1,ig)**2+vgqc(2,ig)**2+vgqc(3,ig)**2)
 ! spherical harmonics for G+q-vectors
@@ -102,7 +102,7 @@ do ik=1,nkpt
       call gencvclmt(nrcmt,nrcmti,nrcmtmax,rlcmt,wprcmt,npcmtmax,crhomt,cvclmt)
       call cpotcoul(nrcmt,nrcmti,npcmt,nrcmtmax,rlcmt,ngdgc,igfc,ngvc,gqc, &
        gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,crhoir,npcmtmax,cvclmt,cvclir)
-      cvclir(:)=cvclir(:)*cfrc(:)
+      cvclir(1:ngtc)=cvclir(1:ngtc)*cfrc(1:ngtc)
       z1=zcfinp(crhomt,crhoir,cvclmt,cvclir)
       vcl1221(ist1,ist2,ik)=wqptnr*dble(z1)
 ! end loop over ist2
