@@ -16,31 +16,31 @@ complex(8), intent(out) :: vmat(nstsv,nstsv,nkpt)
 integer ik,ispn
 integer is,ias,nrc,nrci
 integer n,lp,nthd
+! automatic arrays
+real(8) vmtc(npcmtmax,natmtot),virc(ngtc)
 ! allocatable arrays
-real(8), allocatable :: vmt1(:,:),vir1(:)
 complex(8), allocatable :: apwalm(:,:,:,:,:),evecfv(:,:),evecsv(:,:)
 complex(4), allocatable :: wfmt(:,:,:,:),wfgk(:,:,:)
-! allocate local arrays
-allocate(vmt1(npcmtmax,natmtot),vir1(ngtot))
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(is,nrc,nrci) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
   nrc=nrcmt(is)
   nrci=nrcmti(is)
-! convert muffin-tin potential to a coarse radial mesg
-  call rfmtftoc(nrc,nrci,vmt(:,ias),vmt1(:,ias))
+! convert muffin-tin potential to a coarse radial mesh
+  call rfmtftoc(nrc,nrci,vmt(:,ias),vmtc(:,ias))
 ! convert potential to spherical coordinates
-  call rbshtip(nrc,nrci,vmt1(:,ias))
+  call rbshtip(nrc,nrci,vmtc(:,ias))
 ! multiply by the radial integration weights
-  call rfcmtwr(nrc,nrci,wrcmt(:,is),vmt1(:,ias))
+  call rfcmtwr(nrc,nrci,wr2cmt(:,is),vmtc(:,ias))
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
-! multiply interstitial potential by characteristic function
-vir1(:)=vir(:)*cfunir(:)
+! multiply by characteristic function and convert to coarse grid
+call rfirftoc(vir,virc)
 ! loop over k-points
 call holdthd(nkpt/np_mpi,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
@@ -50,7 +50,7 @@ call holdthd(nkpt/np_mpi,nthd)
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
 allocate(evecfv(nmatmax,nstfv),evecsv(nstsv,nstsv))
 allocate(wfmt(npcmtmax,natmtot,nspinor,nstsv),wfgk(ngkmax,nspinor,nstsv))
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi) /= lp_mpi) cycle
@@ -65,7 +65,7 @@ do ik=1,nkpt
 ! calculate the wavefunctions for all states of the input k-point
   call genwfsv_sp(.false.,.true.,nstsv,[0],ngridg,igfft,ngk(:,ik), &
    igkig(:,:,ik),apwalm,evecfv,evecsv,wfmt,ngkmax,wfgk)
-  call genvmatk(vmt1,vir1,ngk(:,ik),igkig(:,:,ik),wfmt,ngkmax,wfgk,vmat(:,:,ik))
+  call genvmatk(vmtc,virc,ngk(:,ik),igkig(:,:,ik),wfmt,ngkmax,wfgk,vmat(:,:,ik))
 end do
 !$OMP END DO
 deallocate(apwalm,evecfv,evecsv,wfmt,wfgk)
@@ -79,6 +79,5 @@ if (np_mpi > 1) then
     call mpi_bcast(vmat(:,:,ik),n,mpi_double_complex,lp,mpicom,ierror)
   end do
 end if
-deallocate(vmt1,vir1)
 end subroutine
 
