@@ -26,9 +26,9 @@ implicit none
 ! zero the non-local muffin-tin potential for each atom
 vmatmt(:,:,:,:,:)=0.d0
 ! add the DFT+U potential and calculate the corresponding energies
-if (dftu.ne.0) call vmatmtdu
+if (dftu /= 0) call vmatmtdu
 ! add the fixed tensor moment potential if required
-if (ftmtype.gt.0) call vmatmtftm
+if (ftmtype > 0) call vmatmtftm
 ! symmetrise the potential
 call symdmat(lmaxdm,lmmaxdm,vmatmt)
 end subroutine
