@@ -56,7 +56,7 @@ integer, intent(in) :: ld
 complex(8), intent(out) :: wfir(ld,nspinor,nst)
 ! local variables
 integer is,ias,ldmt,nthd
-if (nst <= 0) return
+if (nst < 1) return
 ! muffin-tin wavefunction
 ldmt=npcmtmax*natmtot
 call holdthd(natmtot,nthd)
