@@ -3,12 +3,12 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine genzvclmt(nr,nri,ld1,rl,wpr,ld2,zrhomt,zvclmt)
+subroutine genzvclmt(nrmt_,nrmti_,ld1,rl,wpr,ld2,zrhomt,zvclmt)
 use modmain
 use modomp
 implicit none
 ! arguments
-integer, intent(in) :: nr(nspecies),nri(nspecies)
+integer, intent(in) :: nrmt_(nspecies),nrmti_(nspecies)
 integer, intent(in) :: ld1
 real(8), intent(in) :: rl(ld1,-lmaxo-1:lmaxo+2,nspecies)
 real(8), intent(in) :: wpr(4,ld1,nspecies)
@@ -20,10 +20,11 @@ integer is,ias,nthd
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(is) &
-!$OMP NUM_THREADS(nthd) SCHEDULE(DYNAMIC)
+!$OMP SCHEDULE(DYNAMIC) &
+!$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
-  call zpotclmt(nr(is),nri(is),ld1,rl(:,:,is),wpr(:,:,is),zrhomt(:,ias), &
+  call zpotclmt(nrmt_(is),nrmti_(is),ld1,rl(:,:,is),wpr(:,:,is),zrhomt(:,ias), &
    zvclmt(:,ias))
 end do
 !$OMP END PARALLEL DO
