@@ -12,21 +12,14 @@ implicit none
 ! local variables
 integer istp,jstp,is,i
 real(8) ds
-! initialise global variables (and the muffin-tin radii)
+! initialise global variables
 call init0
 call init1
-! trim the Fourier components of the Kohn-Sham potential
-trimvg0=trimvg
-trimvg=.true.
 ! store orginal volume
 omega0=omega
 ! atomic forces are required
 tforce=.true.
-if (task == 3) then
-  trdstate=.true.
-else
-  trdstate=.false.
-end if
+trdstate=(task == 3)
 ! initial atomic step sizes
 if (allocated(tauatp)) deallocate(tauatp)
 allocate(tauatp(natmtot))
@@ -196,17 +189,15 @@ end if
 if (latvopt /= 0) call gndstate
 ! write optimised variables
 if (wrtvars) then
-  call writevars('avec (geomopt)',nv=9,rva=avec)
-  call writevars('omega (geomopt)',rv=omega)
+  call writevars('avec_opt',nv=9,rva=avec)
+  call writevars('omega_opt',rv=omega)
   do is=1,nspecies
-    call writevars('atposl (geomopt)',n1=is,nv=3*natoms(is),rva=atposl(:,:,is))
+    call writevars('atposl_opt',n1=is,nv=3*natoms(is),rva=atposl(:,:,is))
   end do
   do is=1,nspecies
-    call writevars('atposc (geomopt)',n1=is,nv=3*natoms(is),rva=atposc(:,:,is))
+    call writevars('atposc_opt',n1=is,nv=3*natoms(is),rva=atposc(:,:,is))
   end do
-  call writevars('engytot (geomopt)',rv=engytot)
+  call writevars('engytot_opt',rv=engytot)
 end if
-! restore original parameters
-trimvg=trimvg0
 end subroutine
 
