@@ -69,18 +69,18 @@ allocate(vgpl(3,ng),cf_(ng,ng,m),x(ng))
 ! perform translation operation and store in temporary array
 if (tv0symc(isym)) then
 ! translation vector is zero
-  cf_(:,:,:)=cf(:,:,:)
+  cf_(1:ng,1:ng,1:m)=cf(1:ng,1:ng,1:m)
 else
 ! non-zero translation vector gives a phase factor
-  v(:)=vtcsymc(:,isym)
+  v(1:3)=vtcsymc(1:3,isym)
   do igq=1,ng
-    t1=-(vgc(1,igq)*v(1)+vgc(2,igq)*v(2)+vgc(3,igq)*v(3))
-    x(igq)=cmplx(cos(t1),sin(t1),8)
+    t1=vgc(1,igq)*v(1)+vgc(2,igq)*v(2)+vgc(3,igq)*v(3)
+    x(igq)=cmplx(cos(t1),-sin(t1),8)
   end do
   do jgq=1,ng
     z1=conjg(x(jgq))
     do igq=1,ng
-      cf_(igq,jgq,:)=z1*x(igq)*cf(igq,jgq,:)
+      cf_(igq,jgq,1:m)=z1*x(igq)*cf(igq,jgq,1:m)
     end do
   end do
 end if
@@ -88,16 +88,16 @@ end if
 lspl=lsplsymc(isym)
 ! the inverse of the spatial symmetry
 ilspl=isymlat(lspl)
-si(:,:)=dble(symlat(:,:,ilspl))
+si(1:3,1:3)=dble(symlat(1:3,1:3,ilspl))
 ! find the map from {G+q} to {G+p}
-map(:)=0
+map(1:ng)=0
 do igp=1,ng
-  vgpl(:,igp)=dble(ivg(:,igp))+vpl(:)
+  vgpl(1:3,igp)=dble(ivg(1:3,igp))+vpl(1:3)
 end do
-done(:)=.false.
+done(1:ng)=.false.
 i=1
 do igq=1,ng
-  vgql(:)=dble(ivg(:,igq))+vql(:,iq)
+  vgql(1:3)=dble(ivg(1:3,igq))+vql(1:3,iq)
   call r3mtv(si,vgql,v)
   do igp=i,ng
     if (done(igp)) cycle
@@ -121,9 +121,9 @@ do jgp=1,ng
   do igp=1,ng
     igq=map(igp)
     if ((igq == 0).or.(jgq == 0)) then
-      cf(igp,jgp,:)=0.d0
+      cf(igp,jgp,1:m)=0.d0
     else
-      cf(igp,jgp,:)=cf_(igq,jgq,:)
+      cf(igp,jgp,1:m)=cf_(igq,jgq,1:m)
     end if
   end do
 end do
