@@ -21,7 +21,7 @@ read(332,rec=iq) vql_,nbph_,w,x,y
 close(332)
 !$OMP END CRITICAL(u332)
 t1=abs(vql(1,iq)-vql_(1))+abs(vql(2,iq)-vql_(2))+abs(vql(3,iq)-vql_(3))
-if (t1.gt.epslat) then
+if (t1 > epslat) then
   write(*,*)
   write(*,'("Error(getevecwxy): differing vectors for q-point ",I8)') iq
   write(*,'(" current     : ",3G18.10)') vql(:,iq)
@@ -29,7 +29,7 @@ if (t1.gt.epslat) then
   write(*,*)
   stop
 end if
-if (nbph.ne.nbph_) then
+if (nbph /= nbph_) then
   write(*,*)
   write(*,'("Error(getevecwxy): differing nbph for q-point ",I8)') iq
   write(*,'(" current     : ",I8)') nbph
