@@ -15,7 +15,7 @@ real(8), intent(out) :: occsvp(nstsv)
 integer isym,ik
 integer recl,nstsv_
 real(8) vkl_(3),t1
-if (ikp.gt.0) then
+if (ikp > 0) then
   ik=ikp
 else
 ! find the k-point number
@@ -29,7 +29,7 @@ read(208,rec=ik) vkl_,nstsv_,occsvp
 close(208)
 !$OMP END CRITICAL(u208)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
-if (t1.gt.epslat) then
+if (t1 > epslat) then
   write(*,*)
   write(*,'("Error(getoccsv): differing vectors for k-point ",I8)') ik
   write(*,'(" current   : ",3G18.10)') vkl(:,ik)
@@ -37,7 +37,7 @@ if (t1.gt.epslat) then
   write(*,*)
   stop
 end if
-if (nstsv.ne.nstsv_) then
+if (nstsv /= nstsv_) then
   write(*,*)
   write(*,'("Error(getoccsv): differing nstsv for k-point ",I8)') ik
   write(*,'(" current   : ",I8)') nstsv
