@@ -57,11 +57,7 @@ g3rho(:)=0.d0
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    if (ig <= ngvec) then
-      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
-    else
-      zfft2(ifg)=0.d0
-    end if
+    zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
   end do
   call rzfftifc(3,ngridg,1,rfir,zfft2)
   g3rho(:)=g3rho(:)+gvrho(:,i)*rfir(:)
