@@ -42,7 +42,7 @@ do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
     if (ig <= ngvc) then
-      zfft2(ifg)=vgc(i,ig)*cmplx(-aimag(zfft1(ifg)),dble(zfft1(ifg)),8)
+      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
     else
       zfft2(ifg)=0.d0
     end if
