@@ -42,7 +42,7 @@ rfir1(:)=0.d0
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    zfft2(ifg)=vgc(i,ig)*cmplx(-aimag(zfft1(ifg)),dble(zfft1(ifg)),8)
+    zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
   end do
   call rzfftifc(3,ngridg,1,rfir2,zfft2)
   rfir1(:)=rfir1(:)+rfir2(:)*gvup(:,i)
@@ -55,7 +55,7 @@ rfir1(:)=0.d0
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    zfft2(ifg)=vgc(i,ig)*cmplx(-aimag(zfft1(ifg)),dble(zfft1(ifg)),8)
+    zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
   end do
   call rzfftifc(3,ngridg,1,rfir2,zfft2)
   rfir1(:)=rfir1(:)+rfir2(:)*gvdn(:,i)
@@ -67,7 +67,7 @@ call rzfftifc(3,ngridg,-1,dxdgud,zfft1)
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    zfft2(ifg)=vgc(i,ig)*cmplx(-aimag(zfft1(ifg)),dble(zfft1(ifg)),8)
+    zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
   end do
   call rzfftifc(3,ngridg,1,rfir2,zfft2)
   vxup(:)=vxup(:)-rfir2(:)*gvdn(:,i)
@@ -83,7 +83,7 @@ rfir1(:)=0.d0
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    zfft2(ifg)=vgc(i,ig)*cmplx(-aimag(zfft1(ifg)),dble(zfft1(ifg)),8)
+    zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
   end do
   call rzfftifc(3,ngridg,1,rfir2,zfft2)
   rfir1(:)=rfir1(:)+rfir2(:)*gvup(:,i)
@@ -96,7 +96,7 @@ rfir1(:)=0.d0
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    zfft2(ifg)=vgc(i,ig)*cmplx(-aimag(zfft1(ifg)),dble(zfft1(ifg)),8)
+    zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
   end do
   call rzfftifc(3,ngridg,1,rfir2,zfft2)
   rfir1(:)=rfir1(:)+rfir2(:)*gvdn(:,i)
@@ -108,7 +108,7 @@ call rzfftifc(3,ngridg,-1,dcdgud,zfft1)
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    zfft2(ifg)=vgc(i,ig)*cmplx(-aimag(zfft1(ifg)),dble(zfft1(ifg)),8)
+    zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
   end do
   call rzfftifc(3,ngridg,1,rfir2,zfft2)
   vcup(:)=vcup(:)-rfir2(:)*gvdn(:,i)
