@@ -24,16 +24,14 @@ real(8), intent(in) :: rho(np)
 real(8), intent(out) :: g2rho(np),gvrho(np,3),grho2(np)
 ! local variables
 integer nr,nri,i
-! allocatable arrays
-real(8), allocatable :: grfmt(:,:),rfmt1(:),rfmt2(:)
-allocate(grfmt(np,3),rfmt2(np))
+! automatic arrays
+real(8) grfmt(np,3),rfmt1(np),rfmt2(np)
 nr=nrmt(is)
 nri=nrmti(is)
 ! compute grad^2 rho in spherical coordinates
 if (tsh) then
   call grad2rfmt(nr,nri,rlmt(:,-1,is),rlmt(:,-2,is),wcrmt(:,:,is),rho,rfmt2)
 else
-  allocate(rfmt1(np))
   call rfsht(nr,nri,rho,rfmt1)
   call grad2rfmt(nr,nri,rlmt(:,-1,is),rlmt(:,-2,is),wcrmt(:,:,is),rfmt1,rfmt2)
 end if
@@ -49,8 +47,6 @@ do i=1,3
 end do
 ! (grad rho)^2
 grho2(1:np)=gvrho(1:np,1)**2+gvrho(1:np,2)**2+gvrho(1:np,3)**2
-deallocate(rfmt2,grfmt)
-if (.not.tsh) deallocate(rfmt1)
 end subroutine
 !EOC
 
