@@ -3,15 +3,15 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine ggamt_4(is,np,gvrho,dtdr,dtdgr2,wx,wc,vx,vc)
+subroutine ggamt_4(is,np,gvrho,vx,vc,wx,wc,dtdr,dtdgr2)
 use modmain
 implicit none
 ! arguments
 integer, intent(in) :: is,np
 real(8), intent(in) :: gvrho(np,3)
-real(8), intent(in) :: dtdr(np),dtdgr2(np)
-real(8), intent(in) :: wx(np),wc(np)
 real(8), intent(inout) :: vx(np),vc(np)
+real(8), intent(in) :: wx(np),wc(np)
+real(8), intent(in) :: dtdr(np),dtdgr2(np)
 ! local variables
 integer nr,nri,i
 ! automatic arrays
