@@ -47,11 +47,9 @@ real(8), intent(out) :: g2up(np),g2dn(np)
 real(8), intent(out) :: g3rho(np),g3up(np),g3dn(np)
 ! local variables
 integer nr,nri,i
-! allocatable arrays
-real(8), allocatable :: gvup(:,:),gvdn(:,:),grfmt(:,:)
-real(8), allocatable :: rfmt1(:),rfmt2(:)
-allocate(grfmt(np,3),gvup(np,3),gvdn(np,3))
-allocate(rfmt1(np),rfmt2(np))
+! automatic arrays
+real(8) grfmt(np,3),gvup(np,3),gvdn(np,3)
+real(8) rfmt1(np),rfmt2(np)
 nr=nrmt(is)
 nri=nrmti(is)
 !----------------!
@@ -114,7 +112,6 @@ do i=1,3
   call rbsht(nr,nri,grfmt(:,i),rfmt1)
   g3rho(1:np)=g3rho(1:np)+(gvup(1:np,i)+gvdn(1:np,i))*rfmt1(1:np)
 end do
-deallocate(rfmt1,rfmt2,grfmt,gvup,gvdn)
 end subroutine
 !EOC
 
