@@ -29,9 +29,8 @@ real(8), intent(in) :: dxdgu2(np),dxdgd2(np),dxdgud(np)
 real(8), intent(in) :: dcdgu2(np),dcdgd2(np),dcdgud(np)
 ! local variables
 integer nr,nri,i
-! allocatable arrays
-real(8), allocatable :: rfmt1(:),rfmt2(:),grfmt(:,:)
-allocate(rfmt1(np),rfmt2(np),grfmt(np,3))
+! automatic arrays
+real(8) rfmt1(np),rfmt2(np),grfmt(np,3)
 nr=nrmt(is)
 nri=nrmti(is)
 !------------------!
@@ -108,7 +107,6 @@ do i=1,3
   vcup(1:np)=vcup(1:np)-rfmt1(1:np)*gvdn(1:np,i)
   vcdn(1:np)=vcdn(1:np)-rfmt1(1:np)*gvup(1:np,i)
 end do
-deallocate(rfmt1,rfmt2,grfmt)
 end subroutine
 !EOC
 
