@@ -192,6 +192,8 @@ do iscl=1,maxscl
       call writemom(60)
 ! write muffin-tin, interstitial and total moments for each R-vector
       call writemomru
+! write the moments for each Q-vector
+      call writemomqu
     end if
 ! output effective fields for fixed spin moment calculations
     if (fsmtype /= 0) call writefsm(60)
