@@ -13,7 +13,6 @@ real(8), intent(out) :: grfmt(npmtmax,natmtot,3),grfir(ngtot,3)
 ! local variables
 integer is,ias,ld,i
 integer ig,ifg,nthd
-complex(8) z1
 ! allocatable arrays
 complex(8), allocatable :: zfft1(:),zfft2(:)
 ! muffin-tin gradient
@@ -21,9 +20,9 @@ ld=npmtmax*natmtot
 call holdthd(natmtot+1,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(zfft1,zfft2) &
-!$OMP PRIVATE(is,i,ifg,ig,z1) &
+!$OMP PRIVATE(is,i,ifg,ig) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do ias=1,natmtot
   is=idxis(ias)
   call gradrfmt(nrmt(is),nrmti(is),rlmt(:,-1,is),wcrmt(:,:,is),rfmt(:,ias),ld, &
@@ -37,8 +36,11 @@ call rzfftifc(3,ngridg,-1,rfir,zfft1)
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    z1=zfft1(ifg)
-    zfft2(ifg)=vgc(i,ig)*cmplx(-aimag(z1),dble(z1),8)
+    if (ig <= ngvec) then
+      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
+    else
+      zfft2(ifg)=0.d0
+    end if
   end do
   call rzfftifc(3,ngridg,1,grfir(:,i),zfft2)
 end do
