@@ -9,8 +9,9 @@ use modphonon
 implicit none
 ! local variables
 integer nr,nri,np
-! automatic arrays
-complex(8) zfmt(npmtmax),gzfmt(npmtmax,3)
+! allocatable arrays
+complex(8), allocatable :: zfmt(:),grhomt(:,:)
+allocate(zfmt(npmtmax),grhomt(npmtmax,3))
 ! add gradient contribution from rigid shift of muffin-tin
 nr=nrmt(isph)
 nri=nrmti(isph)
@@ -18,8 +19,11 @@ np=npmt(isph)
 ! convert the density to complex spherical harmonic expansion
 call rtozfmt(nr,nri,rhomt(:,iasph),zfmt)
 ! compute the gradient
-call gradzfmt(nr,nri,rlmt(:,-1,isph),wcrmt(:,:,isph),zfmt,npmtmax,gzfmt)
+call gradzfmt(nr,nri,rlmt(:,-1,isph),wcrmt(:,:,isph),zfmt,npmtmax,grhomt)
+! store density derivative for displaced atom
+if (tlast) drhomt(1:np,natmtot+1)=drhomt(1:np,iasph)
 ! subtract from the density derivative
-drhomt(1:np,iasph)=drhomt(1:np,iasph)-gzfmt(1:np,ipph)
+drhomt(1:np,iasph)=drhomt(1:np,iasph)-grhomt(1:np,ipph)
+deallocate(zfmt,grhomt)
 end subroutine
 
