@@ -22,7 +22,7 @@ do ias=1,natmtot
   iro=nri+1
   np=npmt(is)
   do ist=1,nstsp(is)
-    if (spcore(ist,is).and.(ksp(ist,is).eq.lsp(ist,is)+1)) then
+    if (spcore(ist,is).and.(ksp(ist,is) == lsp(ist,is)+1)) then
       l=lsp(ist,is)
       do lm=l**2+1,(l+1)**2
         wfmt(1:np)=0.d0
