@@ -13,16 +13,15 @@ complex(8), intent(out) :: gzfmt(npmtmax,natmtot,3),gzfir(ngtot,3)
 ! local variables
 integer is,ias,ld,i
 integer ig,ifg,nthd
-complex(8) z1
 ! allocatable arrays
 complex(8), allocatable :: zfft(:)
 ! muffin-tin gradient
 ld=npmtmax*natmtot
 call holdthd(natmtot+1,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(zfft,is,i,ig,ifg,z1) &
+!$OMP PRIVATE(zfft,is,i,ig,ifg) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do ias=1,natmtot
   is=idxis(ias)
   call gradzfmt(nrmt(is),nrmti(is),rlmt(:,-1,is),wcrmt(:,:,is),zfmt(:,ias),ld, &
@@ -32,15 +31,14 @@ end do
 ! interstitial gradient
 !$OMP SINGLE
 allocate(zfft(ngtot))
-zfft(:)=zfir(:)
+zfft(1:ngtot)=zfir(1:ngtot)
 call zfftifc(3,ngridg,-1,zfft)
 do i=1,3
-  gzfir(:,i)=0.d0
   do ig=1,ngvec
     ifg=igfft(ig)
-    z1=zfft(ifg)
-    gzfir(ifg,i)=vgc(i,ig)*cmplx(-aimag(z1),dble(z1),8)
+    gzfir(ifg,i)=vgc(i,ig)*zi*zfft(ifg)
   end do
+  gzfir(igfft(ngvec+1:ngtot),i)=0.d0
   call zfftifc(3,ngridg,1,gzfir(:,i))
 end do
 deallocate(zfft)
