@@ -11,8 +11,9 @@ integer, intent(in) :: is
 complex(8), intent(out) :: gzfmt(npmtmax,3)
 ! local variables
 integer nr,nri,iro,i0,i1
-! automatic arrays
-complex(8) zvclmt(npmtmax)
+! allocatable arrays
+complex(8), allocatable :: zvclmt(:)
+allocate(zvclmt(npmtmax))
 nr=nrmt(is)
 nri=nrmti(is)
 iro=nri+1
@@ -25,5 +26,6 @@ i1=lmmaxo*(nr-iro)+i0
 zvclmt(i0:i1:lmmaxo)=vcln(iro:nr,is)
 ! compute the gradient of the potential
 call gradzfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),zvclmt,npmtmax,gzfmt)
+deallocate(zvclmt)
 end subroutine
 
