@@ -36,15 +36,7 @@ real(8), parameter :: pi=3.1415926535897932385d0
 ! find optimal grid size for potential and density
 ngridg(1:3)=int(gmaxvr*sqrt(avec(1,1:3)**2+avec(2,1:3)**2+avec(3,1:3)**2)/pi)+1
 ! find next largest FFT-compatible grid size
-call nfftifc(npfft,ngridg(1))
-call nfftifc(npfft,ngridg(2))
-call nfftifc(npfft,ngridg(3))
-if ((ngridg(1) <= 0).or.(ngridg(2) <= 0).or.(ngridg(3) <= 0)) then
-  write(*,*)
-  write(*,'("Error(gridsize): invalid ngridg : ",3I8)') ngridg
-  write(*,*)
-  stop
-end if
+call nfftifc(npfft,3,ngridg)
 ! total number of points in grid
 ngtot=ngridg(1)*ngridg(2)*ngridg(3)
 ! determine integer ranges for grid
