@@ -33,9 +33,9 @@ call genvsig
 ! generate k-points along a path for band structure plots
 call plotpt1d(bvec,nvp1d,npp1d,vvlp1d,vplp1d,dvp1d,dpp1d)
 ! compute the matrix elements of -V_xc and -B_xc
-allocate(vmt(npcmtmax,natmtot),vir(ngtot))
+allocate(vmt(npcmtmax,natmtot),vir(ngtc))
 if (spinpol) then
-  allocate(bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag))
+  allocate(bmt(npcmtmax,natmtot,ndmag),bir(ngtc,ndmag))
 end if
 call gwlocal(vmt,vir,bmt,bir)
 ! real axis frequencies
