@@ -40,9 +40,9 @@ call genpmat
 ! generate the inverse dielectric function and write to file
 call epsinv
 ! compute the matrix elements of -V_xc and -B_xc
-allocate(vmt(npcmtmax,natmtot),vir(ngtot))
+allocate(vmt(npcmtmax,natmtot),vir(ngtc))
 if (spinpol) then
-  allocate(bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag))
+  allocate(bmt(npcmtmax,natmtot,ndmag),bir(ngtc,ndmag))
 end if
 call gwlocal(vmt,vir,bmt,bir)
 if (mp_mpi) write(*,*)
@@ -54,7 +54,7 @@ call holdthd(nkpt/np_mpi,nthd)
 !$OMP PRIVATE(se) &
 !$OMP NUM_THREADS(nthd)
 allocate(se(nstsv,nstsv,0:nwfm))
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi) /= lp_mpi) cycle
