@@ -28,29 +28,29 @@ real(8), intent(in) :: x
 integer i
 real(8) h1,h2,ht
 ! fast return if possible
-if (n.eq.0) then
+if (n == 0) then
   hermite=1.d0
   return
-else if (n.eq.1) then
+else if (n == 1) then
   hermite=2.d0*x
   return
-else if (n.eq.2) then
+else if (n == 2) then
   hermite=4.d0*x**2-2.d0
   return
 end if
-if (n.lt.0) then
+if (n < 0) then
   write(*,*)
   write(*,'("Error(hermite): n < 0 : ",I8)') n
   write(*,*)
   stop
 end if
-if (n.gt.20) then
+if (n > 20) then
   write(*,*)
   write(*,'("Error(hermite): n out of range : ",I8)') n
   write(*,*)
   stop
 end if
-if (abs(x).gt.1.d15) then
+if (abs(x) > 1.d15) then
   write(*,*)
   write(*,'("Error(hermite): x out of range : ",G18.10)') x
   write(*,*)
