@@ -15,7 +15,6 @@ complex(8), intent(inout) :: hq(*)
 integer io,jo,i
 integer l0,l1,l2,l3
 integer lm1,lm3,lma,lmb
-real(8) t1
 complex(8) z1
 ! automatic arrays
 complex(8) y(ngp),a(lmoapw(is),ngpq),b(lmoapw(is),ngp)
@@ -24,7 +23,6 @@ do l1=0,lmaxapw
   do lm1=l1**2+1,(l1+1)**2
     do io=1,apword(l1,is)
       i=i+1
-      t1=apwfr(nrmt(is),1,io,l1,ias)
       y(:)=0.d0
       do l3=0,lmaxapw
         if (mod(l1+l3,2) == 0) then; l0=0; else; l0=1; end if
@@ -36,8 +34,6 @@ do l1=0,lmaxapw
               lma=l2**2+1; lmb=lma+2*l2
               z1=z1+sum(gntyry(lma:lmb,lm3,lm1)*haa(lma:lmb,jo,l3,io,l1,ias))
             end do
-! kinetic surface contribution
-            if (lm1 == lm3) z1=z1+t1*apwdfr(jo,l1,ias)
             if (abs(dble(z1))+abs(aimag(z1)) > 1.d-14) then
               call zaxpy(ngp,z1,apwalm(:,jo,lm3),1,y,1)
             end if
@@ -49,6 +45,6 @@ do l1=0,lmaxapw
     end do
   end do
 end do
-call zmctm(lmoapw(is),ngpq,ngp,a,b,ld,hq)
+call zmmab(lmoapw(is),ngpq,ngp,a,b,ld,hq)
 end subroutine
 
