@@ -14,18 +14,21 @@ complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot)
 complex(8), intent(out) :: h(nmatp,nmatp)
 ! local variables
 integer is,ias,j,nthd
-! zero the upper triangular part of the matrix
-do j=1,nmatp
-  h(1:j,j)=0.d0
-end do
+! interstitial contribution
+call hmlistl(ngp,igpig,vgpc,nmatp,h)
+! APW-APW contribution
 do ias=1,natmtot
   is=idxis(ias)
   call hmlaa(tefvr,is,ias,ngp,apwalm(:,:,:,ias),nmatp,h)
 end do
-call hmlistl(ngp,igpig,vgpc,nmatp,h)
+! zero the APW-lo and lo-lo part of the matrix
+do j=ngp+1,nmatp
+  h(1:j,j)=0.d0
+end do
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(is) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
