@@ -32,9 +32,9 @@ implicit none
 integer, intent(in) :: ngp,igpig(ngkmax)
 real(8), intent(in) :: vgpc(3,ngkmax)
 integer, intent(in) :: ld
-complex(8), intent(inout) :: h(ld,*)
+complex(8), intent(out) :: h(ld,*)
 ! local variables
-integer ig,j1,j2,j3,i,j
+integer j1,j2,j3,ig,i,j
 real(8) v1,v2,v3,t1
 do j=1,ngp
   ig=igpig(j)
@@ -44,7 +44,7 @@ do j=1,ngp
     ig=igpig(i)
     ig=ivgig(ivg(1,ig)-j1,ivg(2,ig)-j2,ivg(3,ig)-j3)
     t1=vgpc(1,i)*v1+vgpc(2,i)*v2+vgpc(3,i)*v3
-    h(i,j)=h(i,j)+vsig(ig)+t1*cfunig(ig)
+    h(i,j)=vsig(ig)+t1*cfunig(ig)
   end do
 end do
 end subroutine
