@@ -6,7 +6,7 @@
 !BOP
 ! !ROUTINE: i3mtv
 ! !INTERFACE:
-subroutine i3mtv(a,x,y)
+pure subroutine i3mtv(a,x,y)
 ! !INPUT/OUTPUT PARAMETERS:
 !   a : input matrix (in,integer(3,3))
 !   x : input vector (in,integer(3))
@@ -25,7 +25,6 @@ integer, intent(out) :: y(3)
 y(1)=a(1,1)*x(1)+a(2,1)*x(2)+a(3,1)*x(3)
 y(2)=a(1,2)*x(1)+a(2,2)*x(2)+a(3,2)*x(3)
 y(3)=a(1,3)*x(1)+a(2,3)*x(2)+a(3,3)*x(3)
-return
 end subroutine
 !EOC
 
