@@ -197,11 +197,7 @@ else
   ndmag=0
 end if
 ! set the non-collinear flag
-if (ndmag == 3) then
-  ncmag=.true.
-else
-  ncmag=.false.
-end if
+ncmag=(ndmag == 3)
 ! check for meta-GGA with non-collinearity
 if (any(xcgrad == [3,4,5]).and.ncmag) then
   write(*,*)
@@ -209,6 +205,13 @@ if (any(xcgrad == [3,4,5]).and.ncmag) then
   write(*,*)
   stop
 end if
+if (tbdip.and.(.not.ncmag)) then
+  write(*,*)
+  write(*,'("Error(init0): non-collinear magnetism required for inclusion of &
+   &the dipole field")')
+  write(*,*)
+  stop
+end if
 ! spin-polarised cores
 if (.not.spinpol) spincore=.false.
 if (fsmtype /= 0) then
@@ -267,6 +270,11 @@ end if
 !----------------------------------!
 !     crystal structure set up     !
 !----------------------------------!
+! use reference lattice vectors if required
+if (tavref) then
+  avec0(:,:)=avec(:,:)
+  avec(:,:)=avecref(:,:)
+end if
 ! generate the reciprocal lattice vectors, unit cell and Brillouin zone volumes
 call reciplat(avec,bvec,omega,omegabz)
 ! inverse of the lattice vector matrix
@@ -292,20 +300,6 @@ do is=1,nspecies
 end do
 ! input q-vector in Cartesian coordinates
 call r3mv(bvec,vecql,vecqc)
-! write to VARIABLES.OUT
-if (wrtvars) then
-  call writevars('avec',nv=9,rva=avec)
-  call writevars('bvec',nv=9,rva=bvec)
-  call writevars('omega',rv=omega)
-  do is=1,nspecies
-    call writevars('atposl',n1=is,nv=3*natoms(is),rva=atposl(:,:,is))
-  end do
-  do is=1,nspecies
-    call writevars('atposc',n1=is,nv=3*natoms(is),rva=atposc(:,:,is))
-  end do
-  call writevars('vqlss',nv=3,rva=vqlss)
-  call writevars('vqcss',nv=3,rva=vqcss)
-end if
 
 !-------------------------------!
 !     vector fields E and A     !
@@ -453,7 +447,7 @@ case(-3)
 case(-2)
 ! use the fixed value of 2.0
   gkmax=rgkmax/2.d0
-case(-1)
+case(-1,0)
 ! use average muffin-tin radius
   t1=sum(natoms(1:nspecies)*rmt(1:nspecies))/dble(natmtot)
   gkmax=rgkmax/t1
@@ -470,6 +464,8 @@ case(1:)
 end select
 ! generate the G-vectors
 call gengvec
+! apply strain to A-, B- and G-vectors if required
+call strainabg
 ! write number of G-vectors to test file
 call writetest(900,'number of G-vectors',iv=ngvec)
 ! Poisson solver pseudocharge density constant
@@ -480,7 +476,7 @@ else
 end if
 npsd=max(nint(t1),1)
 lnpsd=lmaxo+npsd+1
-! generate the Coulomb Green's function in G-space = fourpi / G^2
+! generate the Coulomb Green's function in G-space = 4π/G²
 call gengclg
 ! compute the spherical Bessel functions j_l(|G|R_mt)
 if (allocated(jlgrmt)) deallocate(jlgrmt)
@@ -505,6 +501,17 @@ call gengvc
 call gencfrc
 ! write to VARIABLES.OUT
 if (wrtvars) then
+  call writevars('avec',nv=9,rva=avec)
+  call writevars('bvec',nv=9,rva=bvec)
+  call writevars('omega',rv=omega)
+  do is=1,nspecies
+    call writevars('atposl',n1=is,nv=3*natoms(is),rva=atposl(:,:,is))
+  end do
+  do is=1,nspecies
+    call writevars('atposc',n1=is,nv=3*natoms(is),rva=atposc(:,:,is))
+  end do
+  call writevars('vqlss',nv=3,rva=vqlss)
+  call writevars('vqcss',nv=3,rva=vqcss)
   call writevars('gmaxvr',rv=gmaxvr)
   call writevars('ngridg',nv=3,iva=ngridg)
   call writevars('intgv',nv=6,iva=intgv)
@@ -658,11 +665,7 @@ allocate(chgmt(natmtot))
 if (allocated(mommt)) deallocate(mommt)
 allocate(mommt(3,natmtot))
 ! check if scaled spin exchange-correlation should be used
-if (abs(sxcscf-1.d0) > 1.d-6) then
-  tssxc=.true.
-else
-  tssxc=.false.
-end if
+tssxc=(abs(sxcscf-1.d0) > 1.d-6)
 ! spin-spiral phase factors
 if (ssdph) then
   if (allocated(zqss)) deallocate(zqss)
