@@ -259,9 +259,6 @@ do is=1,nspecies
   nlmwf(is)=max(nlmwf(is),n)
 end do
 lolmmax=(lolmax+1)**2
-! polynomial order used for APW and local-orbital radial derivatives
-npapw=max(apwordmax+1,4)
-nplorb=max(lorbordmax+1,4)
 ! set the APW and local-orbital linearisation energies to the default
 if (allocated(apwe)) deallocate(apwe)
 allocate(apwe(apwordmax,0:lmaxapw,natmtot))
@@ -309,7 +306,7 @@ end if
 nempty=nint(nempty0*max(natmtot,1))
 if (nempty < 1) nempty=1
 ! number of first-variational states
-nstfv=int(chgval/2.d0)+nempty+1
+nstfv=nint(chgval/2.d0)+nempty+1
 ! overlap and Hamiltonian matrix sizes
 if (allocated(nmat)) deallocate(nmat)
 allocate(nmat(nspnfv,nkpt))
@@ -336,7 +333,6 @@ if (allocated(evalsv)) deallocate(evalsv)
 allocate(evalsv(nstsv,nkpt))
 if (allocated(occsv)) deallocate(occsv)
 allocate(occsv(nstsv,nkpt))
-occsv(1:nstsv,1:nkpt)=0.d0
 ! allocate overlap and Hamiltonian integral arrays
 if (allocated(oalo)) deallocate(oalo)
 allocate(oalo(apwordmax,nlomax,natmtot))
@@ -368,11 +364,7 @@ do l1=0,lmaxapw
   end do
 end do
 ! check if the scissor correction is non-zero
-if (abs(scissor).gt.1.d-8) then
-  tscissor=.true.
-else
-  tscissor=.false.
-end if
+tscissor=(abs(scissor) > 1.d-8)
 ! write to VARIABLES.OUT
 if (wrtvars) then
   call writevars('nempty',iv=nempty)
