@@ -98,9 +98,9 @@ end if
 !---------------------------!
 if (task == 205) then
   if (allocated(vgqc)) deallocate(vgqc)
-  allocate(vgqc(3,ngtot))
+  allocate(vgqc(3,ngvec))
   if (allocated(gqc)) deallocate(gqc)
-  allocate(gqc(ngtot))
+  allocate(gqc(ngvec))
   if (allocated(gclgq)) deallocate(gclgq)
   allocate(gclgq(ngvec))
   if (allocated(jlgqrmt)) deallocate(jlgqrmt)
@@ -110,9 +110,9 @@ if (task == 205) then
   if (allocated(sfacgq)) deallocate(sfacgq)
   allocate(sfacgq(ngvec,natmtot))
   if (allocated(ffacgq)) deallocate(ffacgq)
-  allocate(ffacgq(ngtot,nspecies))
+  allocate(ffacgq(ngvec,nspecies))
   if (allocated(dcfunig)) deallocate(dcfunig)
-  allocate(dcfunig(ngtot))
+  allocate(dcfunig(ngvec))
   if (allocated(dcfunir)) deallocate(dcfunir)
   allocate(dcfunir(ngtot))
 end if
@@ -122,7 +122,7 @@ end if
 !-----------------------------------------------------------------!
 if (task == 205) then
   if (allocated(drhomt)) deallocate(drhomt)
-  allocate(drhomt(npmtmax,natmtot))
+  allocate(drhomt(npmtmax,natmtot+1))
   if (allocated(drhoir)) deallocate(drhoir)
   allocate(drhoir(ngtot))
   if (allocated(dmagmt)) deallocate(dmagmt)
@@ -135,13 +135,11 @@ if (task == 205) then
   allocate(dvclmt(npmtmax,natmtot))
   if (allocated(dvclir)) deallocate(dvclir)
   allocate(dvclir(ngtot))
-  if (allocated(zvnmt)) deallocate(zvnmt)
-  allocate(zvnmt(npmtmax))
   if (allocated(gvsmt)) deallocate(gvsmt)
   allocate(gvsmt(npmtmax))
 ! combined target array for Kohn-Sham potential and magnetic field derivative
   if (allocated(dvsbs)) deallocate(dvsbs)
-  n=npmtmax*natmtot+ngtot
+  n=npmtmax*natmtot+ngvc
   if (spinpol) n=n+(npcmtmax*natmtot+ngtot)*ndmag
   allocate(dvsbs(n))
 ! zero the array
@@ -149,15 +147,15 @@ if (task == 205) then
 ! associate pointer arrays with target
   dvsmt(1:npmtmax,1:natmtot) => dvsbs(1:)
   i=npmtmax*natmtot+1
-  dvsir(1:ngtot) => dvsbs(i:)
+  dvsig(1:ngvc) => dvsbs(i:)
   if (spinpol) then
-    i=i+ngtot
+    i=i+ngvc
     dbsmt(1:npcmtmax,1:natmtot,1:ndmag) => dvsbs(i:)
     i=i+npcmtmax*natmtot*ndmag
     dbsir(1:ngtot,1:ndmag) => dvsbs(i:)
   end if
-  if (allocated(dvsig)) deallocate(dvsig)
-  allocate(dvsig(ngvec))
+  if (allocated(dvsir)) deallocate(dvsir)
+  allocate(dvsir(ngtot))
   if (allocated(dsocfr)) deallocate(dsocfr)
   if (spinorb) then
     allocate(dsocfr(nrcmtmax,natmtot))
