@@ -13,8 +13,8 @@ integer iq,ik,n,i
 ! automatic arrays
 complex(8) u(nstsv,nstsv),v(nstsv,nstsv)
 complex(8) w(nbph,nbph),x(nbph,nbph),y(nbph)
+complex(8) ev(nbph,nbph)
 ! allocatable arrays
-complex(8), allocatable :: dynq(:,:,:),ev(:,:)
 complex(8), allocatable :: ephmat(:,:,:)
 
 ! combined target array for fermionic and bosonic density matrices
@@ -57,16 +57,12 @@ end if
 !----------------------------!
 !     phononic variables     !
 !----------------------------!
-allocate(dynq(nbph,nbph,nqpt),ev(nbph,nbph))
-! read in the dynamical matrices
-call readdyn(dynq)
-! apply the acoustic sum rule
-call sumrule(dynq)
+! initialise the phonon dynamical matrices
+call initph
 ! find the eigenvalues of the dynamical matrices and store in global array
 do iq=1,nqpt
   call dynev(dynq(:,:,iq),wphq(:,iq),ev)
 end do
-deallocate(dynq,ev)
 if (allocated(evalwx)) deallocate(evalwx)
 allocate(evalwx(nbph,nqpt))
 if (allocated(xnorm)) deallocate(xnorm)
