@@ -7,19 +7,15 @@ subroutine initoep
 use modmain
 implicit none
 ! local variables
-integer is,ic,ist,m
+integer is,ist,nc
 ! find maximum core states over all species
 ncrmax=0
 do is=1,nspecies
-  ic=0
+  nc=0
   do ist=1,nstsp(is)
-    if (spcore(ist,is)) then
-      do m=-ksp(ist,is),ksp(ist,is)-1
-        ic=ic+1
-      end do
-    end if
+    if (spcore(ist,is)) nc=nc+2*ksp(ist,is)
   end do
-  ncrmax=max(ncrmax,ic)
+  ncrmax=max(ncrmax,nc)
 end do
 ! allocate the exchange potential and magnetic field
 if (allocated(vxmt)) deallocate(vxmt)
@@ -32,12 +28,12 @@ if (spinpol) then
   if (allocated(bxir)) deallocate(bxir)
   allocate(bxir(ngtot,ndmag))
 end if
-! zero the exchange potential and magnetic field
-vxmt(:,:)=0.d0
-vxir(:)=0.d0
+! allocate the OEP residual functions
+allocate(dvxmt(npcmtmax,natmtot),dvxir(ngtot))
 if (spinpol) then
-  bxmt(:,:,:)=0.d0
-  bxir(:,:)=0.d0
+  allocate(dbxmt(npcmtmax,natmtot,ndmag),dbxir(ngtot,ndmag))
 end if
+! set initial step size for iterative method
+tauoep=tau0oep
 end subroutine
 
