@@ -30,7 +30,7 @@ if (num_bands > nstsv) then
   stop
 end if
 ! if num_bands is not positive then assume all states are used
-if (num_bands <= 0) then
+if (num_bands < 1) then
   if (allocated(idxw90)) deallocate(idxw90)
   allocate(idxw90(nstsv))
   do ist=1,nstsv
@@ -49,7 +49,7 @@ do i=1,num_bands
   end if
 end do
 ! set the number of Wannier functions
-if (num_wann <= 0) then
+if (num_wann < 1) then
   num_wann=num_bands+num_wann
   num_wann=max(num_wann,1)
 end if
