@@ -7,8 +7,6 @@ subroutine jprplot
 use modmain
 use modmpi
 implicit none
-! local variables
-integer ik
 ! initialise universal variables
 call init0
 call init1
@@ -16,8 +14,6 @@ call init1
 call readstate
 ! generate the core wavefunctions and densities
 call gencore
-! read Fermi energy from file
-call readfermi
 ! find the new linearisation energies
 call linengy
 ! generate the APW radial functions
@@ -25,9 +21,7 @@ call genapwfr
 ! generate the local-orbital radial functions
 call genlofr
 ! get the occupation numbers from file
-do ik=1,nkpt
-  call getoccsv(filext,ik,vkl(:,ik),occsv(:,ik))
-end do
+call readoccsv
 ! compute the paramagnetic current density
 call genjpr
 ! plot the current density (master process only)
