@@ -12,12 +12,11 @@ complex(8), intent(in) :: pmat(nstsv,nstsv,3)
 complex(8), intent(in) :: evecsv(nstsv,nstsv),evecsvt(nstsv,nstsv)
 ! local variables
 integer ist,l
-real(8) wo
-complex(8) z1
+real(8) wo,t1
 ! allocatable arrays
 complex(8), allocatable :: a(:,:),b(:,:)
 ! external functions
-complex(8), external :: zdotc
+real(8), external :: ddot
 allocate(a(nstsv,nstsv),b(nstsv,nstsv))
 do l=1,3
 ! form the momentum operator matrix elements in the first-variational basis
@@ -30,9 +29,9 @@ do l=1,3
     wo=occsv(ist,ik)
     if (abs(wo) < epsocc) cycle
     wo=wo*wkpt(ik)
-    z1=zdotc(nstsv,evecsvt(:,ist),1,a(:,ist),1)
+    t1=ddot(2*nstsv,evecsvt(:,ist),1,a(:,ist),1)
 !$OMP ATOMIC
-    jtot(l)=jtot(l)+wo*dble(z1)
+    jtot(l)=jtot(l)+wo*t1
   end do
 end do
 deallocate(a,b)
