@@ -394,7 +394,7 @@ if (present(fxcdd)) fxcdd(1:n)=0.d0
 ! loop over functional kinds (exchange or correlation)
 do k=2,3
   id=fxctype(k)
-  if (id <= 0) cycle
+  if (id < 1) cycle
   fmly=xc_f03_family_from_id(id)
 ! initialise functional
   call xc_f03_func_init(p,id,nspin)
@@ -461,7 +461,7 @@ hybrid=.false.
 xcdescr='none'
 do k=2,3
   id=xctype(k)
-  if (id <= 0) cycle
+  if (id < 1) cycle
 ! initialise functional
   call xc_f03_func_init(p,id,XC_UNPOLARIZED)
 !-----------------------!
