@@ -12,21 +12,22 @@ complex(8), intent(out) :: zlflm1(ld,n),zlflm2(ld,n),zlflm3(ld,n)
 ! local variables
 integer l,m,lm,i
 real(8) t1
+complex(8), parameter :: zi=(0.d0,1.d0),zmi=(0.d0,-1.d0)
 complex(8) z1
 lm=0
 do l=0,lmax
   do m=-l,l
     lm=lm+1
     if (m == -l) then
-      zlflm1(lm,:)=0.d0
-      zlflm2(lm,:)=0.d0
+      zlflm1(lm,1:n)=0.d0
+      zlflm2(lm,1:n)=0.d0
     end if
     if (m < l) then
       t1=0.5d0*sqrt(dble((l-m)*(l+m+1)))
       do i=1,n
         z1=t1*zflm(lm,i)
         zlflm1(lm+1,i)=z1
-        zlflm2(lm+1,i)=cmplx(aimag(z1),-dble(z1),8)
+        zlflm2(lm+1,i)=zmi*z1
       end do
     end if
     if (m > -l) then
@@ -34,13 +35,13 @@ do l=0,lmax
       do i=1,n
         z1=t1*zflm(lm,i)
         zlflm1(lm-1,i)=zlflm1(lm-1,i)+z1
-        zlflm2(lm-1,i)=zlflm2(lm-1,i)+cmplx(-aimag(z1),dble(z1),8)
+        zlflm2(lm-1,i)=zlflm2(lm-1,i)+zi*z1
       end do
     end if
     if (m /= 0) then
-      zlflm3(lm,:)=dble(m)*zflm(lm,:)
+      zlflm3(lm,1:n)=dble(m)*zflm(lm,1:n)
     else
-      zlflm3(lm,:)=0.d0
+      zlflm3(lm,1:n)=0.d0
     end if
   end do
 end do
