@@ -32,11 +32,7 @@ cmagz=.true.
 ! no fixed spin moment calculation: the crystal is rotated instead
 fsmtype=0
 ! if task=28 then start from atomic densities; if task=29 read STATE.OUT
-if (task == 28) then
-  trdstate=.false.
-else
-  trdstate=.true.
-end if
+trdstate=(task == 29)
 ! zero k-point offset
 vkloff(:)=0.d0
 ! start with large magnetic field
