@@ -55,7 +55,7 @@ complex(8), intent(out) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot)
 integer is,ia,ias,omax,ord
 integer l,lma,lmb,lm,io,jo
 integer nr,ir,igp,i,info
-real(8) t0,t1
+real(8) t0,t1,t2
 complex(8) z1,z2
 ! automatic arrays
 integer ipiv(apwordmax)
@@ -98,13 +98,12 @@ do is=1,nspecies
 ! evaluate the spherical Bessel function derivatives for all G+p-vectors
   do igp=1,ngp
     t1=gpc(igp)*rmt(is)
-    do io=1,omax
-      call sbesseldm(io-1,lmaxapw,t1,djl(:,io,igp))
-    end do
-    t1=1.d0
+    call sbessel(lmaxapw,t1,djl(:,1,igp))
+    t2=1.d0
     do io=2,omax
-      t1=t1*gpc(igp)
-      djl(0:lmaxapw,io,igp)=t1*djl(0:lmaxapw,io,igp)
+      call sbesseldm(io-1,lmaxapw,t1,djl(:,io,igp))
+      t2=t2*gpc(igp)
+      djl(0:lmaxapw,io,igp)=t2*djl(0:lmaxapw,io,igp)
     end do
   end do
 ! loop over atoms
@@ -115,7 +114,8 @@ do is=1,nspecies
       ord=apword(l,is)
 ! set up matrix of derivatives
       do jo=1,ord
-        do io=1,ord
+        a(1,jo)=apwfr(nr,1,jo,l,ias)
+        do io=2,ord
           a(io,jo)=polynm(io-1,npapw,rsp(ir,is),apwfr(ir,1,jo,l,ias),rmt(is))
         end do
       end do
