@@ -14,9 +14,9 @@ real(8), intent(out) :: d
 ! local variables
 integer i
 real(8) t0,t1
-if (n <= 0) return
+if (n < 1) return
 ! initialise mixer
-if (iscl <= 0) then
+if (iscl < 1) then
   mu(1:n)=nu(1:n)
   d=1.d0
   return
