@@ -6,12 +6,19 @@
 subroutine mkl_init
 use modomp
 implicit none
-! set the initial number of MKL threads equal to one
+! set the initial global number of MKL threads equal to one
 call mkl_set_num_threads(1)
 ! set the maximum number of threads available to MKL
-if (maxthdmkl.le.0) maxthdmkl=maxthd
+select case(maxthdmkl)
+case(:-1)
+  maxthdmkl=maxthd/abs(maxthdmkl)
+  maxthdmkl=max(maxthdmkl,1)
+case(0)
+  maxthdmkl=maxthd
+case default
+  maxthdmkl=min(maxthdmkl,maxthd)
+end select
 ! enable dynamic thread allocation
 call mkl_set_dynamic(.true.)
-return
 end subroutine
 
