@@ -8,12 +8,16 @@
 subroutine mkl_set_num_threads(num_threads)
 implicit none
 integer, intent(in) :: num_threads
-return
 end subroutine
 
+integer function mkl_set_num_threads_local(num_threads)
+implicit none
+integer, intent(in) :: num_threads
+mkl_set_num_threads_local=0
+end function
+
 subroutine mkl_set_dynamic(dynamic)
 implicit none
 logical, intent(in) :: dynamic
-return
 end subroutine
 
