@@ -11,6 +11,8 @@ real(8) wmaxgw
 integer nwgw
 ! integer grid intervals for Matsubara frequencies
 integer intwgw(2)
+! number of prime factors for the Matsubara frequency FFT
+integer npfftw
 ! map from frequency index to FFT array
 integer, allocatable :: iwfft(:)
 ! maximum fermionic Matsubara frequency index to be used for the GW calculation
