@@ -56,8 +56,6 @@ case default
 end select
 ! switch off dynamic allocation of threads
 call omp_set_dynamic(.false.)
-! set the scheduling method and chunk size
-call omp_set_schedule(omp_sched_dynamic,0)
 ! allow nested parallelism (deprecated in OpenMP version 5)
 call omp_set_nested(.true.)
 ! set the maximum nesting level
@@ -73,7 +71,7 @@ subroutine omp_reset
 implicit none
 ! number of active threads at each nesting level
 nathd(0)=1
-nathd(1:)=0
+nathd(1:maxlvl)=0
 end subroutine
 
 subroutine holdthd(nloop,nthd)
