@@ -23,8 +23,19 @@ real(8), allocatable :: vqlwrt(:,:)
 real(8) mustar
 ! number of temperatures for the Eliashberg equations and thermal properties
 integer ntemp
+! dynamical matrices for all q-points
+complex(8), allocatable :: dynq(:,:,:)
+! dynamical matrices for all R-points
+real(8), allocatable :: dynr(:,:,:)
 ! phonon frequencies for all q-points
 real(8), allocatable :: wphq(:,:)
+! tphnat is .true. if the non-analytic term is to be added to the phonon
+! dispersion; this requires the Born effective charges and dielectric function
+logical tphnat
+! Born effective charge tensor for each atom
+real(8), allocatable :: bec(:,:,:)
+! static dielectric tensor
+real(8) epsw0(3,3)
 
 !-----------------------------!
 !     supercell variables     !
@@ -89,20 +100,18 @@ complex(8), allocatable :: drhomt(:,:),drhoir(:)
 complex(8), allocatable :: dmagmt(:,:,:),dmagir(:,:)
 ! Coulomb potential derivative
 complex(8), allocatable :: dvclmt(:,:),dvclir(:)
-! if tphdyn is .true. then the phonon dynamical matrix is being calculated
-logical :: tphdyn=.false.
-! nuclear potential without the self-term; used for the phonon dynamical matrix
-complex(8), allocatable :: zvnmt(:)
 ! gradient of vsmt for the displaced muffin-tin
 complex(8), allocatable :: gvsmt(:)
 ! combined target array for dvsmt, dvsir, dbsmt and dbsir
 complex(8), allocatable, target :: dvsbs(:)
-! Kohn-Sham potential derivative
-complex(8), pointer, contiguous :: dvsmt(:,:),dvsir(:)
+! muffin-tin Kohn-Sham potential derivative
+complex(8), pointer, contiguous :: dvsmt(:,:)
+! interstitial Kohn-Sham potential derivative
+complex(8), allocatable :: dvsir(:)
+! G+q-space interstitial Kohn-Sham potential derivative
+complex(8), pointer, contiguous :: dvsig(:)
 ! Kohn-Sham effective magnetic field derivative
 complex(8), pointer, contiguous :: dbsmt(:,:,:),dbsir(:,:)
-! G+q-space interstitial Kohn-Sham potential derivative
-complex(8), allocatable :: dvsig(:)
 ! spin-orbit coupling radial function derivative
 complex(8), allocatable :: dsocfr(:,:)
 ! APW-APW Hamiltonian integral derivatives
