@@ -38,12 +38,9 @@ subroutine initrd
 implicit none
 ! local variables
 integer i
-if (allocated(file)) then
-  write(*,*)
-  write(*,'("Error(initrd): RAM disk already initialised")')
-  write(*,*)
-  stop
-end if
+! check if the RAM disk is already initialised
+if (allocated(file)) return
+! allocate the files array and null the file names
 allocate(file(maxfiles))
 do i=1,maxfiles
   file(i)%fname=''
@@ -192,12 +189,12 @@ if (present(n3)) then
 end if
 if (present(v1)) then
   j=i+5
-  file(fnum)%rec(irec)%dat(i:j)=transfer(v1(:),file(fnum)%rec(irec)%dat(i:j))
+  file(fnum)%rec(irec)%dat(i:j)=transfer(v1(1:3),file(fnum)%rec(irec)%dat(i:j))
   i=i+6
 end if
 if (present(v2)) then
   j=i+5
-  file(fnum)%rec(irec)%dat(i:j)=transfer(v2(:),file(fnum)%rec(irec)%dat(i:j))
+  file(fnum)%rec(irec)%dat(i:j)=transfer(v2(1:3),file(fnum)%rec(irec)%dat(i:j))
   i=i+6
 end if
 if (present(rva)) then
@@ -272,13 +269,13 @@ if (present(n3)) then
 end if
 if (present(v1)) then
   if (n < 6) return
-  v1(:)=transfer(file(fnum)%rec(irec)%dat(i:i+5),v1(:))
+  v1(1:3)=transfer(file(fnum)%rec(irec)%dat(i:i+5),v1(1:3))
   i=i+6
   n=n-6
 end if
 if (present(v2)) then
   if (n < 6) return
-  v2(:)=transfer(file(fnum)%rec(irec)%dat(i:i+5),v2(:))
+  v2(1:3)=transfer(file(fnum)%rec(irec)%dat(i:i+5),v2(1:3))
   i=i+6
   n=n-6
 end if
