@@ -60,6 +60,9 @@ real(8), allocatable :: afieldt(:,:)
 logical tafspt
 ! spin- and time-dependent A-field
 real(8), allocatable :: afspt(:,:,:)
+! tbaspat is .true. if the effective magnetic field B = 1/c²((Aₛ)ᵗA)⋅σ should be
+! added to the time-dependent Hamiltonian
+logical tbaspat
 ! induced A-field and its time derivative at the current time step
 real(8) afindt(3,0:1)
 ! induced A-field parameters
