@@ -67,6 +67,8 @@ complex(8), allocatable :: vclq(:)
 complex(8), allocatable :: bfcq(:,:)
 ! Q-dependent external muffin-tin magnetic fields
 complex(8), allocatable :: bfcmtq(:,:,:)
+! global external magnetic field in Cartesian coordinates
+real(8) bfielduc(3)
 ! electric field vector in Cartesian coordinates
 real(8) efielduc(3)
 ! if tbdipu is .true. then the spin dipole-dipole interaction is included
