@@ -40,7 +40,7 @@ if ((present(iva)).or.(present(rva)).or.(present(zva)).or.(present(sva))) then
 end if
 open(95,file='VARIABLES.OUT',position='APPEND',form='FORMATTED',action='WRITE')
 write(95,*)
-write(95,'(A," ")',advance='NO') trim(vname)
+write(95,'(A)',advance='NO') trim(vname)
 if (present(n1)) write(95,'(I8)',advance='NO') n1
 if (present(n2)) write(95,'(I8)',advance='NO') n2
 if (present(n3)) write(95,'(I8)',advance='NO') n3
