@@ -121,9 +121,9 @@ real(8), optional, intent(out) :: dtdg2r(n),dtdg2u(n),dtdg2d(n)
 real(8) kappa,mu,beta
 ! allocatable arrays
 real(8), allocatable :: ra(:,:)
-if (n <= 0) then
+if (n < 1) then
   write(*,*)
-  write(*,'("Error(xcifc): n <= 0 : ",I8)') n
+  write(*,'("Error(xcifc): n < 1 : ",I8)') n
   write(*,*)
   stop
 end if
@@ -255,7 +255,7 @@ case(30)
     goto 10
   end if
 case(50)
-! Thomas-Fermi kinetic energy functional
+! Thomas-Fermi kinetic energy functional derivative δτ(r')/δρ(r)
   if (present(rhoup).and.present(rhodn).and.present(dtdru) &
    .and.present(dtdrd)) then
     call k_tf_sp(n,rhoup,rhodn,dtdru,dtdrd)
@@ -267,8 +267,22 @@ case(50)
   else
     goto 10
   end if
+case(51)
+! Thomas-Fermi kinetic energy functional derivative scaled by the ratio of the
+! exact τ to the TF τ
+  if (present(rhoup).and.present(rhodn).and.present(tauup).and.present(taudn) &
+   .and.present(dtdru).and.present(dtdrd)) then
+    call k_tfsc_sp(n,rhoup,rhodn,tauup,taudn,dtdru,dtdrd)
+    if (present(dtdgu2)) dtdgu2(1:n)=0.d0
+    if (present(dtdgd2)) dtdgd2(1:n)=0.d0
+  else if (present(rho).and.present(tau).and.present(dtdr)) then
+    call k_tfsc(n,rho,tau,dtdr)
+    if (present(dtdgr2)) dtdgr2(1:n)=0.d0
+  else
+    goto 10
+  end if
 case(52)
-! Thomas-Fermi-von Weizsacker kinetic energy functional
+! Thomas-Fermi-von Weizsacker kinetic energy functional derivative
   if (present(rhoup).and.present(rhodn).and.present(gup2).and.present(gdn2) &
    .and.present(dtdru).and.present(dtdrd).and.present(dtdgu2) &
    .and.present(dtdgd2)) then
@@ -448,6 +462,11 @@ case(50)
   xcdescr='Thomas-Fermi kinetic energy functional'
   xcspin=-1
   xcgrad=0
+case(51)
+  xcdescr='Thomas-Fermi kinetic energy functional scaled by the ratio of the &
+   &exact τ to the TF τ'
+  xcspin=-1
+  xcgrad=0
 case(52)
   xcdescr='Thomas-Fermi-von Weizsacker kinetic energy functional'
   xcspin=-1
