@@ -25,7 +25,7 @@ allocate(sig1(nwplot,2),sig2(nwplot,2))
 allocate(kerr(nwplot))
 ! read diagonal contribution to optical conductivity
 open(50,file='SIGMA_11.OUT',status='OLD',form='FORMATTED',iostat=ios)
-if (ios.ne.0) then
+if (ios /= 0) then
   write(*,*)
   write(*,'("Error(moke): error opening SIGMA_11.OUT")')
   write(*,*)
@@ -41,7 +41,7 @@ end do
 close(50)
 ! read off-diagonal contribution to optical conductivity
 open(50,file='SIGMA_12.OUT',status='OLD',form='FORMATTED',iostat=ios)
-if (ios.ne.0) then
+if (ios /= 0) then
   write(*,*)
   write(*,'("Error(moke): error opening SIGMA_12.OUT")')
   write(*,*)
@@ -57,11 +57,11 @@ end do
 close(50)
 ! calculate the complex Kerr angle
 do iw=1,nwplot
-  if (w(iw).gt.0.d0) then
+  if (w(iw) > 0.d0) then
     z1=cmplx(sig1(iw,1),sig2(iw,1),8)
     z2=cmplx(sig1(iw,2),sig2(iw,2),8)
     z3=z1*sqrt(1.d0+fourpi*zi*z1/w(iw))
-    if (abs(z3).gt.1.d-8) then
+    if (abs(z3) > 1.d-8) then
       kerr(iw)=-z2/z3
     else
       kerr(iw)=0.d0
