@@ -20,24 +20,16 @@ atposc0(:,:,:)=atposc(:,:,:)
 tshift0=tshift
 tforce0=tforce
 tfav00=tfav0
-trimvg0=trimvg
 ! no shifting of atomic basis allowed
 tshift=.false.
 ! calculate atomic forces
 tforce=.true.
 ! average force can be non-zero (allow for translation of atomic basis)
 tfav0=.false.
-! trim the Fourier components of the exchange-correlation potential
-trimvg=.true.
 ! generate the time step grid
 call gentimes
-if (task == 420) then
-! calculation starts at t=0
-  tdt0=.true.
-else
-! calculation restarts
-  tdt0=.false.
-end if
+! flag for starting at t=0 or a restart
+tdt0=(task == 420)
 if (tdt0) then
 ! start from t=0
   itimes0=1
@@ -109,7 +101,6 @@ atposl(:,:,:)=atposl0(:,:,:)
 tshift=tshift0
 tforce=tforce0
 tfav0=tfav00
-trimvg=trimvg0
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
 end subroutine
