@@ -6,10 +6,11 @@
 !BOP
 ! !ROUTINE: nfftifc
 ! !INTERFACE:
-subroutine nfftifc(np,n)
+subroutine nfftifc(np,nd,n)
 ! !INPUT/OUTPUT PARAMETERS:
 !   np : number of allowed primes (in,integer)
-!   n  : required/avalable grid size (inout,integer)
+!   nd : number of dimensions (in,integer)
+!   n  : required/available grid size (inout,integer(nd))
 ! !DESCRIPTION:
 !   Interface to the grid requirements of the fast Fourier transform routine.
 !   Most routines restrict $n$ to specific prime factorisations. This routine
@@ -21,10 +22,10 @@ subroutine nfftifc(np,n)
 !BOC
 implicit none
 ! arguments
-integer, intent(in) :: np
-integer, intent(inout) :: n
+integer, intent(in) :: np,nd
+integer, intent(inout) :: n(nd)
 ! local variables
-integer i,j
+integer i,j,l
 integer, parameter :: p(10)=[2,3,5,7,11,13,17,19,23,29]
 if ((np < 1).or.(np > 10)) then
   write(*,*)
@@ -32,21 +33,31 @@ if ((np < 1).or.(np > 10)) then
   write(*,*)
   stop
 end if
-if (n <= 0) then
+if (nd < 1) then
   write(*,*)
-  write(*,'("Error(nfftifc): n <= 0 : ",I8)') n
+  write(*,'("Error(nfftifc): nd < 1 : ",I8)') nd
   write(*,*)
   stop
 end if
-do
-  i=n
-  do j=1,np
-    do while (mod(i,p(j)) == 0)
-      i=i/p(j)
+! loop over dimensions
+do l=1,nd
+  if (n(l) < 1) then
+    write(*,*)
+    write(*,'("Error(nfftifc): n < 1 : ",I8)') n(l)
+    write(*,'(" for dimension : ",I4)') l
+    write(*,*)
+    stop
+  end if
+  do
+    i=n(l)
+    do j=1,np
+      do while (mod(i,p(j)) == 0)
+        i=i/p(j)
+      end do
     end do
+    if (i == 1) exit
+    n(l)=n(l)+1
   end do
-  if (i == 1) return
-  n=n+1
 end do
 end subroutine
 !EOC
