@@ -83,7 +83,7 @@ do ioc=1,noptcomp
   allocate(cc1(nstsv,nstsv),cc2(nstsv,nstsv))
   allocate(ce1(nstsv,nstsv),ce2(nstsv,nstsv))
   allocate(cs1(nstsv,nstsv))
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
   do ik=1,nkptnr
 ! distribute among MPI processes
     if (mod(ik-1,np_mpi) /= lp_mpi) cycle
@@ -116,7 +116,7 @@ do ioc=1,noptcomp
           t1=e(m,n)
           if (abs(t1) > swidth) then
             z1=r(m,n,i)/t1
-            r(m,n,i)=cmplx(aimag(z1),-dble(z1),8)
+            r(m,n,i)=zmi*z1
           else
             r(m,n,i)=0.d0
           end if
@@ -186,12 +186,12 @@ do ioc=1,noptcomp
           if (abs(t1) > swidth) then
             t1=1.d0/t1**2
             z1=r(n,m,a)*(d(m,n,b)*r(m,n,c)+d(m,n,c)*r(m,n,b))
-            z1=cmplx(aimag(z1),-dble(z1),8)
+            z1=zmi*z1
             z1=4.d0*f(n,m)*t1*z1
             ce2(m,n)=ce2(m,n)+z1
 ! Eq. (B16b)
             z1=r(n,m,a)*(r(m,n,b)*d(m,n,c)+r(m,n,c)*d(m,n,b))
-            z1=cmplx(-aimag(z1),dble(z1),8)
+            z1=zi*z1
             z1=0.25d0*f(n,m)*t1*z1
             cs1(m,n)=cs1(m,n)+z1
           end if
