@@ -25,22 +25,23 @@ implicit none
 integer, parameter :: maxit=1000
 integer ik,ist,it
 real(8) e0,e1,e,de
+real(8) ei0,ei1,ed0,ed1
 real(8) chg,w,x,t0
 ! external functions
 real(8), external :: sdelta,stheta
 ! determine the smearing width automatically if required
-if ((autoswidth).and.(iscl.gt.1)) call findswidth
+if ((autoswidth).and.(iscl > 1)) call findswidth
 ! find minimum and maximum eigenvalues
 e0=evalsv(1,1)
 e1=e0
 do ik=1,nkpt
   do ist=1,nstsv
     e=evalsv(ist,ik)
-    if (e.lt.e0) e0=e
-    if (e.gt.e1) e1=e
+    if (e < e0) e0=e
+    if (e > e1) e1=e
   end do
 end do
-if (e0.lt.e0min) then
+if (e0 < e0min) then
   write(*,*)
   write(*,'("Warning(occupy): minimum eigenvalue less than minimum &
    &linearisation energy : ",2G18.10)') e0,e0min
@@ -55,7 +56,7 @@ do it=1,maxit
     w=wkpt(ik)
     do ist=1,nstsv
       e=evalsv(ist,ik)
-      if (e.lt.e0min) then
+      if (e < e0min) then
         occsv(ist,ik)=0.d0
       else
         x=(efermi-e)*t0
@@ -64,12 +65,12 @@ do it=1,maxit
       end if
     end do
   end do
-  if (chg.lt.chgval) then
+  if (chg < chgval) then
     e0=efermi
   else
     e1=efermi
   end if
-  if ((e1-e0).lt.1.d-12) goto 10
+  if ((e1-e0) < 1.d-12) goto 10
 end do
 write(*,*)
 write(*,'("Warning(occupy): could not find Fermi energy")')
@@ -83,7 +84,7 @@ do ik=1,nkpt
     x=(evalsv(ist,ik)-efermi)*t0
     fermidos=fermidos+w*sdelta(stype,x)
   end do
-  if (abs(occsv(nstsv,ik)).gt.epsocc) then
+  if (abs(occsv(nstsv,ik)) > epsocc) then
     write(*,*)
     write(*,'("Warning(occupy): not enough empty states for k-point ",I6)') ik
     write(*,'(" and s.c. loop ",I5)') iscl
@@ -92,53 +93,39 @@ end do
 fermidos=fermidos*occmax*t0
 ! write Fermi density of states to test file
 call writetest(500,'DOS at Fermi energy',tol=5.d-3,rv=fermidos)
-! estimate the indirect band gap (FC)
-e0=-1.d8
-e1=1.d8
-ikgap(1)=1
-ikgap(2)=1
-! these loops are inefficiently ordered to fix a bug in versions 17 and 18 of
-! the Intel compiler
-do ist=1,nstsv
-  do ik=1,nkpt
-    e=evalsv(ist,ik)
-    if (e.le.efermi) then
-      if (e.gt.e0) then
-        e0=e
-        ikgap(1)=ik
-      end if
-    else
-      if (e.lt.e1) then
-        e1=e
-        ikgap(2)=ik
-      end if
-    end if
-  end do
-end do
-bandgap(1)=e1-e0
-! write band gap to test file
-call writetest(510,'estimated indirect band gap',tol=2.d-2,rv=bandgap(1))
-! estimate the direct band gap
+! estimate the indirect and direct band gaps (FC)
+ei0=-1.d8; ei1=1.d8
 de=1.d8
-ikgap(3)=1
+ikgap(1:3)=1
 do ik=1,nkpt
-  e0=-1.d8
-  e1=1.d8
+  ed0=-1.d8; ed1=1.d8
   do ist=1,nstsv
     e=evalsv(ist,ik)
-    if (e.le.efermi) then
-      if (e.gt.e0) e0=e
+    if (e <= efermi) then
+      if (e > ed0) ed0=e
+      if (e > ei0) then
+! transfer is a workaround for a bug in Intel Fortran versions 17 and 18
+        ikgap(1)=transfer(ik,ik)
+        ei0=e
+      end if
     else
-      if (e.lt.e1) e1=e
+      if (e < ed1) ed1=e
+      if (e < ei1) then
+        ikgap(2)=ik
+        ei1=e
+      end if
     end if
   end do
-  e=e1-e0
-  if (e.lt.de) then
-    de=e
+  e=ed1-ed0
+  if (e < de) then
     ikgap(3)=ik
+    de=e
   end if
 end do
+bandgap(1)=ei1-ei0
 bandgap(2)=de
+! write band gap to test file
+call writetest(510,'estimated indirect band gap',tol=2.d-2,rv=bandgap(1))
 end subroutine
 !EOC
 
