@@ -20,11 +20,11 @@ e1=e0
 do ik0=1,nkpt0
   do ist=1,nstulr
     e=evalu(ist,ik0)
-    if (e.lt.e0) e0=e
-    if (e.gt.e1) e1=e
+    if (e < e0) e0=e
+    if (e > e1) e1=e
   end do
 end do
-if (e0.lt.e0min) then
+if (e0 < e0min) then
   write(*,*)
   write(*,'("Warning(occupyulr): minimum eigenvalue less than minimum &
    &linearisation energy : ",2G18.10)') e0,e0min
@@ -40,7 +40,7 @@ do it=1,maxit
     ik=(ik0-1)*nkpa+1
     do ist=1,nstulr
       e=evalu(ist,ik0)
-      if (e.lt.e0min) then
+      if (e < e0min) then
         occulr(ist,ik0)=0.d0
       else
         x=(efermi-e)*t1
@@ -49,12 +49,12 @@ do it=1,maxit
       end if
     end do
   end do
-  if (chg.lt.chgval) then
+  if (chg < chgval) then
     e0=efermi
   else
     e1=efermi
   end if
-  if ((e1-e0).lt.1.d-12) return
+  if ((e1-e0) < 1.d-12) return
 end do
 write(*,*)
 write(*,'("Warning(occupyulr): could not find Fermi energy")')
