@@ -13,18 +13,21 @@ complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot)
 complex(8), intent(out) :: o(nmatp,nmatp)
 ! local variables
 integer is,ias,j,nthd
-! zero the upper triangular part of the matrix
-do j=1,nmatp
-  o(1:j,j)=0.d0
-end do
+! interstitial contribution
+call olpistl(ngp,igpig,nmatp,o)
+! APW-APW contribution
 do ias=1,natmtot
   is=idxis(ias)
   call olpaa(tefvr,is,ngp,apwalm(:,:,:,ias),nmatp,o)
 end do
-call olpistl(ngp,igpig,nmatp,o)
+! zero the APW-lo and lo-lo part of the matrix
+do j=ngp+1,nmatp
+  o(1:j,j)=0.d0
+end do
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(is) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
