@@ -28,7 +28,7 @@ use modmain
 implicit none
 ! arguments
 integer, intent(in) :: ngp,igpig(ngkmax),ld
-complex(8), intent(inout) :: o(ld,*)
+complex(8), intent(out) :: o(ld,*)
 ! local variables
 integer ig,j1,j2,j3,i,j
 do j=1,ngp
@@ -37,7 +37,7 @@ do j=1,ngp
   do i=1,j
     ig=igpig(i)
     ig=ivgig(ivg(1,ig)-j1,ivg(2,ig)-j2,ivg(3,ig)-j3)
-    o(i,j)=o(i,j)+cfunig(ig)
+    o(i,j)=cfunig(ig)
   end do
 end do
 end subroutine
