@@ -8,7 +8,7 @@ use modmain
 implicit none
 ! arguments
 integer, intent(in) :: is,ias,ngp,ld
-complex(8), intent(inout) :: o(ld,*)
+complex(8), intent(out) :: o(ld,*)
 ! local variables
 integer ilo,jlo,l,lm,i,j
 do ilo=1,nlorb(is)
@@ -18,7 +18,7 @@ do ilo=1,nlorb(is)
       do lm=l**2+1,(l+1)**2
         i=ngp+idxlo(lm,ilo,ias)
         j=ngp+idxlo(lm,jlo,ias)
-        if (i <= j) o(i,j)=o(i,j)+ololo(ilo,jlo,ias)
+        if (i <= j) o(i,j)=ololo(ilo,jlo,ias)
       end do
     end if
   end do
