@@ -20,9 +20,9 @@ real(8) t1,t2
 complex(8) z1
 ! automatic arrays
 complex(8) u1(ni),u2(no)
-if (ns <= 0) then
+if (ns < 1) then
   write(*,*)
-  write(*,'("Error(pades): ns <= 0 : ",I8)') ns
+  write(*,'("Error(pades): ns < 1 : ",I8)') ns
   write(*,*)
   stop
 end if
