@@ -16,22 +16,15 @@ real(8) tmax,temp(ntemp),s(ntemp)
 real(8) v(3),t1,t2
 ! allocatable arrays
 real(8), allocatable :: wq(:),w(:),gw(:),f(:)
-complex(8), allocatable :: dynq(:,:,:),dynr(:,:,:)
-complex(8), allocatable :: dynp(:,:),ev(:,:)
+complex(8), allocatable :: dq(:,:),ev(:,:)
 ! external functions
 real(8), external :: splint
 ! initialise universal variables
 call init0
 call init2
+call initph
 allocate(wq(nbph),w(nwplot),gw(nwplot),f(nwplot))
-allocate(dynq(nbph,nbph,nqpt),dynr(nbph,nbph,nqptnr))
-allocate(dynp(nbph,nbph),ev(nbph,nbph))
-! read in the dynamical matrices
-call readdyn(dynq)
-! apply the acoustic sum rule
-call sumrule(dynq)
-! Fourier transform the dynamical matrices to real-space
-call dynqtor(dynq,dynr)
+allocate(dq(nbph,nbph),ev(nbph,nbph))
 ! find the minimum and maximum frequencies
 wmin=0.d0
 wmax=0.d0
@@ -58,9 +51,9 @@ do i1=0,ngrkf-1
     do i3=0,ngrkf-1
       v(3)=dble(i3)/dble(ngrkf)
 ! compute the dynamical matrix at this particular q-point
-      call dynrtoq(v,dynr,dynp)
+      call dynrtoq(v,dynr,dq)
 ! find the phonon frequencies
-      call dynev(dynp,wq,ev)
+      call dynev(dq,wq,ev)
       do i=1,nbph
         t1=(wq(i)-wmin)/dw+1.d0
         iw=nint(t1)
@@ -166,6 +159,6 @@ close(50)
 write(*,'(" thermodynamic properties written to THERMO.OUT")')
 ! write phonon DOS to test file
 call writetest(210,'phonon DOS',nv=nwplot,tol=1.d-2,rva=gw)
-deallocate(wq,w,gw,f,dynq,dynr,dynp,ev)
+deallocate(wq,w,gw,f,dq,ev)
 end subroutine
 
