@@ -105,7 +105,7 @@ if (spmass(isph) <= 0.d0) goto 20
 call gengkqvec(iqph)
 ! generate the G+q-vectors and related quantities
 call gengqvec(iqph)
-! generate the regularised Coulomb Green's function in G+q-space
+! generate the Coulomb Green's function in G+q-space
 call gengclgq(.false.,iqph,ngvec,gqc,gclgq)
 ! generate the characteristic function derivative
 call gendcfun
@@ -152,7 +152,7 @@ do iscl=1,maxscl
   allocate(dapwalmq(ngkmax,apwordmax,lmmaxapw,nspnfv))
   allocate(evecfv(nmatmax,nstfv,nspnfv),devecfv(nmatmax,nstfv,nspnfv))
   allocate(evecsv(nstsv,nstsv),devecsv(nstsv,nstsv))
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
   do ik=1,nkptnr
 ! distribute among MPI processes
     if (mod(ik-1,np_mpi) /= lp_mpi) cycle
@@ -216,13 +216,18 @@ devalsv(:,ik)=devalfv(:,1,ik)
     call mpi_bcast(devalfv(:,:,ik),n,mpi_double_precision,lp,mpicom,ierror)
     call mpi_bcast(devalsv(:,ik),nstsv,mpi_double_precision,lp,mpicom,ierror)
   end do
-! convert to spherical harmonic representation
+! convert muffin-tin density/magnetisation derivatives to spherical harmonics
   call drhomagsh
 ! convert from a coarse to a fine radial mesh
   call zfmtctof(drhomt)
   do idm=1,ndmag
     call zfmtctof(dmagmt(:,:,idm))
   end do
+! convert interstitial density/magnetisation derivatives to fine grid
+  call zfirctof(drhoir,drhoir)
+  do idm=1,ndmag
+    call zfirctof(dmagir(:,idm),dmagir(:,idm))
+  end do
 ! add densities from each process and redistribute
   if (np_mpi > 1) then
     n=npmtmax*natmtot
@@ -245,6 +250,8 @@ devalsv(:,ik)=devalfv(:,1,ik)
   call gradrhomt
 ! compute the Kohn-Sham potential derivative
   call dpotks
+! Fourier transform Kohn-Sham potential derivative to G+q-space
+  call gendvsig
 ! mix the old potential and field with the new
   call mixerifc(mtype,nmix,dvsbs,ddv,nwork,work)
   if (mp_mpi) then
@@ -259,8 +266,6 @@ devalsv(:,ik)=devalfv(:,1,ik)
   end if
 ! broadcast tlast from master process to all other processes
   call mpi_bcast(tlast,1,mpi_logical,0,mpicom,ierror)
-! Fourier transform Kohn-Sham potential derivative to G+q-space
-  call gendvsig
 ! compute the occupation number derivatives
   call doccupy
 ! end the self-consistent loop
