@@ -19,8 +19,8 @@ complex(8) z1,z2
 real(8), allocatable :: vsmt0(:,:),vsir0(:)
 complex(8), allocatable :: dyn(:,:)
 ! store original parameters
-natoms0(:)=natoms(:)
 avec0(:,:)=avec(:,:)
+natoms0(:)=natoms(:)
 atposl0(:,:,:)=atposl(:,:,:)
 bfcmt00(:,:,:)=bfcmt0(:,:,:)
 mommtfix0(:,:,:)=mommtfix(:,:,:)
@@ -105,11 +105,7 @@ else
   nph=1
 end if
 ! initialise or read the charge density and potentials from file
-if (task == 200) then
-  trdstate=.false.
-else
-  trdstate=.true.
-end if
+trdstate=(task == 201)
 ! loop over cos and sin displacements
 do p=0,nph
 ! generate the supercell with negative displacement
