@@ -42,7 +42,9 @@ do istrain=1,nstrain
     write(*,'("Info(piezoelt): working on strain tensor ",I1," of ",I1)') &
      istrain,nstrain
   end if
-! run the ground-state calculation again
+! restore the lattice vectors
+  avec(:,:)=avec0(:,:)
+! run the ground-state calculation
   call gndstate
 ! compute the second polarisation
   call polar(pvl2)
@@ -90,10 +92,11 @@ if (mp_mpi) then
   write(*,'(" Piezoelectric tensor written to PIEZOELT.OUT")')
 end if
 ! write test file if required
-call writetest(380,'Piezoelectric tensor',nv=3*nstrain,tol=1.d-5,rva=pelt)
+call writetest(380,'Piezoelectric tensor',nv=3*nstrain,tol=5.d-5,rva=pelt)
 deallocate(pelt)
 ! restore original parameters
-tshift=tshift0
+istrain=0
 avec(:,:)=avec0(:,:)
+tshift=tshift0
 end subroutine
 
