@@ -35,7 +35,7 @@ integer np,jf,ip
 real(8) vpnl(3)
 ! allocatable arrays
 real(8), allocatable :: vpl(:,:),vppc(:,:),fp(:,:)
-if ((nf.lt.1).or.(nf.gt.4)) then
+if ((nf < 1).or.(nf > 4)) then
   write(*,*)
   write(*,'("Error(plot2d): invalid number of functions : ",I8)') nf
   write(*,*)
@@ -51,7 +51,7 @@ do jf=1,nf
   call rfplot(np,vpl,rfmt(:,:,jf),rfir(:,jf),fp(:,jf))
 end do
 ! project the vector function onto the 2D plotting plane axes if required
-if (tproj.and.(nf.eq.3)) then
+if (tproj.and.(nf == 3)) then
   call proj2d(np,fp)
 end if
 ! write the functions to file
