@@ -3,7 +3,7 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine plotpt3d(vpl)
+pure subroutine plotpt3d(vpl)
 use modmain
 implicit none
 ! arguments
@@ -28,6 +28,5 @@ do i3=0,np3d(3)-1
     end do
   end do
 end do
-return
 end subroutine
 
