@@ -15,7 +15,7 @@ integer jf,ip,iv
 real(8) fmin,fmax,t1
 ! allocatable arrays
 real(8), allocatable :: fp(:,:)
-if ((nf.lt.1).or.(nf.gt.4)) then
+if ((nf < 1).or.(nf > 4)) then
   write(*,*)
   write(*,'("Error(plotu1d): invalid number of functions : ",I8)') nf
   write(*,*)
@@ -26,7 +26,7 @@ allocate(fp(npp1d,nf))
 call plotpt1d(avec,nvp1d,npp1d,vvlp1d,vplp1d,dvp1d,dpp1d)
 ! evaluate function at each point
 call plotulr(npp1d,vplp1d,nf,zfmt,zfir,fp)
-do ip=1,npp1d
+do ip=ip01d,npp1d
 ! write the point distances and function to file
   write(fnum1,'(5G18.10)') dpp1d(ip),(fp(ip,jf),jf=1,nf)
 end do
