@@ -16,7 +16,7 @@ integer np,jf,ip
 real(8) vpnl(3)
 ! allocatable arrays
 real(8), allocatable :: vpl(:,:),vppc(:,:),fp(:,:)
-if ((nf.lt.1).or.(nf.gt.4)) then
+if ((nf < 1).or.(nf > 4)) then
   write(*,*)
   write(*,'("Error(plotu2d): invalid number of functions : ",I8)') nf
   write(*,*)
@@ -30,7 +30,7 @@ call plotpt2d(avec,ainv,vpnl,vpl,vppc)
 ! evaluate the functions at the grid points
 call plotulr(np,vpl,nf,zfmt,zfir,fp)
 ! project the vector function onto the 2D plotting plane if required
-if (tproj.and.(nf.eq.3)) then
+if (tproj.and.(nf == 3)) then
   call proj2d(np,fp)
 end if
 ! write the functions to file
