@@ -15,7 +15,7 @@ integer np,jf,ip
 real(8) v1(3)
 ! allocatable arrays
 real(8), allocatable :: vpl(:,:),fp(:,:)
-if ((nf.lt.1).or.(nf.gt.4)) then
+if ((nf < 1).or.(nf > 4)) then
   write(*,*)
   write(*,'("Error(plotu3d): invalid number of functions : ",I8)') nf
   write(*,*)
