@@ -24,7 +24,7 @@ call holdthd(nfqrz/np_mpi,nthd)
 !$OMP NUM_THREADS(nthd)
 allocate(zrhomt(npmtmax,natmtot),zrhoir(ngtot))
 allocate(zvclmt(npmtmax,natmtot))
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do ifq=1,nfqrz
 ! distribute among MPI processes
   if (mod(ifq-1,np_mpi) /= lp_mpi) cycle
@@ -56,7 +56,7 @@ do ifq=1,nfqrz
 ! convert the interstitial density from coarse to fine grid
   call zfirctof(rhoqir(:,ifq),zrhoir)
 ! solve Poisson's equation in the entire unit cell
-  call zpotcoul(nrmt,nrmti,npmt,nrmtmax,rlmt,ngridg,igfft,ngvec,gqc(:,ifq), &
+  call zpotcoul(0,nrmt,nrmti,npmt,nrmtmax,rlmt,ngridg,igfft,ngvec,gqc(:,ifq), &
    gclgq(:,ifq),ngvec,jlgqrmt(:,:,:,ifq),ylmgq(:,:,ifq),sfacgq(:,:,ifq),zrhoir,&
    npmtmax,zvclmt,vsqir(:,ifq))
   do ias=1,natmtot
