@@ -31,7 +31,7 @@ do is=1,nspecies
     ias=idxas(ia,is)
 ! coefficient for R_00
     e00=v0-dot_product(efieldc(:),atposc(:,ia,is))
-    e00=e00/y00
+    e00=e00*y00i
     i=1
     do ir=1,nr
       r=rsp(ir,is)
