@@ -40,7 +40,7 @@ if (xctype(1) < 0) call oepmain
 ! remove the source term of the exchange-correlation magnetic field if required
 if (spinpol.and.nosource) call projsbf
 ! trim the exchange-correlation potential for |G| > 2 gkmax
-if (trimvg) call trimrfg(vxcir)
+call trimrfg(vxcir)
 ! effective potential from sum of Coulomb and exchange-correlation potentials
 do ias=1,natmtot
   is=idxis(ias)
