@@ -12,6 +12,8 @@ real(8) ts0,ts1
 call timesec(ts0)
 ! compute the ultra long-range Coulomb potential
 call potcoulu
+! compute the ultra long-range dipole-dipole magnetic field if required
+if (tbdipu) call bdipoleu
 ! compute the ultra long-range exchange-correlation potential and fields
 call potxcu
 ! reduce the external magnetic field if required
