@@ -8,9 +8,7 @@ use modmain
 use modulr
 implicit none
 ! local variables
-integer ifq,ias,is,npc
-! allocatable arrays
-complex(8), allocatable :: zfmt(:)
+integer ifq,ias,is
 ! initialise universal variables
 call init0
 call init1
@@ -19,16 +17,12 @@ call initulr
 ! read in the Kohn-Sham potential from STATE_ULR.OUT
 call readstulr
 ! convert potential to spherical harmonics
-allocate(zfmt(npcmtmax))
 do ifq=1,nfqrz
   do ias=1,natmtot
     is=idxis(ias)
-    npc=npcmt(is)
-    zfmt(1:npc)=vsqmt(1:npc,ias,ifq)
-    call zfsht(nrcmt(is),nrcmti(is),zfmt,vsqmt(:,ias,ifq))
+    call zfshtip(nrcmt(is),nrcmti(is),vsqmt(:,ias,ifq))
   end do
 end do
-deallocate(zfmt)
 ! write the density plot to file
 select case(task)
 case(741)
