@@ -51,15 +51,13 @@ end do
 !$OMP SINGLE
 call potxcir(xctype_,rhoir_,magir_,tauir_,exir_,ecir_,vxcir_,bxcir_,wxcir_)
 !$OMP END SINGLE
-! symmetrise the exchange-correlation potential and magnetic field
+! symmetrise the muffin-tin exchange-correlation potentials and magnetic fields
 if (tsh) then
 !$OMP SECTIONS
 !$OMP SECTION
-  call symrf(nrmt,nrmti,npmt,ngridg,ngtot,ngvec,nfgrz,igfft,igrzf,npmtmax, &
-   vxcmt_,vxcir_)
+  call symrfmt(nrmt,nrmti,npmt,npmtmax,vxcmt_)
 !$OMP SECTION
-  if (spinpol) call symrvf(.true.,ncmag,nrmt,nrmti,npmt,ngridg,ngtot,ngvec, &
-   nfgrz,igfft,igrzf,npmtmax,bxcmt_,ngtot,bxcir_)
+  if (spinpol) call symrvfmt(.true.,ncmag,nrmt,nrmti,npmt,npmtmax,bxcmt_)
 !$OMP END SECTIONS
 end if
 !$OMP END PARALLEL
