@@ -147,7 +147,7 @@ if (spinpol) then
     end do
   end if
 ! call the exchange-correlation interface routine
-  if (xcgrad <= 0) then
+  if (xcgrad < 1) then
     call xcifc(xctype_,n,tempa=swidth,rhoup=rhoup,rhodn=rhodn,ex=ex,ec=ec, &
      vxup=vxup,vxdn=vxdn,vcup=vcup,vcdn=vcdn)
   else if (xcgrad == 1) then
@@ -236,7 +236,7 @@ else
 !--------------------------!
 !     spin-unpolarised     !
 !--------------------------!
-  if (xcgrad <= 0) then
+  if (xcgrad < 1) then
     call xcifc(xctype_,n,tempa=swidth,rho=rho,ex=ex,ec=ec,vx=vx,vc=vc)
   else if (xcgrad == 1) then
     call ggamt_1(tsh,is,n,rhomt_(:,ias),grho,g2rho,g3rho)
