@@ -37,7 +37,7 @@ if (spinpol) then
   allocate(magmt_(npmtmax,natmtot,ndmag),magir_(ngtot,ndmag))
   allocate(bxcmt_(npmtmax,natmtot,ndmag))
 end if
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do ir=1,nqpt
 ! distribute among MPI processes
   if (mod(ir-1,np_mpi) /= lp_mpi) cycle
@@ -112,7 +112,7 @@ call holdthd(2*nfqrz,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(z1,ias,is,npc) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do ifq=1,nfqrz
   z1=vclq(ifq)
   do ias=1,natmtot
@@ -122,10 +122,10 @@ do ifq=1,nfqrz
   end do
 end do
 !$OMP END DO NOWAIT
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do ifq=1,nfqrz
   z1=vclq(ifq)
-  vsqir(:,ifq)=vsqir(:,ifq)+vxcqir(:,ifq)+z1
+  vsqir(1:ngtot,ifq)=vsqir(1:ngtot,ifq)+vxcqir(1:ngtot,ifq)+z1
 end do
 !$OMP END DO
 !$OMP END PARALLEL
@@ -140,10 +140,11 @@ if (spinpol) then
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(idm,z1,z2,ias,is,npc) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
   do ifq=1,nfqrz
     do idm=1,ndmag
       z1=bfcq(idm,ifq)
+      if (tbdipu) z1=z1+bdipq(idm,ifq)
       do ias=1,natmtot
         is=idxis(ias)
         npc=npcmt(is)
@@ -153,11 +154,12 @@ if (spinpol) then
     end do
   end do
 !$OMP END DO NOWAIT
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
   do ifq=1,nfqrz
     do idm=1,ndmag
       z1=bfcq(idm,ifq)
-      bsqir(:,idm,ifq)=bsqir(:,idm,ifq)+z1
+      if (tbdipu) z1=z1+bdipq(idm,ifq)
+      bsqir(1:ngtot,idm,ifq)=bsqir(1:ngtot,idm,ifq)+z1
     end do
   end do
 !$OMP END DO
