@@ -23,7 +23,7 @@ call r3cross(vc1,vc2,vc3)
 t1=sqrt(vc1(1)**2+vc1(2)**2+vc1(3)**2)
 t2=sqrt(vc2(1)**2+vc2(2)**2+vc2(3)**2)
 t3=sqrt(vc3(1)**2+vc3(2)**2+vc3(3)**2)
-if ((t1.lt.epslat).or.(t2.lt.epslat).or.(t3.lt.epslat)) then
+if ((t1 < epslat).or.(t2 < epslat).or.(t3 < epslat)) then
   write(*,*)
   write(*,'("Error(proj2d): degenerate 2D plotting directions")')
   write(*,*)
