@@ -11,10 +11,10 @@ implicit none
 ! arguments
 logical, intent(in) :: tfv,tvclcr
 integer, intent(in) :: ik
-real(8), intent(in) :: vmt(npcmtmax,natmtot),vir(ngtot)
-real(8), intent(in) :: bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag)
+real(8), intent(in) :: vmt(npcmtmax,natmtot),vir(ngtc)
+real(8), intent(in) :: bmt(npcmtmax,natmtot,ndmag),bir(ngtc,ndmag)
 ! local variables
-integer ist,ispn,recl
+integer jst,ispn,recl
 ! automatic arrays
 complex(8) kmat(nstsv,nstsv),a(nstsv,nstsv)
 ! allocatable arrays
@@ -43,11 +43,11 @@ else
   call genvmatk(vmt,vir,ngk(:,ik),igkig(:,:,ik),wfmt,ngkmax,wfgk,kmat)
 end if
 deallocate(wfgk)
-! negate the potential matrix elements because we have to subtract them
-kmat(:,:)=-kmat(:,:)
-! add second-variational eigenvalues along the diagonal
-do ist=1,nstsv
-  kmat(ist,ist)=kmat(ist,ist)+evalsv(ist,ik)
+! negate the potential matrix elements because we have to subtract them and add
+! the second-variational eigenvalues along the diagonal
+do jst=1,nstsv
+  kmat(1:nstsv,jst)=-kmat(1:nstsv,jst)
+  kmat(jst,jst)=kmat(jst,jst)+evalsv(jst,ik)
 end do
 ! add the Coulomb core matrix elements if required
 if (tvclcr) call vclcore(wfmt,kmat)
@@ -62,14 +62,14 @@ deallocate(evecsv,wfmt)
 !$OMP CRITICAL(u220)
 ! write to RAM disk if required
 if (ramdisk) then
-  call putrd('KMAT.OUT',ik,v1=vkl(:,ik),n1=nstsv,nzv=nstsv*nstsv,zva=kmat)
+  call putrd('KMAT.OUT',ik,v1=vkl(1:3,ik),n1=nstsv,nzv=nstsv*nstsv,zva=kmat)
 end if
 ! write to disk if required
 if (wrtdsk) then
 ! determine the record length
-  inquire(iolength=recl) vkl(:,1),nstsv,kmat
+  inquire(iolength=recl) vkl(1:3,1),nstsv,kmat
   open(220,file='KMAT.OUT',form='UNFORMATTED',access='DIRECT',recl=recl)
-  write(220,rec=ik) vkl(:,ik),nstsv,kmat
+  write(220,rec=ik) vkl(1:3,ik),nstsv,kmat
   close(220)
 end if
 !$OMP END CRITICAL(u220)
