@@ -48,9 +48,9 @@ real(8) t1,de
 real(8) g1(nr),f1(nr),fr(nr)
 ! external functions
 real(8), external :: splint
-if (k <= 0) then
+if (k < 1) then
   write(*,*)
-  write(*,'("Error(rdirac): k <= 0 : ",I8)') k
+  write(*,'("Error(rdirac): k < 1 : ",I8)') k
   write(*,*)
   stop
 end if
@@ -96,7 +96,7 @@ do it=1,maxit
   end if
   if (it > 1) then
     if ((nnd /= 0).or.(nndp /= 0)) then
-      if (nnd*nndp <= 0) then
+      if (nnd*nndp < 1) then
         de=de*0.5d0
       else
         de=de*1.1d0
