@@ -15,11 +15,9 @@ pure subroutine rdiracint(sol,kpa,e,nr,r,vr,nn,g0,g1,f0,f1)
 !   r    : radial mesh (in,real(nr))
 !   vr   : potential on radial mesh (in,real(nr))
 !   nn   : number of nodes (out,integer)
-!   g0   : m th energy derivative of the major component multiplied by r
-!          (out,real(nr))
+!   g0   : major component multiplied by r (out,real(nr))
 !   g1   : radial derivative of g0 (out,real(nr))
-!   f0   : m th energy derivative of the minor component multiplied by r
-!          (out,real(nr))
+!   f0   : minor component multiplied by r (out,real(nr))
 !   f1   : radial derivative of f0 (out,real(nr))
 ! !DESCRIPTION:
 !   Integrates the radial Dirac equation from $r=0$ outwards. This involves
@@ -98,10 +96,8 @@ do ir=2,nr
   if ((abs(g0(ir)) > rsc).or.(abs(g1(ir)) > rsc).or. &
       (abs(f0(ir)) > rsc).or.(abs(f1(ir)) > rsc)) then
 ! set the remaining points and return
-    g0(ir:nr)=g0(ir)
-    g1(ir:nr)=g1(ir)
-    f0(ir:nr)=f0(ir)
-    f1(ir:nr)=f1(ir)
+    g0(ir+1:nr)=g0(ir); g1(ir+1:nr)=g1(ir)
+    f0(ir+1:nr)=f0(ir); f1(ir+1:nr)=f1(ir)
     return
   end if
 ! check for node
