@@ -28,13 +28,13 @@ integer ik1,ik2,jk,iv(3)
 integer ist1,ist2,ist3,ist4
 real(8) t1,t2,t3
 ! allocatable arrays
-complex(8), allocatable :: vclijjk(:,:,:,:),evecsv(:,:)
-if (rdmxctype.eq.0) return
+complex(8), allocatable :: vcl1223(:,:,:,:),evecsv(:,:)
+if (rdmxctype == 0) return
 ! calculate the prefactor
-if (rdmxctype.eq.1) then
+if (rdmxctype == 1) then
 ! Hartree-Fock functional
   t1=1.d0/occmax
-else if (rdmxctype.eq.2) then
+else if (rdmxctype == 2) then
 ! Power functional
   if (spinpol) then
     t1=1.d0
@@ -47,12 +47,12 @@ else
   write(*,*)
   stop
 end if
-allocate(vclijjk(nstsv,nstsv,nstsv,nkpt))
+allocate(vcl1223(nstsv,nstsv,nstsv,nkpt))
 allocate(evecsv(nstsv,nstsv))
 ! start loop over non-reduced k-points
 do ik1=1,nkptnr
 ! get the Coulomb matrix elements
-  call getvclijjk(ik1,vclijjk)
+  call getvcl1223(ik1,vcl1223)
 ! find the equivalent reduced k-point
   iv(:)=ivk(:,ik1)
   jk=ivkik(iv(1),iv(2),iv(3))
@@ -64,20 +64,20 @@ do ik1=1,nkptnr
       do ist3=1,nstsv
         do ist2=1,nstsv
           do ist1=1,nstsv
-            if (rdmxctype.eq.1) then
+            if (rdmxctype == 1) then
 ! Hartree-Fock functional
               t2=t1*occsv(ist3,ik2)*occsv(ist4,jk)
-            else if (rdmxctype.eq.2) then
+            else if (rdmxctype == 2) then
 ! Power functional
               t3=sum(abs(vkl(:,ik2)-vkl(:,ik1)))
-              if ((ist3.eq.ist4).and.(t3.lt.epslat)) then
+              if ((ist3 == ist4).and.(t3 < epslat)) then
                 t2=(1.d0/occmax)*occsv(ist4,jk)**2
               else
                 t2=t1*(occsv(ist3,ik2)*occsv(ist4,jk))**rdmalpha
               end if
             end if
             dedc(ist2,ist3,ik2)=dedc(ist2,ist3,ik2)-t2*evecsv(ist2,ist1)* &
-             vclijjk(ist1,ist3,ist4,ik2)
+             vcl1223(ist1,ist3,ist4,ik2)
           end do
         end do
       end do
@@ -86,7 +86,7 @@ do ik1=1,nkptnr
   end do
 ! end loop over non-reduced k-points
 end do
-deallocate(vclijjk,evecsv)
+deallocate(vcl1223,evecsv)
 end subroutine
 !EOC
 
