@@ -19,6 +19,8 @@ use modmpi
 !EOP
 !BOC
 implicit none
+! local variables
+character(64) str
 ! initialise global variables
 call init0
 call init1
@@ -56,18 +58,13 @@ if (mp_mpi) then
   open(65,file='RDM_ENERGY.OUT',form='FORMATTED')
 ! write out general information to RDM_INFO.OUT
   call writeinfo(60)
-  write(60,*)
-  write(60,'("+------------------------------+")')
-  write(60,'("| Self-consistent loop started |")')
-  write(60,'("+------------------------------+")')
+  call writebox(60,"Self-consistent loop started")
 end if
 ! begin main RDMFT self-consistent loop
 do iscl=1,rdmmaxscl
   if (mp_mpi) then
-    write(60,*)
-    write(60,'("+--------------------+")')
-    write(60,'("| Loop number : ",I4," |")') iscl
-    write(60,'("+--------------------+")')
+    write(str,'("Loop number : ",I0)') iscl
+    call writebox(60,trim(str))
     flush(60)
     write(*,'("Info(rdmft): self-consistent loop number : ",I4)') iscl
   end if
@@ -90,18 +87,11 @@ do iscl=1,rdmmaxscl
   end if
 end do
 if (mp_mpi) then
-  write(60,*)
-  write(60,'("+------------------------------+")')
-  write(60,'("| Self-consistent loop stopped |")')
-  write(60,'("+------------------------------+")')
+  call writebox(60,"Self-consistent loop stopped")
 ! write density to STATE.OUT
   call writestate
   write(60,*)
   write(60,'("Wrote STATE.OUT")')
-  write(60,*)
-  write(60,'("+----------------------------+")')
-  write(60,'("| Elk version ",I1.1,".",I1.1,".",I2.2," stopped |")') version
-  write(60,'("+----------------------------+")')
 ! close information files
   close(60)
   close(61)
