@@ -30,7 +30,7 @@ call rdmdedc(dedc)
 allocate(evecsv(nstsv,nstsv))
 do ik=1,nkpt
 ! distribute among MPI processes
-  if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
+  if (mod(ik-1,np_mpi) /= lp_mpi) cycle
 ! get the eigenvectors from file
   call getevecsv(filext,ik,vkl(:,ik),evecsv)
 ! calculate new evecsv
