@@ -10,7 +10,7 @@ implicit none
 integer ios
 open(50,file='AFINDT.OUT',form='FORMATTED',action='READ',status='OLD', &
  iostat=ios)
-if (ios.ne.0) then
+if (ios /= 0) then
   write(*,*)
   write(*,'("Error(readafindt): error opening AFINDT.OUT")')
   write(*,*)
