@@ -13,6 +13,8 @@ integer is_,ia_,ispn_,jspn_
 integer l,ll,m1,m2,lm1,lm2
 integer l_,m1_,m2_
 real(8) a,b
+! zero the density matrix
+dmatmt(:,:,:,:,:)=0.d0
 ! read density matrix from DMATMT.OUT
 open(50,file='DMATMT'//trim(filext),form='FORMATTED')
 do idu=1,ndftu
@@ -24,7 +26,7 @@ do idu=1,ndftu
     read(50,*)
     read(50,*)
     read(50,*) is_,ia_,l_
-    if ((is.ne.is_).or.(ia.ne.ia_).or.(l.ne.l_)) then
+    if ((is /= is_).or.(ia /= ia_).or.(l /= l_)) then
       write(*,*)
       write(*,'("Error(readdmatmt): differing is, ia or l")')
       write(*,'(" current    : ",3I4)') is,ia,l
@@ -36,7 +38,7 @@ do idu=1,ndftu
       do jspn=1,nspinor
         read(50,*)
         read(50,*) ispn_,jspn_
-        if ((ispn.ne.ispn_).or.(jspn.ne.jspn_)) then
+        if ((ispn /= ispn_).or.(jspn /= jspn_)) then
           write(*,*)
           write(*,'("Error(readdmatmt): differing ispn or jspn")')
           write(*,'(" current    : ",2I4)') ispn,jspn
@@ -49,7 +51,7 @@ do idu=1,ndftu
           do m2=-l,l
             lm2=ll+m2
             read(50,*) m1_,m2_,a,b
-            if ((m1.ne.m1_).or.(m2.ne.m2_)) then
+            if ((m1 /= m1_).or.(m2 /= m2_)) then
               write(*,*)
               write(*,'("Error(readdmatmt): differing m1 or m2")')
               write(*,'(" current    : ",2I6)') m1,m2
