@@ -22,7 +22,7 @@ open(250,file='EMD.OUT',form='UNFORMATTED',access='DIRECT',recl=recl)
 do ik=1,nkpt
   read(250,rec=ik) vkl_,nhk_,emd
   t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
-  if (t1.gt.epslat) then
+  if (t1 > epslat) then
     write(*,*)
     write(*,'("Error(reademd): differing vectors for k-point ",I8)') ik
     write(*,'(" current : ",3G18.10)') vkl(:,ik)
@@ -30,7 +30,7 @@ do ik=1,nkpt
     write(*,*)
     stop
   end if
-  if (nhk(1,ik).ne.nhk_) then
+  if (nhk(1,ik) /= nhk_) then
     write(*,*)
     write(*,'("Error(reademd): differing nhk for k-point ",I8)') ik
     write(*,'(" current : ",I8)') nhk(1,ik)
