@@ -379,6 +379,7 @@ epsdmat=1.d-8
 tm3old=.false.
 batch=.false.
 tafspt=.false.
+tbaspat=.false.
 trdatdv=.false.
 atdfc=0.d0
 maxforce=-1.d0
@@ -2144,6 +2145,8 @@ case('batch')
   read(50,*,err=20) batch
 case('tafspt')
   read(50,*,err=20) tafspt
+case('tbaspat')
+  read(50,*,err=20) tbaspat
 case('trdatdv')
   read(50,*,err=20) trdatdv
 case('atdfc')
