@@ -61,8 +61,8 @@ end if
 if (any(version(:) /= version_(:))) then
   write(*,*)
   write(*,'("Warning(readstate): different versions")')
-  write(*,'(" current   : ",I3.3,".",I3.3,".",I3.3)') version
-  write(*,'(" STATE.OUT : ",I3.3,".",I3.3,".",I3.3)') version_
+  write(*,'(" current   : ",I0,".",I0,".",I0)') version
+  write(*,'(" STATE.OUT : ",I0,".",I0,".",I0)') version_
 end if
 read(100) spinpol_
 read(100) nspecies_
@@ -118,7 +118,7 @@ if ((version_(1) > 5).or.((version_(1) == 5).and.(version_(2) >= 1))) then
 else
   xcgrad_=0
 end if
-if ((version_(1) > 10).or.((version_(1) == 9).and.(version_(2) >= 6))) then
+if ((version_(1) >= 10).or.((version_(1) == 9).and.(version_(2) >= 6))) then
   read(100) efermi
 else
   call readfermi
@@ -157,15 +157,15 @@ read(100) rfmt_,rfir_
 ! regrid and pack the muffin-tin function
 call rgfmt(rhomt)
 ! regrid the interstitial function
-rhoir(:)=rfir_(mapir(:))
+rhoir(1:ngtot)=rfir_(mapir(1:ngtot))
 ! read the Coulomb potential, regrid and pack
 read(100) rfmt_,rfir_
 call rgfmt(vclmt)
-vclir(:)=rfir_(mapir(:))
+vclir(1:ngtot)=rfir_(mapir(1:ngtot))
 ! read the exchange-correlation potential, regrid and pack
 read(100) rfmt_,rfir_
 call rgfmt(vxcmt)
-vxcir(:)=rfir_(mapir(:))
+vxcir(1:ngtot)=rfir_(mapir(1:ngtot))
 ! read the Kohn-Sham effective potential, regrid and pack
 if ((version_(1) > 2).or.(version_(2) >= 2)) then
   read(100) rfmt_,rfir_
@@ -175,7 +175,9 @@ else
   deallocate(vsig_)
 end if
 call rgfmt(vsmt)
-vsir(:)=rfir_(mapir(:))
+vsir(1:ngtot)=rfir_(mapir(1:ngtot))
+! compute the Kohn-Sham potential on coarse interstitial grid
+call rfirftoc(vsir,vsirc)
 ! read the magnetisation, exchange-correlation and effective magnetic fields
 if (spinpol_) then
 ! component map for spin-polarised case
@@ -199,6 +201,10 @@ if (spinpol_) then
   read(100) rvfcmt_,rvfir_
   call rgvfcmt(bsmt)
   call rgvir(bsir)
+! compute the Kohn-Sham magnetic field on coarse interstitial grid
+  do idm=1,ndmag
+    call rfirftoc(bsir(:,idm),bsirc(:,idm))
+  end do
   deallocate(rvfmt_,rvfir_,rvfcmt_)
 ! read fixed spin moment effective fields
   if (fsmtype_ /= 0) then
@@ -229,10 +235,10 @@ if (any(xcgrad == [3,4,5])) then
   if (any(xcgrad_ == [3,4,5])) then
     read(100) rfmt_,rfir_
     call rgfmt(wxcmt)
-    wxcir(:)=rfir_(mapir(:))
+    wxcir(1:ngtot)=rfir_(mapir(1:ngtot))
   else
     wxcmt(:,:)=0.d0
-    wxcir(:)=0.d0
+    wxcir(1:ngtot)=0.d0
   end if
 end if
 deallocate(wcrmt_,wcrcmt_,rfmt_,rfir_,rfmt,fi,fo)
@@ -349,9 +355,9 @@ real(8), intent(out) :: rvfir(ngtot,ndmag)
 do idm=1,ndmag
   jdm=mapidm(idm)
   if (jdm /= 0) then
-    rvfir(:,idm)=rvfir_(mapir(:),jdm)
+    rvfir(1:ngtot,idm)=rvfir_(mapir(1:ngtot),jdm)
   else
-    rvfir(:,idm)=0.d0
+    rvfir(1:ngtot,idm)=0.d0
   end if
 end do
 end subroutine
