@@ -97,16 +97,16 @@ if (fsmtype /= fsmtype_) then
   stop
 end if
 read(100) nqpt_
-if (nqpt_ <= 0) then
+if (nqpt_ < 1) then
   write(*,*)
-  write(*,'("Error(readstulr): nqpt_ <= 0 : ",I8)') nqpt_
+  write(*,'("Error(readstulr): nqpt_ < 1 : ",I8)') nqpt_
   write(*,*)
   stop
 end if
 read(100) nfqrz_
-if (nfqrz_ <= 0) then
+if (nfqrz_ < 1) then
   write(*,*)
-  write(*,'("Error(readstulr): nfqrz_ <= 0 : ",I8)') nfqrz_
+  write(*,'("Error(readstulr): nfqrz_ < 1 : ",I8)') nfqrz_
   write(*,*)
   stop
 end if
