@@ -11,27 +11,27 @@ implicit none
 integer ios
 real(8) times_,t1
 open(50,file='TIMESTEP.OUT',form='FORMATTED',status='OLD',iostat=ios)
-if (ios.ne.0) then
+if (ios /= 0) then
   write(*,*)
   write(*,'("Error(readtimes): error opening TIMESTEP.OUT")')
   write(*,*)
   stop
 end if
 read(50,*,iostat=ios) itimes0,times_
-if (ios.ne.0) then
+if (ios /= 0) then
   write(*,*)
   write(*,'("Error(readtimes): error reading time step from TIMESTEP.OUT")')
   write(*,*)
   stop
 end if
-if ((itimes0.lt.1).or.(itimes0.gt.ntimes)) then
+if ((itimes0 < 1).or.(itimes0 > ntimes)) then
   write(*,*)
   write(*,'("Error(readtimes): invalid itimes : ",I8)') itimes0
   write(*,*)
   stop
 end if
 t1=abs(times(itimes0)-times_)
-if (t1.gt.1.d-8) then
+if (t1 > 1.d-8) then
   write(*,*)
   write(*,'("Error(readtimes): differing time step")')
   write(*,'(" current      : ",G18.10)') times(itimes0)
