@@ -10,13 +10,12 @@ implicit none
 ! local variables
 integer i1,i2,i3,ir
 integer ngridq_(3),i1_,i2_,i3_
-! allocatable arrays
-real(8), allocatable :: vclr(:)
-allocate(vclr(nqpt))
+! automatic arrays
+real(8) vclr(nqpt)
 ! read the real-space external Coulomb potential from file
 open(50,file='VCLR.OUT',form='FORMATTED')
-read(50,*) ngridq_(:)
-if (any(ngridq(:) /= ngridq_(:))) then
+read(50,*) ngridq_(1:3)
+if (any(ngridq(1:3) /= ngridq_(1:3))) then
   write(*,*)
   write(*,'("Error(readvclr): differing ngridq")')
   write(*,'(" current  : ",3I6)') ngridq
@@ -44,6 +43,5 @@ end do
 close(50)
 ! Fourier transform external Coulomb potential from real-space to Q-space
 call rzfftifc(3,ngridq,-1,vclr,vclq)
-deallocate(vclr)
 end subroutine
 
