@@ -30,8 +30,7 @@ subroutine reciplat(avec,bvec,omega,omegabz)
 implicit none
 ! arguments
 real(8), intent(in) :: avec(3,3)
-real(8), intent(out) :: bvec(3,3)
-real(8), intent(out) :: omega,omegabz
+real(8), intent(out) :: bvec(3,3),omega,omegabz
 ! local variables
 real(8), parameter :: twopi=6.2831853071795864769d0
 real(8) t1
