@@ -13,12 +13,12 @@ integer is,ias
 ! external functions
 real(8), external :: rfmtint
 ! interstitial contribution
-rfint=dot_product(rfir(:),cfunir(:))
+rfint=dot_product(rfir(1:ngtot),cfunir(1:ngtot))
 rfint=rfint*omega/dble(ngtot)
 ! muffin-tin contribution
 do ias=1,natmtot
   is=idxis(ias)
-  rfint=rfint+rfmtint(nrmt(is),nrmti(is),wrmt(:,is),rfmt(:,ias))
+  rfint=rfint+rfmtint(nrmt(is),nrmti(is),wr2mt(:,is),rfmt(:,ias))
 end do
 end function
 
