@@ -17,8 +17,8 @@ real(8) t1
 real(8), external :: rfint
 t1=rfint(rfmt,rfir)
 t1=rf0-t1/omega
-rfir(:)=rfir(:)+t1
-t1=t1/y00
+rfir(1:ngtot)=rfir(1:ngtot)+t1
+t1=t1*y00i
 do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
