@@ -38,7 +38,7 @@ real(8), intent(in) :: rfmt1(*),rfmt2(*)
 integer n,ir,i
 ! compute the dot-products for each radial point and integrate over r
 rfmtinp=0.d0
-if (lmaxi.eq.1) then
+if (lmaxi == 1) then
 !$OMP SIMD PRIVATE(i) REDUCTION(+:rfmtinp)
   do ir=1,nri
     i=4*(ir-1)+1
