@@ -10,17 +10,13 @@ implicit none
 integer, intent(in) :: nr,nri
 real(8), intent(in) :: wr(nr),rfmt(*)
 ! local variables
-integer ir,i
-rfmtint=0.d0
-i=1
-do ir=1,nri
-  rfmtint=rfmtint+wr(ir)*rfmt(i)
-  i=i+lmmaxi
-end do
-do ir=nri+1,nr
-  rfmtint=rfmtint+wr(ir)*rfmt(i)
-  i=i+lmmaxo
-end do
+integer iro,i0,i1
+i1=lmmaxi*(nri-1)+1
+rfmtint=sum(wr(1:nri)*rfmt(1:i1:lmmaxi))
+iro=nri+1
+i0=i1+lmmaxi
+i1=lmmaxo*(nr-iro)+i0
+rfmtint=rfmtint+sum(wr(iro:nr)*rfmt(i0:i1:lmmaxo))
 rfmtint=fourpi*y00*rfmtint
 end function
 
