@@ -9,8 +9,7 @@ use modomp
 implicit none
 ! arguments
 integer, intent(in) :: np
-real(8), intent(in) :: vpl(3,np)
-real(8), intent(in) :: rfmt(npmtmax,natmtot),rfir(ngtot)
+real(8), intent(in) :: vpl(3,np),rfmt(npmtmax,natmtot),rfir(ngtot)
 real(8), intent(out) :: fp(np)
 ! local variables
 integer ias,is,ip,nthd
@@ -22,6 +21,7 @@ allocate(rfmt1(lmmaxo,nrmtmax,natmtot))
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(is) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
@@ -31,11 +31,12 @@ end do
 call freethd(nthd)
 ! Fourier transform rfir to G-space
 allocate(zfft(ngtot))
-zfft(:)=rfir(:)
+zfft(1:ngtot)=rfir(1:ngtot)
 call zfftifc(3,ngridg,-1,zfft)
 ! begin loop over all points
 call holdthd(np,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ip=1,np
   call rfip(ip)
@@ -59,7 +60,7 @@ real(8) rmt2,r,sm,ya(4),t1
 real(8) v1(3),v2(3),v3(3),v4(3),v5(3)
 ! automatic arrays
 real(8) rlm(lmmaxo)
-v2(:)=vpl(:,ip)
+v2(1:3)=vpl(1:3,ip)
 call r3frac(epslat,v2)
 ! convert point to Cartesian coordinates
 call r3mv(avec,v2,v1)
@@ -70,13 +71,13 @@ do is=1,nspecies
   rmt2=rmt(is)**2
   do ia=1,natoms(is)
     ias=idxas(ia,is)
-    v2(:)=v1(:)-atposc(:,ia,is)
+    v2(1:3)=v1(1:3)-atposc(1:3,ia,is)
     do i1=-1,1
-      v3(:)=v2(:)+dble(i1)*avec(:,1)
+      v3(1:3)=v2(1:3)+dble(i1)*avec(1:3,1)
       do i2=-1,1
-        v4(:)=v3(:)+dble(i2)*avec(:,2)
+        v4(1:3)=v3(1:3)+dble(i2)*avec(1:3,2)
         do i3=-1,1
-          v5(:)=v4(:)+dble(i3)*avec(:,3)
+          v5(1:3)=v4(1:3)+dble(i3)*avec(1:3,3)
           t1=v5(1)**2+v5(2)**2+v5(3)**2
           if (t1 < rmt2) then
             r=sqrt(t1)
@@ -120,6 +121,7 @@ do is=1,nspecies
 end do
 ! otherwise use direct Fourier transform of interstitial function
 sm=0.d0
+!$OMP SIMD PRIVATE(ifg,t1) REDUCTION(+:sm)
 do ig=1,ngvec
   ifg=igfft(ig)
   t1=vgc(1,ig)*v1(1)+vgc(2,ig)*v1(2)+vgc(3,ig)*v1(3)
