@@ -30,17 +30,16 @@ real(8) x,sm,t1,t2
 complex(8) z1,z2
 ! automatic arrays
 real(8) ffg(ngvc),wr(nrspmax),jl(0:lmaxi,nrcmtmax)
-complex(8) zfmt(npcmtmax)
-! allocatable arrays
-complex(8), allocatable :: zfft(:)
+complex(8) zfmt(npcmtmax),zfft(ngtc)
 lmax=min(lmaxi,1)
 ! compute the superposition of all the atomic density tails
-allocate(zfft(ngtot))
-zfft(:)=0.d0
+zfft(1:ngtc)=0.d0
 call holdthd(nspecies,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(ffg,wr,nr,nrs,nro,ig) &
 !$OMP PRIVATE(t1,t2,sm,ir,x,ia,ias,ifg) &
+!$OMP REDUCTION(+:zfft) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do is=1,nspecies
   nr=nrmt(is)
@@ -67,12 +66,10 @@ do is=1,nspecies
   end do
   do ia=1,natoms(is)
     ias=idxas(ia,is)
-!$OMP CRITICAL(rhoinit_)
     do ig=1,ngvc
-      ifg=igfft(ig)
+      ifg=igfc(ig)
       zfft(ifg)=zfft(ifg)+ffg(ig)*conjg(sfacg(ig,ias))
     end do
-!$OMP END CRITICAL(rhoinit_)
   end do
 end do
 !$OMP END PARALLEL DO
@@ -83,6 +80,7 @@ call holdthd(natmtot,nthd)
 !$OMP PRIVATE(jl,zfmt,is,nrc,nrci) &
 !$OMP PRIVATE(irco,ig,ifg,irc,x) &
 !$OMP PRIVATE(z1,z2,lm,l,i0,i1) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
@@ -91,7 +89,7 @@ do ias=1,natmtot
   irco=nrci+1
   zfmt(1:npcmt(is))=0.d0
   do ig=1,ngvc
-    ifg=igfft(ig)
+    ifg=igfc(ig)
     do irc=1,nrc
       x=gc(ig)*rcmt(irc,is)
       call sbessel(lmax,x,jl(:,irc))
@@ -122,21 +120,22 @@ do ias=1,natmtot
   nri=nrmti(is)
   iro=nri+1
   i1=lmmaxi*(nri-1)+1
-  rhomt(1:i1:lmmaxi,ias)=rhomt(1:i1:lmmaxi,ias)+(t1+rhosp(1:nri,is))/y00
+  rhomt(1:i1:lmmaxi,ias)=rhomt(1:i1:lmmaxi,ias)+(t1+rhosp(1:nri,is))*y00i
   i0=i1+lmmaxi
   i1=lmmaxo*(nr-iro)+i0
-  rhomt(i0:i1:lmmaxo,ias)=rhomt(i0:i1:lmmaxo,ias)+(t1+rhosp(iro:nr,is))/y00
+  rhomt(i0:i1:lmmaxo,ias)=rhomt(i0:i1:lmmaxo,ias)+(t1+rhosp(iro:nr,is))*y00i
 end do
+! deallocate the global array rhosp as it is not used again
+deallocate(rhosp)
 ! interstitial density determined from the atomic tails and excess charge
-call zfftifc(3,ngridg,1,zfft)
-do ir=1,ngtot
+call zfftifc(3,ngdgc,1,zfft)
+do ir=1,ngtc
   rhoir(ir)=dble(zfft(ir))+t1
 ! make sure that the density is always positive
   if (rhoir(ir) < 1.d-10) rhoir(ir)=1.d-10
 end do
-deallocate(zfft)
-! deallocate rhosp as it is not used again
-deallocate(rhosp)
+! convert the interstitial density from coarse to fine grid
+call rfirctof(rhoir,rhoir)
 end subroutine
 !EOC
 
