@@ -60,10 +60,10 @@ do i=1,3
     np=npmt(is)
     rhosmt(1:np,ias,i)=rhomt(1:np,ias)+t1*(jrmt0(1:np,ias,i)-jrmt(1:np,ias,i))
 ! compute the muffin-tin static charge
-    chgsmt(ias,i)=rfmtint(nrmt(is),nrmti(is),wrmt(:,is),rhosmt(:,ias,i))
+    chgsmt(ias,i)=rfmtint(nrmt(is),nrmti(is),wr2mt(:,is),rhosmt(:,ias,i))
   end do
 ! interstitial static density
-  rhosir(:,i)=rhoir(:)+t1*(jrir0(:,i)-jrir(:,i))
+  rhosir(1:ngtot,i)=rhoir(1:ngtot)+t1*(jrir0(1:ngtot,i)-jrir(1:ngtot,i))
 ! compute the static charge
   chgstot(i)=rfint(rhosmt(:,:,i),rhosir(:,i))
 end do
