@@ -35,7 +35,7 @@ pure subroutine rtozflmn(lmax,n,ld,rflm,zflm)
 !   harmonics into a complex spherical harmonic expansion, $z_{lm}$:
 !   $$ z_{lm}=\begin{cases} \frac{1}{\sqrt{2}}(r_{lm}+i(-1)^mr_{l-m}) & m>0 \\
 !    \frac{1}{\sqrt{2}}((-1)^mr_{l-m}-ir_{lm}) & m<0 \\
-!    r_{lm} & m=0 \end{cases}\;. $$
+!    r_{lm} & m=0 \end{cases} $$
 !   See routine {\tt genrlm}.
 !
 ! !REVISION HISTORY:
@@ -58,21 +58,21 @@ do l=0,lmax
     lm1=lm1+1
     lm2=lm2-1
     if (mod(m,2) /= 0) then
-      zflm(lm1,:)=c1*cmplx(-rflm(lm2,:),-rflm(lm1,:),8)
+      zflm(lm1,1:n)=c1*cmplx(-rflm(lm2,1:n),-rflm(lm1,1:n),8)
     else
-      zflm(lm1,:)=c1*cmplx(rflm(lm2,:),-rflm(lm1,:),8)
+      zflm(lm1,1:n)=c1*cmplx(rflm(lm2,1:n),-rflm(lm1,1:n),8)
     end if
   end do
   lm1=lm1+1
   lm2=lm2-1
-  zflm(lm1,:)=rflm(lm1,:)
+  zflm(lm1,1:n)=rflm(lm1,1:n)
   do m=1,l
     lm1=lm1+1
     lm2=lm2-1
     if (mod(m,2) /= 0) then
-      zflm(lm1,:)=c1*cmplx(rflm(lm1,:),-rflm(lm2,:),8)
+      zflm(lm1,1:n)=c1*cmplx(rflm(lm1,1:n),-rflm(lm2,1:n),8)
     else
-      zflm(lm1,:)=c1*cmplx(rflm(lm1,:),rflm(lm2,:),8)
+      zflm(lm1,1:n)=c1*cmplx(rflm(lm1,1:n),rflm(lm2,1:n),8)
     end if
   end do
 end do
