@@ -97,7 +97,7 @@ if (x < 2*lmax) then
   end do
 ! rescaling constant
   t1=sinh(x)/(x*j0)
-  jl(:)=t1*jl(:)
+  jl(0:lmax)=t1*jl(0:lmax)
 else
 ! for x >= 2*lmax recurse up
   jl(0)=sinh(x)*xi
