@@ -60,9 +60,9 @@ do idm=1,ndmag
     b=-aimag(zmagh(ih))*omega
     r=abs(zmagh(ih))*omega
     iv(:)=nint(v(:))
-    if ((abs(v(1)-iv(1)).le.epslat).and. &
-        (abs(v(2)-iv(2)).le.epslat).and. &
-        (abs(v(3)-iv(3)).le.epslat)) then
+    if ((abs(v(1)-iv(1)) <= epslat).and. &
+        (abs(v(2)-iv(2)) <= epslat).and. &
+        (abs(v(3)-iv(3)) <= epslat)) then
 ! integer hkl
       write(50,'(4I7,4G16.8)') iv(:),mulh(ih),hc(ih),a,b,r
     else
@@ -76,7 +76,7 @@ write(*,*)
 write(*,'("Info(sfacmag): magnetic structure factors written to &
  &SFACMAG_j.OUT")')
 write(*,'(" for magnetic components j = ",3I2)') (idm,idm=1,ndmag)
-if (ndmag.eq.1) then
+if (ndmag == 1) then
   write(*,'(" (this corresponds to the z-component of the magnetisation)")')
 end if
 write(*,*)
