@@ -29,8 +29,8 @@ integer, intent(out) :: idx(n)
 ! local variables
 integer i,j,k,l,m
 ! tolerance for deciding if one number is smaller than another
-real(8), parameter :: eps=1.d-14
-if (n <= 0) return
+real(8), parameter :: eps=1.d-10
+if (n < 1) return
 do i=1,n
   idx(i)=i
 end do
