@@ -6,7 +6,7 @@
 !BOP
 ! !ROUTINE: r3cross
 ! !INTERFACE:
-subroutine r3cross(x,y,z)
+pure subroutine r3cross(x,y,z)
 ! !INPUT/OUTPUT PARAMETERS:
 !   x : input vector 1 (in,real(3))
 !   y : input vector 2 (in,real(3))
@@ -20,13 +20,11 @@ subroutine r3cross(x,y,z)
 !BOC
 implicit none
 ! arguments
-real(8), intent(in) :: x(3)
-real(8), intent(in) :: y(3)
+real(8), intent(in) :: x(3),y(3)
 real(8), intent(out) :: z(3)
 z(1)=x(2)*y(3)-x(3)*y(2)
 z(2)=x(3)*y(1)-x(1)*y(3)
 z(3)=x(1)*y(2)-x(2)*y(1)
-return
 end subroutine
 !EOC
 
