@@ -28,16 +28,16 @@ real(8), intent(out) :: r,tp(2)
 real(8), parameter :: eps=1.d-14
 real(8) t1
 r=sqrt(v(1)**2+v(2)**2+v(3)**2)
-if (r.gt.eps) then
+if (r > eps) then
   t1=v(3)/r
-  if (t1.ge.1.d0) then
+  if (t1 >= 1.d0) then
     tp(1)=0.d0
-  else if (t1.le.-1.d0) then
+  else if (t1 <= -1.d0) then
     tp(1)=3.1415926535897932385d0
   else
     tp(1)=acos(t1)
   end if
-  if ((abs(v(1)).gt.eps).or.(abs(v(2)).gt.eps)) then
+  if ((abs(v(1)) > eps).or.(abs(v(2)) > eps)) then
     tp(2)=atan2(v(2),v(1))
   else
     tp(2)=0.d0
