@@ -41,7 +41,7 @@ case(5)
   stheta=stheta_lr(x)
 case default
   write(*,*)
-  write(*,'("Error(stheta): sytpe not defined : ",I8)') stype
+  write(*,'("Error(stheta): stype not defined : ",I8)') stype
   write(*,*)
   stop
 end select
