@@ -24,11 +24,11 @@ elemental real(8) function stheta_sq(x)
 implicit none
 ! arguments
 real(8), intent(in) :: x
-if (x.le.-0.5d0) then
+if (x <= -0.5d0) then
   stheta_sq=0.d0
   return
 end if
-if (x.lt.0.5d0) then
+if (x < 0.5d0) then
   stheta_sq=x+0.5d0
 else
   stheta_sq=1.d0
