@@ -6,9 +6,7 @@
 !BOP
 ! !ROUTINE: sumrule
 ! !INTERFACE:
-subroutine sumrule(dynq)
-! !INPUT/OUTPUT PARAMETERS:
-!   dynq : dynamical matrices on q-point set (in,real(nbph,nbph,nqpt))
+subroutine sumrule
 ! !DESCRIPTION:
 !   Applies the same correction to all the dynamical matrices such that the
 !   matrix for ${\bf q}=0$ satisfies the acoustic sum rule. In other words, the
@@ -29,12 +27,10 @@ subroutine sumrule(dynq)
 use modmain
 use modphonon
 implicit none
-! arguments
-complex(8), intent(inout) :: dynq(nbph,nbph,nqpt)
 ! local variables
 integer iq,i,j,k
 ! automatic arrays
-real(8) w(nbph)
+real(8) wq0(nbph)
 complex(8) ev(nbph,nbph)
 ! compute the eigenvalues and vectors of the q = 0 dynamical matrix
 do i=1,nbph
@@ -42,14 +38,14 @@ do i=1,nbph
     ev(i,j)=0.5d0*(dynq(i,j,1)+conjg(dynq(j,i,1)))
   end do
 end do
-call eveqnzh(nbph,nbph,ev,w)
+call eveqnzh(nbph,nbph,ev,wq0)
 ! subtract outer products of 3 lowest eigenvectors for q = 0 from all the
 ! dynamical matrices
 do iq=1,nqpt
   do i=1,nbph
     do j=1,nbph
       do k=1,3
-        dynq(i,j,iq)=dynq(i,j,iq)-w(k)*ev(i,k)*conjg(ev(j,k))
+        dynq(i,j,iq)=dynq(i,j,iq)-wq0(k)*ev(i,k)*conjg(ev(j,k))
       end do
     end do
   end do
