@@ -12,7 +12,7 @@ call r3minv(avec,ainv)
 ! find Bravais lattice symmetries
 call findsymlat
 ! use only the identity if required
-if (symtype.eq.0) nsymlat=1
+if (symtype == 0) nsymlat=1
 ! find the crystal symmetries and shift atomic positions if required
 call findsymcrys
 ! find the site symmetries
