@@ -39,7 +39,6 @@ integer isym,lspl,sym(3,3)
 integer ig,jg,ifg,jfg
 integer i1,i2,i3,j1,j2,j3
 real(8) v1,v2,v3,t1
-complex(8) z1
 ! allocatable arrays
 complex(8), allocatable :: zfft1(:),zfft2(:)
 allocate(zfft1(ngtot_),zfft2(nfgrz_))
@@ -81,8 +80,7 @@ do isym=1,nsymcrys
     else
 ! complex phase factor for translation
       t1=vgc(1,jg)*v1+vgc(2,jg)*v2+vgc(3,jg)*v3
-      z1=cmplx(cos(t1),-sin(t1),8)
-      zfft2(ifg)=zfft2(ifg)+z1*zfft1(jfg)
+      zfft2(ifg)=zfft2(ifg)+zfft1(jfg)*cmplx(cos(t1),-sin(t1),8)
     end if
   end do
 end do
