@@ -16,8 +16,6 @@ integer is,ia,ja,ias,jas
 integer nr,nri,np,i
 real(8) sc(3,3),t0,t1
 real(8) x1,x2,x3,y1,y2,y3
-! automatic arrays
-logical done(natmmax)
 ! allocatable arrays
 real(8), allocatable :: rvfmt1(:,:,:),rvfmt2(:,:)
 ! dimension of the vector field
@@ -39,9 +37,9 @@ do is=1,nspecies
       rvfmt1(1:np,ia,i)=rvfmt(1:np,ias,i)
     end do
   end do
-  done(1:natmmax)=.false.
   do ia=1,natoms(is)
-    if (done(ia)) cycle
+! only symmetrise first equivalent atom (rotate into others)
+    if (.not.tfeqat(ia,is)) cycle
     ias=idxas(ia,is)
     rvfmt(1:np,ias,1:nd)=0.d0
 ! begin loop over crystal symmetries
@@ -85,44 +83,41 @@ do is=1,nspecies
     do i=1,nd
       rvfmt(1:np,ias,i)=t0*rvfmt(1:np,ias,i)
     end do
-! mark atom as done
-    done(ia)=.true.
 ! rotate into equivalent atoms
-    do isym=1,nsymcrys
-      ja=ieqatom(ia,is,isym)
-      if (done(ja)) cycle
-      jas=idxas(ja,is)
+    do ja=1,natoms(is)
+      if (eqatoms(ia,ja,is).and.(ia /= ja)) then
+        isym=findloc(ieqatom(ia,is,1:nsymcrys),ja,1)
+        jas=idxas(ja,is)
 ! parallel transport of vector field (using operation inverse)
-      lspl=isymlat(lsplsymc(isym))
-      do i=1,nd
-        call rotrfmt(symlatc(:,:,lspl),nr,nri,rvfmt(:,ias,i),rvfmt(:,jas,i))
-      end do
-      if (tspin) then
-! inverse of global proper rotation matrix in Cartesian coordinates
-        lspn=isymlat(lspnsymc(isym))
-        sc(1:3,1:3)=symlatd(lspn)*symlatc(1:3,1:3,lspn)
-      else
-! set spin rotation equal to spatial rotation
-        lspn=lspl
-        sc(1:3,1:3)=symlatc(1:3,1:3,lspl)
-      end if
-! global spin rotation of vector field
-      if (tnc) then
-! non-collinear case
-        do i=1,np
-          x1=rvfmt(i,jas,1); x2=rvfmt(i,jas,2); x3=rvfmt(i,jas,3)
-          y1=sc(1,1)*x1+sc(1,2)*x2+sc(1,3)*x3
-          y2=sc(2,1)*x1+sc(2,2)*x2+sc(2,3)*x3
-          y3=sc(3,1)*x1+sc(3,2)*x2+sc(3,3)*x3
-          rvfmt(i,jas,1)=y1; rvfmt(i,jas,2)=y2; rvfmt(i,jas,3)=y3
+        lspl=isymlat(lsplsymc(isym))
+        do i=1,nd
+          call rotrfmt(symlatc(:,:,lspl),nr,nri,rvfmt(:,ias,i),rvfmt(:,jas,i))
         end do
-      else
+        if (tspin) then
+! inverse of global proper rotation matrix in Cartesian coordinates
+          lspn=isymlat(lspnsymc(isym))
+          sc(1:3,1:3)=symlatd(lspn)*symlatc(1:3,1:3,lspn)
+        else
+! set spin rotation equal to spatial rotation
+          lspn=lspl
+          sc(1:3,1:3)=symlatc(1:3,1:3,lspl)
+        end if
+! global spin rotation of vector field
+        if (tnc) then
+! non-collinear case
+          do i=1,np
+            x1=rvfmt(i,jas,1); x2=rvfmt(i,jas,2); x3=rvfmt(i,jas,3)
+            y1=sc(1,1)*x1+sc(1,2)*x2+sc(1,3)*x3
+            y2=sc(2,1)*x1+sc(2,2)*x2+sc(2,3)*x3
+            y3=sc(3,1)*x1+sc(3,2)*x2+sc(3,3)*x3
+            rvfmt(i,jas,1)=y1; rvfmt(i,jas,2)=y2; rvfmt(i,jas,3)=y3
+          end do
+        else
 ! collinear case
-        t1=sc(3,3)
-        rvfmt(1:np,jas,1)=t1*rvfmt(1:np,jas,1)
+          t1=sc(3,3)
+          rvfmt(1:np,jas,1)=t1*rvfmt(1:np,jas,1)
+        end if
       end if
-! mark atom as done
-      done(ja)=.true.
     end do
 ! end loop over atoms and species
   end do
