@@ -13,7 +13,7 @@ implicit none
 integer ik
 ! allocatable arrays
 complex(8), allocatable :: evecsvt(:,:)
-if (ntsbackup <= 0) return
+if (ntsbackup < 1) return
 if (mod(itimes-1,ntsbackup) /= 0) return
 ! ensure eigenvectors are written to disk
 wrtdsk0=wrtdsk
