@@ -47,11 +47,7 @@ do itimes=itimes0,ntimes-1
     end if
   end if
 ! flag for calculating forces at this time step
-  if (mod(itimes-1,ntsforce) == 0) then
-    ttsforce=.true.
-  else
-    ttsforce=.false.
-  end if
+  ttsforce=(mod(itimes-1,ntsforce) == 0)
 ! evolve the wavefunctions across a single time step
   call timestep
 ! generate the density and magnetisation at current time step
