@@ -34,8 +34,8 @@ call init1
 call init2
 call init3
 ! check q-vector is commensurate with k-point grid
-v(:)=dble(ngridk(:))*vecql(:)
-v(:)=abs(v(:)-nint(v(:)))
+v(1:3)=dble(ngridk(1:3))*vecql(1:3)
+v(1:3)=abs(v(1:3)-nint(v(1:3)))
 if ((v(1) > epslat).or.(v(2) > epslat).or.(v(3) > epslat)) then
   write(*,*)
   write(*,'("Error(tddftsplr): q-vector incommensurate with k-point grid")')
@@ -74,6 +74,7 @@ allocate(chi(ngrf,4,ngrf,4,nwrf))
 chi(:,:,:,:,:)=0.d0
 call holdthd(nkptnr/np_mpi,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ik=1,nkptnr
 ! distribute among MPI processes
@@ -100,9 +101,9 @@ end if
 do iw=1,nwrf
   do ig=1,ngrf
     do jg=1,ngrf
-      a(:,:)=chi(ig,:,jg,:,iw)
+      a(1:4,1:4)=chi(ig,1:4,jg,1:4,iw)
       call tfm2213(a,b)
-      chi(ig,:,jg,:,iw)=b(:,:)
+      chi(ig,1:4,jg,1:4,iw)=b(1:4,1:4)
     end do
   end do
 end do
@@ -110,7 +111,7 @@ end do
 if (.not.ncmag) then
   allocate(chit(nwrf))
   do iw=1,nwrf
-    a(:,:)=chi(1,:,1,:,iw)
+    a(1:4,1:4)=chi(1,1:4,1,1:4,iw)
     call tfm13t(a,b)
     chit(iw)=b(2,2)
   end do
@@ -178,7 +179,7 @@ deallocate(c,d)
 ! generate transverse χ for the collinear case
 if (.not.ncmag) then
   do iw=1,nwrf
-    a(:,:)=chi(1,:,1,:,iw)
+    a(1:4,1:4)=chi(1,1:4,1,1:4,iw)
     call tfm13t(a,b)
     chit(iw)=b(2,2)
   end do
@@ -267,19 +268,17 @@ complex(8), intent(in) :: a(4,4)
 complex(8), intent(out) :: b(4,4)
 ! local variables
 integer i,j
-complex(8) c(4,4),z1
+complex(8) c(4,4)
 do i=1,4
   c(i,1)=a(i,1)+a(i,4)
   c(i,2)=a(i,2)+a(i,3)
-  z1=a(i,2)-a(i,3)
-  c(i,3)=cmplx(aimag(z1),-dble(z1),8)
+  c(i,3)=zmi*(a(i,2)-a(i,3))
   c(i,4)=a(i,1)-a(i,4)
 end do
 do j=1,4
   b(1,j)=c(1,j)+c(4,j)
   b(2,j)=c(2,j)+c(3,j)
-  z1=c(2,j)-c(3,j)
-  b(3,j)=cmplx(-aimag(z1),dble(z1),8)
+  b(3,j)=zi*(c(2,j)-c(3,j))
   b(4,j)=c(1,j)-c(4,j)
 end do
 end subroutine
@@ -295,15 +294,15 @@ complex(8) c(4,4),z1
 do i=1,4
   c(i,1)=a(i,1)
   z1=a(i,3)
-  c(i,2)=a(i,2)+cmplx(aimag(z1),-dble(z1),8)
-  c(i,3)=a(i,2)+cmplx(-aimag(z1),dble(z1),8)
+  c(i,2)=a(i,2)+zmi*z1
+  c(i,3)=a(i,2)+zi*z1
   c(i,4)=a(i,4)
 end do
 do j=1,4
   b(1,j)=c(1,j)
   z1=c(3,j)
-  b(2,j)=c(2,j)+cmplx(-aimag(z1),dble(z1),8)
-  b(3,j)=c(2,j)+cmplx(aimag(z1),-dble(z1),8)
+  b(2,j)=c(2,j)+zi*z1
+  b(3,j)=c(2,j)+zmi*z1
   b(4,j)=c(4,j)
 end do
 end subroutine
