@@ -12,8 +12,7 @@ real(8) torq(3)
 ! allocatable arrays
 real(8), allocatable :: rvfmt(:,:,:),rvfir(:,:)
 ! external functions
-real(8) rfint
-external rfint
+real(8), external :: rfint
 ! initialise universal variables
 call init0
 if (.not.ncmag) then
@@ -34,6 +33,5 @@ write(*,*)
 write(*,'("Info(torque):")')
 write(*,'(" Total torque exerted by B_xc on the magnetisation :")')
 write(*,'(3G18.10)') torq
-return
 end subroutine
 
