@@ -25,27 +25,20 @@ do ias=1,natmtot
 end do
 vsqir(1:ngtot,1)=vsqir(1:ngtot,1)-vsir(1:ngtot)
 call holdthd(2*nfqrz,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(ias,is,nrc,nrci) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
 do ifq=1,nfqrz
   do ias=1,natmtot
     is=idxis(ias)
     nrc=nrcmt(is)
     nrci=nrcmti(is)
 ! multiply the muffin-tin potential by the radial integration weights
-    call zfcmtwr(nrc,nrci,wrcmt(:,is),vsqmt(:,ias,ifq))
+    call zfcmtwr(nrc,nrci,wr2cmt(:,is),vsqmt(:,ias,ifq))
   end do
 end do
-!$OMP END DO NOWAIT
-!$OMP DO
-do ifq=1,nfqrz
-! multiply the interstitial potential by the characteristic function
-  vsqir(1:ngtot,ifq)=vsqir(1:ngtot,ifq)*cfunir(1:ngtot)
-end do
-!$OMP END DO
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
 call freethd(nthd)
 if (.not.spinpol) return
 ! subtract the normal Kohn-Sham magnetic field for Q=0 in the muffin-tins
@@ -57,10 +50,10 @@ do idm=1,ndmag
   end do
 end do
 call holdthd(2*nfqrz,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(idm,ias,is,nrc,nrci) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
 do ifq=1,nfqrz
   do idm=1,ndmag
     do ias=1,natmtot
@@ -68,23 +61,13 @@ do ifq=1,nfqrz
       nrc=nrcmt(is)
       nrci=nrcmti(is)
 ! multiply the muffin-tin field by the radial integration weights
-      call zfcmtwr(nrc,nrci,wrcmt(:,is),bsqmt(:,ias,idm,ifq))
+      call zfcmtwr(nrc,nrci,wr2cmt(:,is),bsqmt(:,ias,idm,ifq))
     end do
   end do
 end do
-!$OMP END DO NOWAIT
-!$OMP DO
-do ifq=1,nfqrz
-  do idm=1,ndmag
-! multiply interstitial field by the characteristic function
-    bsqir(1:ngtot,idm,ifq)=bsqir(1:ngtot,idm,ifq)*cfunir(1:ngtot)
-  end do
-end do
-!$OMP END DO
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
 call freethd(nthd)
 ! subtract the normal Kohn-Sham magnetic field for Q=0 in the interstitial
-! (this is already multiplied by the characteristic function)
 do idm=1,ndmag
   bsqir(1:ngtot,idm,1)=bsqir(1:ngtot,idm,1)-bsir(1:ngtot,idm)
 end do
