@@ -8,7 +8,7 @@ use modmain
 use modulr
 implicit none
 ! zero the external Coulomb potential in Q-space
-vclq(:)=0.d0
+vclq(1:nfqrz)=0.d0
 if (trdvclr) then
 ! read the external Coulomb potential from file if required
   call readvclr
