@@ -3,13 +3,13 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine wfirsv(tgp,nst,idx,ngdg,igf,ngp,igpig,evecfv,evecsv,ld,wfir)
+subroutine wfirsv(tgp,nst,idx,ngridg_,igfft_,ngp,igpig,evecfv,evecsv,ld,wfir)
 use modmain
 use modomp
 implicit none
 ! arguments
 logical, intent(in) :: tgp
-integer, intent(in) :: nst,idx(*),ngdg(3),igf(*)
+integer, intent(in) :: nst,idx(*),ngridg_(3),igfft_(*)
 integer, intent(in) :: ngp(nspnfv),igpig(ngkmax,nspnfv)
 complex(8), intent(in) :: evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv)
 integer, intent(in) :: ld
@@ -24,15 +24,15 @@ complex(8) wfgp(ngkmax)
 t0=1.d0/sqrt(omega)
 call holdthd(nst,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
-!$OMP PRIVATE(wfgp,k,i,ispn,jspn) &
-!$OMP PRIVATE(n,ist,z1,igp) &
+!$OMP PRIVATE(wfgp,k,ispn,jspn) &
+!$OMP PRIVATE(n,ist,i,z1,igp) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do j=1,nst
 ! index to state in evecsv
   if (idx(1) == 0) then; k=j; else; k=idx(j); end if
   if (tevecsv) then
 ! generate spinor wavefunction from second-variational eigenvectors
-    i=0
     do ispn=1,nspinor
       jspn=jspnfv(ispn)
       n=ngp(jspn)
@@ -42,9 +42,9 @@ do j=1,nst
         wfgp(1:n)=0.d0
       end if
       do ist=1,nstfv
-        i=i+1
+        i=(ispn-1)*nstfv+ist
         z1=evecsv(i,k)
-        if (abs(dble(z1))+abs(aimag(z1)) < epsocc) cycle
+        if (abs(dble(z1))+abs(aimag(z1)) < 1.d-10) cycle
         if (tgp) then
 ! wavefunction in G+p-space
           wfir(1:n,ispn,j)=wfir(1:n,ispn,j)+z1*evecfv(1:n,ist,jspn)
@@ -56,11 +56,11 @@ do j=1,nst
       end do
 ! Fourier transform wavefunction to real-space if required
       if (.not.tgp) then
-        wfir(:,ispn,j)=0.d0
+        wfir(1:ld,ispn,j)=0.d0
         do igp=1,n
-          wfir(igf(igpig(igp,jspn)),ispn,j)=wfgp(igp)
+          wfir(igfft_(igpig(igp,jspn)),ispn,j)=wfgp(igp)
         end do
-        call zfftifc(3,ngdg,1,wfir(:,ispn,j))
+        call zfftifc(3,ngridg_,1,wfir(:,ispn,j))
       end if
     end do
   else
@@ -69,11 +69,11 @@ do j=1,nst
     if (tgp) then
       wfir(1:n,1,j)=evecfv(1:n,k,1)
     else
-      wfir(:,1,j)=0.d0
+      wfir(1:ld,1,j)=0.d0
       do igp=1,n
-        wfir(igf(igpig(igp,1)),1,j)=t0*evecfv(igp,k,1)
+        wfir(igfft_(igpig(igp,1)),1,j)=t0*evecfv(igp,k,1)
       end do
-      call zfftifc(3,ngdg,1,wfir(:,1,j))
+      call zfftifc(3,ngridg_,1,wfir(:,1,j))
     end if
   end if
 end do
