@@ -44,11 +44,7 @@ if (ssdph) then
   zq(2)=conjg(zq(1))
 end if
 ! check if all the second-variational wavefunctions should be calculated
-if (idx(1) == 0) then
-  tasv=.true.
-else
-  tasv=.false.
-end if
+tasv=(idx(1) == 0)
 call holdthd(nst,nthd)
 !-----------------------!
 !     APW functions     !
