@@ -18,8 +18,6 @@ call init0
 call init1
 ! read the density and potentials from file
 call readstate
-! read Fermi energy from file
-call readfermi
 ! find the new linearisation energies
 call linengy
 ! generate the APW radial functions
