@@ -16,6 +16,8 @@ real(8), parameter :: ced=ha_si/(100.d0*br_si)**2
 real(8), allocatable :: f(:),g(:),pd(:)
 ! external functions
 real(8), external :: splint
+! read time-dependent A-field from file
+call readafieldt
 ! allocate local arrays
 allocate(f(ntimes),g(ntimes),pd(ntimes))
 ! compute the power density at each time step
