@@ -28,10 +28,10 @@ if (spinpol) then
 end if
 write(fnum,'(" exchange",T30,": ",G22.12)') engyx
 write(fnum,'(" correlation",T30,": ",G22.12)') engyc
-if (dftu.ne.0) then
+if (dftu /= 0) then
   write(fnum,'(" DFT+U",T30,": ",G22.12)') engydu
 end if
-if (stype.eq.3) then
+if (stype == 3) then
   write(fnum,'(" electron entropic",T30,": ",G22.12)') engyts
 end if
 write(fnum,'(" total energy",T30,": ",G22.12)') engytot
