@@ -14,8 +14,6 @@ call init2
 call init3
 ! read density and potentials from file
 call readstate
-! read Fermi energy from file
-call readfermi
 ! find the new linearisation energies
 call linengy
 ! generate the APW radial functions
@@ -30,7 +28,7 @@ call epsinv
 if (mp_mpi) then
   write(*,*)
   write(*,'("Info(writeepsinv):")')
-  write(*,'(" inverse RPA dielectric function, eps^(-1)(G,G'',q,w), written to &
+  write(*,'(" inverse RPA dielectric function, ϵ⁻¹(G,G'',q,w), written to &
    &EPSINV.OUT")')
 end if
 end subroutine
