@@ -22,15 +22,14 @@ do iw=1,nwplot
   w=dw*dble(iw-1)+wplot(1)
   write(50,'(2G18.10)') w,sf(iw)
 end do
-write(50,'("     ")')
+write(50,*)
 ! write the Kohn-Sham eigenvalues for reference
 do ist=1,nstsv
   e=evalsv(ist,ik)-efermi
   write(50,'(2G18.10)') e,0.d0
   write(50,'(2G18.10)') e,1.d0/swidth
-  write(50,'("     ")')
+  write(50,*)
 end do
 close(50)
-return
 end subroutine
 
