@@ -19,8 +19,6 @@ call init2
 call init3
 ! read density and potentials from file
 call readstate
-! read Fermi energy from a file
-call readfermi
 ! find the new linearisation energies
 call linengy
 ! generate the APW radial functions
