@@ -36,8 +36,9 @@ do is=1,nspecies
         do i1=-1,1
           do i2=-1,1
             do i3=-1,1
-              v(:)=dble(i1)*avec(:,1)+dble(i2)*avec(:,2)+dble(i3)*avec(:,3) &
-               +atposc(:,ja,js)
+              v(:)=dble(i1)*avec(:,1) &
+                  +dble(i2)*avec(:,2) &
+                  +dble(i3)*avec(:,3)+atposc(:,ja,js)
               v(:)=v(:)-atposc(:,ia,is)
               d=sqrt(v(1)**2+v(2)**2+v(3)**2)
               dmin=min(d,dmin)
@@ -50,7 +51,6 @@ do is=1,nspecies
     end do
   end do
 end do
-return
 end subroutine
 !EOC
 
