@@ -23,7 +23,7 @@ do iq=1,nqpt
   write(50,'(3G18.10," : q-vector (Cartesian coordinates)")') vqc(:,iq)
   do i=1,nbph
     t1=pi*fermidos*wphq(i,iq)**2
-    if (t1.gt.1.d-8) then
+    if (t1 > 1.d-8) then
       t2=gq(i,iq)/t1
     else
       t2=0.d0
