@@ -10,32 +10,22 @@ implicit none
 ! local variables
 integer iq,i,j,is,ia,ip
 ! allocatable arrays
-real(8), allocatable :: w(:)
-complex(8), allocatable :: dynq(:,:,:),dynr(:,:,:)
-complex(8), allocatable :: dynp(:,:),ev(:,:)
+real(8), allocatable :: wq(:)
+complex(8), allocatable :: dq(:,:),ev(:,:)
 ! initialise universal variables
 call init0
 call init2
-allocate(w(nbph))
-allocate(dynq(nbph,nbph,nqpt))
-allocate(dynr(nbph,nbph,nqptnr))
-allocate(dynp(nbph,nbph))
-allocate(ev(nbph,nbph))
-! read in the dynamical matrices
-call readdyn(dynq)
-! apply the acoustic sum rule
-call sumrule(dynq)
-! Fourier transform the dynamical matrices to real-space
-call dynqtor(dynq,dynr)
+call initph
+allocate(wq(nbph),dq(nbph,nbph),ev(nbph,nbph))
 open(50,file='PHONON.OUT',form='FORMATTED')
 do iq=1,nphwrt
-  call dynrtoq(vqlwrt(:,iq),dynr,dynp)
-  call dynev(dynp,w,ev)
+  call dynrtoq(vqlwrt(:,iq),dynr,dq)
+  call dynev(dq,wq,ev)
   write(50,*)
   write(50,'(I6,3G18.10," : q-point, vqlwrt")') iq,vqlwrt(:,iq)
   do j=1,nbph
     write(50,*)
-    write(50,'(I6,G18.10," : mode, frequency")') j,w(j)
+    write(50,'(I6,G18.10," : mode, frequency")') j,wq(j)
     i=0
     do is=1,nspecies
       do ia=1,natoms(is)
@@ -58,6 +48,6 @@ write(*,*)
 write(*,'("Info(writephn): phonon frequencies and eigenvectors written to &
  &PHONON.OUT")')
 write(*,'(" for all q-vectors in the phwrite list")')
-deallocate(w,dynq,dynr,dynp,ev)
+deallocate(wq,dq,ev)
 end subroutine
 
