@@ -10,6 +10,7 @@ subroutine writepmat
 ! !USES:
 use modmain
 use modmpi
+use modramdisk
 ! !DESCRIPTION:
 !   Calculates the momentum matrix elements using routine {\tt genpmat} and
 !   writes them to direct access file {\tt PMAT.OUT}.
@@ -19,6 +20,9 @@ use modmpi
 !EOP
 !BOC
 implicit none
+! ensure momentum matrix elements are written to disk
+wrtdsk0=wrtdsk
+wrtdsk=.true.
 ! initialise universal variables
 call init0
 call init1
@@ -32,6 +36,7 @@ call genapwfr
 call genlofr
 ! write the momentum matrix elements in the second-variational basis to file
 call genpmat
+wrtdsk=wrtdsk0
 if (mp_mpi) then
   write(*,*)
   write(*,'("Info(writepmat):")')
