@@ -8,12 +8,11 @@ use modmain
 implicit none
 ! local variables
 integer iq
-open(50,file='QPOINTS.OUT',form='FORMATTED')
+open(50,file='QPOINTS.OUT',form='FORMATTED',action='WRITE')
 write(50,'(I6," : nqpt; q-point, vql, wqpt below")') nqpt
 do iq=1,nqpt
   write(50,'(I6,4G18.10)') iq,vql(:,iq),wqpt(iq)
 end do
 close(50)
-return
 end subroutine
 
