@@ -22,13 +22,7 @@ logical core(maxstsp),lorb(maxstsp)
 ! default APW band energy
 real(8), parameter :: e0=0.15d0
 ! find which states belong to core
-do ist=1,nst
-  if (eval(ist) < ecvcut) then
-    core(ist)=.true.
-  else
-    core(ist)=.false.
-  end if
-end do
+core(1:nst)=(eval(1:nst) < ecvcut)
 ! check that the state for same n and l but different k is also core
 do ist=1,nst
   if (core(ist)) then
