@@ -7,56 +7,39 @@ subroutine writetddft
 use modmain
 use modtddft
 use moddftu
+use moddelf
 implicit none
 ! local variables
 integer is,ia,ias
-real(8) vc(3),vl(3)
-character(256) fext
+character(32) fext
 ! allocatable arrays
 real(8), allocatable :: rvfmt(:,:,:),rvfir(:,:)
 ! file extension
 write(fext,'("_TS",I8.8,".OUT")') itimes
-! delete all files at first time step
-if (itimes.le.1) then
-  open(50,file='CHARGEMT_TD.OUT')
-  close(50,status='DELETE')
-  open(50,file='CHARGEIR_TD.OUT')
-  close(50,status='DELETE')
-  open(50,file='MOMENT_TD.OUT')
-  close(50,status='DELETE')
-  open(50,file='MOMENTM_TD.OUT')
-  close(50,status='DELETE')
-  open(50,file='MOMENTMT_TD.OUT')
-  close(50,status='DELETE')
-  open(50,file='MOMENTIR_TD.OUT')
-  close(50,status='DELETE')
-  open(50,file='JTOT_TD.OUT')
-  close(50,status='DELETE')
-  open(50,file='JTOTM_TD.OUT')
-  close(50,status='DELETE')
-  open(50,file='TOTENERGY_TD.OUT')
-  close(50,status='DELETE')
-  if (tddos) then
-    open(50,file='TDTEMP.OUT')
-    close(50,status='DELETE')
+! delete files at first time step
+if (itimes <= 1) then
+  call delfile('TOTENERGY_TD.OUT')
+  call delfile('CHARGEMT_TD.OUT')
+  call delfile('CHARGEIR_TD.OUT')
+  if (spinpol) then
+    call delfile('MOMENT_TD.OUT')
+    call delfile('MOMENTM_TD.OUT')
+    call delfile('MOMENTMT_TD.OUT')
+    call delfile('MOMENTIR_TD.OUT')
   end if
-  if (tdlsj) then
-    open(50,file='TDLSJ.OUT')
-    close(50,status='DELETE')
-  end if
-  if (tforce) then
-    open(50,file='FORCETOT_TD.OUT')
-    close(50,status='DELETE')
-  end if
-  if (tdatpos) then
-    open(50,file='ATPOSL_TD.OUT')
-    close(50,status='DELETE')
-  end if
-  if (tafindt) then
-    open(50,file='AFIND_TD.OUT')
-    close(50,status='DELETE')
+  call delfile('JTOT_TD.OUT')
+  call delfile('JTOTM_TD.OUT')
+  if (tddos) call delfile('TDTEMP.OUT')
+  if (tdlsj) call delfile('TDLSJ.OUT')
+  if (tforce) call delfile('FORCETOT_TD.OUT')
+  if (tatdisp) then
+    call delfile('ATDISPL_TD.OUT')
+    call delfile('ATDISPC_TD.OUT')
   end if
+  if (tafindt) call delfile('AFIND_TD.OUT')
 end if
+! total energy
+call writetdengy
 ! muffin-tin charges
 open(50,file='CHARGEMT_TD.OUT',form='FORMATTED',position='APPEND')
 write(50,'(G18.10)') times(itimes)
@@ -72,28 +55,8 @@ close(50)
 open(50,file='CHARGEIR_TD.OUT',form='FORMATTED',position='APPEND')
 write(50,'(2G18.10)') times(itimes),chgir
 close(50)
-! spin moment
-open(50,file='MOMENT_TD.OUT',form='FORMATTED',position='APPEND')
-write(50,'(4G18.10)') times(itimes),momtot(1:ndmag)
-close(50)
-open(50,file='MOMENTM_TD.OUT',form='FORMATTED',position='APPEND')
-write(50,'(2G18.10)') times(itimes),momtotm
-close(50)
-! muffin-tin moments
-open(50,file='MOMENTMT_TD.OUT',form='FORMATTED',position='APPEND')
-write(50,'(G18.10)') times(itimes)
-do is=1,nspecies
-  do ia=1,natoms(is)
-    ias=idxas(ia,is)
-    write(50,'(2I4,3G18.10)') is,ia,mommt(1:ndmag,ias)
-  end do
-end do
-write(50,*)
-close(50)
-! interstitial moment
-open(50,file='MOMENTIR_TD.OUT',form='FORMATTED',position='APPEND')
-write(50,'(4G18.10)') times(itimes),momir(1:ndmag)
-close(50)
+! write spin moments to file if required
+if (spinpol) call writemomtd
 ! total current
 open(50,file='JTOT_TD.OUT',form='FORMATTED',position='APPEND')
 write(50,'(4G18.10)') times(itimes),jtot(:)
@@ -102,44 +65,23 @@ close(50)
 open(50,file='JTOTM_TD.OUT',form='FORMATTED',position='APPEND')
 write(50,'(4G18.10)') times(itimes),jtotm
 close(50)
-! total energy
-open(50,file='TOTENERGY_TD.OUT',form='FORMATTED',position='APPEND')
-write(50,'(2G18.10)') times(itimes),engytot
-close(50)
-! total force
-if (tforce) then
-  open(50,file='FORCETOT_TD.OUT',form='FORMATTED',position='APPEND')
-  write(50,'(I8,G18.10)') itimes,times(itimes)
-  do is=1,nspecies
-    do ia=1,natoms(is)
-      ias=idxas(ia,is)
-      write(50,'(2I4,3G18.10)') is,ia,forcetot(:,ias)
-    end do
-  end do
-  close(50)
-end if
-! write the time-dependent atomic positions in lattice coordinates
-if (tdatpos) then
-  open(50,file='ATPOSL_TD.OUT',form='FORMATTED',position='APPEND')
-  write(50,'(I8,G18.10)') itimes,times(itimes)
-  do is=1,nspecies
-    do ia=1,natoms(is)
-      vc(:)=atposc(:,ia,is)+datposc(:,0,ia,is)
-      call r3mv(ainv,vc,vl)
-      write(50,'(2I4,3G18.10)') is,ia,vl(:)
-    end do
-  end do
+! write the time-dependent atomic forces
+if (tforce.and.ttsforce) then
+  call writetdforces
+  open(50,file='FORCES'//trim(fext),form='FORMATTED',action='WRITE')
+  call writeforces(50)
   close(50)
 end if
+! write the time-dependent atomic displacements
+if (tatdisp.and.ttsforce) call writeatdisp
+! write the time-dependent induced A-field
 if (tafindt) then
   open(50,file='AFIND_TD.OUT',form='FORMATTED',position='APPEND')
   write(50,'(4G18.10)') times(itimes),afindt(:,0)
   close(50)
 end if
 ! write optional quantities
-if (ntswrite(1).le.0) return
-if (mod(itimes-1,ntswrite(1)).ne.0) return
-if ((itimes.gt.1).and.(itimes.lt.ntswrite(2))) return
+if (.not.ttswrite) return
 ! charge density in 1D
 if (tdrho1d) then
   open(50,file='RHO1D'//trim(fext),form='FORMATTED',action='WRITE')
@@ -214,18 +156,8 @@ if (tdjr3d) then
   close(50)
 end if
 ! calculate and write tensor moments
-if (dftu.ne.0) then
-  if (tmwrite) call writetm3td
-end if
-! write time-dependent DOS
-if (tddos) then
-  call writetddos(fext)
-end if
-! write the atomic forces
-if (tforce) then
-  open(50,file='FORCES'//trim(fext),form='FORMATTED',action='WRITE')
-  call writeforces(50)
-  close(50)
+if (dftu /= 0) then
+  if (tmwrite) call writetdtm3
 end if
 end subroutine
 
