@@ -14,9 +14,6 @@ real(8) xl(3),xs(3)
 character(256) fext
 ! allocatable arrays
 complex(8), allocatable :: dmat(:,:,:,:,:)
-if (ntswrite(1).le.0) return
-if (mod(itimes-1,ntswrite(1)).ne.0) return
-if ((itimes.gt.1).and.(itimes.lt.ntswrite(2))) return
 allocate(dmat(lmmaxo,nspinor,lmmaxo,nspinor,natmtot))
 ! generate the density matrix in each muffin-tin
 call gendmat(.false.,.false.,0,lmaxo,lmmaxo,dmat)
