@@ -15,6 +15,9 @@ if (dftu == 0) then
 end if
 ! initialize universal variables
 call init0
+call init1
+! read the potential from file
+call readstate
 ! read density matrix from file DMATMT.OUT
 call readdmatmt
 ! generate the DFT+U muffin-tin potential matrices
