@@ -31,10 +31,9 @@ write(50,'("length_unit = bohr")')
 write(50,'("num_wann =  ",I8)') num_wann
 write(50,'("num_bands = ",I8)') num_bands
 write(50,'("num_iter = ",I8)') num_iter
+write(50,'("dis_num_iter = ",I8)') dis_num_iter
 write(50,*)
 write(50,'("trial_step = ",G18.10)') trial_step
-write(50,*)
-write(50,'("use_bloch_phases = true")')
 ! write spinors if required
 if (spinpol) then
   write(50,*)
