@@ -20,7 +20,7 @@ real(8) kf,s,u,v,rs,z,g
 real(8) ks,ksg,t,uu,vv,ww
 do i=1,n
   r=rho(i)
-  if (r.gt.1.d-12) then
+  if (r > 1.d-12) then
     grho_=grho(i)
     g2rho_=g2rho(i)
     g3rho_=g3rho(i)
