@@ -40,12 +40,6 @@ integer lm1,lm2,n
 real(8) t1
 ! automatic arrays
 real(8) dy(ld,ld)
-if (lmax < 0) then
-  write(*,*)
-  write(*,'("Error(ylmrot): lmax < 0 : ",I8)') lmax
-  write(*,*)
-  stop
-end if
 ! generate the rotation matrix about the y-axis
 call ylmroty(ang(2),lmax,ld,dy)
 ! apply inversion if required
