@@ -14,13 +14,13 @@ integer ig
 ! automatic arrays
 complex(8) zfftc(ngtc)
 ! Fourier transform function on coarse grid to G-space
-zfftc(:)=zfirc(:)
+zfftc(1:ngtc)=zfirc(1:ngtc)
 call zfftifc(3,ngdgc,-1,zfftc)
 ! Fourier transform to fine real-space grid
-zfir(:)=0.d0
 do ig=1,ngvc
   zfir(igfft(ig))=zfftc(igfc(ig))
 end do
+zfir(igfft(ngvc+1:ngtot))=0.d0
 call zfftifc(3,ngridg,1,zfir)
 end subroutine
 
