@@ -3,7 +3,7 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine zfmtftoc(nrc,nrci,zfmt,zfcmt)
+pure subroutine zfmtftoc(nrc,nrci,zfmt,zfcmt)
 use modmain
 implicit none
 ! arguments
@@ -11,22 +11,23 @@ integer, intent(in) :: nrc,nrci
 complex(8), intent(in) :: zfmt(*)
 complex(8), intent(out) :: zfcmt(*)
 ! local variables
-integer irc,i,j,n
+integer irc,i,j,m,n
 i=1
 j=1
-n=lmmaxi*lradstp
+m=lmmaxi*lradstp
+n=lmmaxi-1
 do irc=1,nrci
-  call zcopy(lmmaxi,zfmt(i),1,zfcmt(j),1)
-  i=i+n
-  j=j+lmmaxi
+  zfcmt(i:i+n)=zfmt(j:j+n)
+  i=i+lmmaxi
+  j=j+m
 end do
-i=i+(lradstp-1)*(lmmaxo-lmmaxi)
-n=lmmaxo*lradstp
+j=j+(lradstp-1)*(lmmaxo-lmmaxi)
+m=lmmaxo*lradstp
+n=lmmaxo-1
 do irc=nrci+1,nrc
-  call zcopy(lmmaxo,zfmt(i),1,zfcmt(j),1)
-  i=i+n
-  j=j+lmmaxo
+  zfcmt(i:i+n)=zfmt(j:j+n)
+  i=i+lmmaxo
+  j=j+m
 end do
-return
 end subroutine
 
