@@ -40,7 +40,7 @@ complex(8), intent(in) :: zfmt1(*),zfmt2(*)
 integer n,ir,i
 ! compute the dot-products for each radial point and integrate over r
 zfmtinp=0.d0
-if (lmaxi.eq.1) then
+if (lmaxi == 1) then
   do ir=1,nri
     i=4*(ir-1)+1
     zfmtinp=zfmtinp+wr(ir) &
