@@ -13,7 +13,7 @@ complex(8), intent(inout) :: zfmt(*)
 ! local variables
 integer n,ir,i
 i=1
-if (lmaxi.eq.1) then
+if (lmaxi == 1) then
   do ir=1,nri
     zfmt(i:i+3)=wr(ir)*zfmt(i:i+3)
     i=i+4
