@@ -21,6 +21,7 @@ allocate(zfmt1(lmmaxo,nrcmtmax,natmtot))
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(is) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
@@ -30,11 +31,12 @@ end do
 call freethd(nthd)
 ! Fourier transform rfir to G-space
 allocate(zfft(ngtot))
-zfft(:)=zfir(:)
+zfft(1:ngtot)=zfir(1:ngtot)
 call zfftifc(3,ngridg,-1,zfft)
 ! begin loop over all points
 call holdthd(np,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ip=1,np
   call zfip(ip)
@@ -70,13 +72,13 @@ do is=1,nspecies
   rmt2=rmt(is)**2
   do ia=1,natoms(is)
     ias=idxas(ia,is)
-    v2(:)=v1(:)-atposc(:,ia,is)
+    v2(1:3)=v1(1:3)-atposc(1:3,ia,is)
     do i1=-1,1
-      v3(:)=v2(:)+dble(i1)*avec(:,1)
+      v3(1:3)=v2(1:3)+dble(i1)*avec(1:3,1)
       do i2=-1,1
-        v4(:)=v3(:)+dble(i2)*avec(:,2)
+        v4(1:3)=v3(1:3)+dble(i2)*avec(1:3,2)
         do i3=-1,1
-          v5(:)=v4(:)+dble(i3)*avec(:,3)
+          v5(1:3)=v4(1:3)+dble(i3)*avec(1:3,3)
           t1=v5(1)**2+v5(2)**2+v5(3)**2
           if (t1 < rmt2) then
             r=sqrt(t1)
