@@ -38,8 +38,7 @@ use modmain
 implicit none
 ! arguments
 integer, intent(in) :: npv,ivp(3,npv)
-real(8), intent(in) :: vpc(3,npv)
-real(8), intent(in) :: rfmt(npmtmax,natmtot),rfir(ngtot)
+real(8), intent(in) :: vpc(3,npv),rfmt(npmtmax,natmtot),rfir(ngtot)
 complex(8), intent(out) :: zfp(npv)
 ! local variables
 integer is,ia,ias,ip,ig,ifg
@@ -54,12 +53,12 @@ complex(8) ylm(lmmaxo)
 complex(8), allocatable :: zfft(:),zfmt(:,:)
 allocate(zfft(ngtot),zfmt(npcmtmax,natmtot))
 ! zero the coefficients
-zfp(:)=0.d0
+zfp(1:npv)=0.d0
 !---------------------------!
 !     interstitial part     !
 !---------------------------!
 ! Fourier transform to G-space
-zfft(:)=rfir(:)
+zfft(1:ngtot)=rfir(1:ngtot)
 call zfftifc(3,ngridg,-1,zfft)
 ! find coefficients for all required input vectors
 do ip=1,npv
@@ -83,11 +82,11 @@ do ias=1,natmtot
   call rtozfmt(nrc,nrci,rfmt1,zfmt(:,ias))
 end do
 ! remove continuation of interstitial function into muffin-tin
-do ig=1,ngtot
+do ig=1,ngvec
   ifg=igfft(ig)
 ! conjugate spherical harmonics 4π iˡ Yₗₘ(G)*
   call genylmv(.true.,lmaxo,vgc(:,ig),ylm)
-  ylm(:)=conjg(ylm(:))
+  ylm(1:lmmaxo)=conjg(ylm(1:lmmaxo))
   do is=1,nspecies
     nrc=nrcmt(is)
     nrci=nrcmti(is)
@@ -163,7 +162,7 @@ do ip=1,npv
           z1=z1+jl(l,irc)*sum(zfmt(i:i+n,ias)*ylm(lm:lm+n))
           i=i+n+1
         end do
-        zsm=zsm+wrcmt(irc,is)*z1
+        zsm=zsm+wr2cmt(irc,is)*z1
       end do
       do irc=irco,nrc
         z1=jl(0,irc)*zfmt(i,ias)*ylm(1)
@@ -174,7 +173,7 @@ do ip=1,npv
           z1=z1+jl(l,irc)*sum(zfmt(i:i+n,ias)*ylm(lm:lm+n))
           i=i+n+1
         end do
-        zsm=zsm+wrcmt(irc,is)*z1
+        zsm=zsm+wr2cmt(irc,is)*z1
       end do
 ! conjugate structure factor
       t1=vpc(1,ip)*atposc(1,ia,is) &
