@@ -22,7 +22,7 @@ do i=1,n
   zsm=0.d0
   do j=1,n-1
     dw=w(j+1)-w(j)
-    zsm=zsm+dw*zf(j)/((w(j)-wi)**2+s2)
+    zsm=zsm+zf(j)*(dw/((w(j)-wi)**2+s2))
   end do
   zg(i)=zsm*s/pi
 end do
