@@ -6,20 +6,21 @@
 !BOP
 ! !ROUTINE: zpotcoul
 ! !INTERFACE:
-subroutine zpotcoul(nr,nri,np,ld1,rl,ngdg,igf,ngp,gpc,gclgp,ld2,jlgprmt,ylmgp, &
- sfacgp,zrhoir,ld3,zvclmt,zvclir)
+subroutine zpotcoul(iash,nrmt_,nrmti_,npmt_,ld1,rl,ngridg_,igfft_,ngp,gpc, &
+ gclgp,ld2,jlgprmt,ylmgp,sfacgp,zrhoir,ld3,zvclmt,zvclir)
 ! !USES:
 use modmain
-use modphonon
 ! !INPUT/OUTPUT PARAMETERS:
-!   nr      : number of radial points for each species (in,integer(nspecies))
-!   nri     : number of radial points on inner part (in,integer(nspecies))
-!   np      : total number of points in muffin-tins (in,integer(nspecies))
+!   iash    : if iash > 0 then the homogeous solution is stored for this
+!             muffin-tin in the array zvclmt(:,natmtot+1) (in,integer)
+!   nrmt_   : number of radial points for each species (in,integer(nspecies))
+!   nrmti_  : number of radial points on inner part (in,integer(nspecies))
+!   npmt_   : total number of points in muffin-tins (in,integer(nspecies))
 !   ld1     : leading dimension (in,integer)
 !   rl      : r^l on radial mesh for each species
 !             (in,real(ld1,-lmaxo-1:lmaxo+2,nspecies))
-!   ngdg    : G-vector grid sizes (in,integer(3))
-!   igf     : map from G-vector index to FFT array (in,integer(*))
+!   ngridg_ : G-vector grid sizes (in,integer(3))
+!   igfft_  : map from G-vector index to FFT array (in,integer(*))
 !   ngp     : number of G+p-vectors (in,integer)
 !   gpc     : G+p-vector lengths (in,real(ngp))
 !   gclgp   : Coulomb Green's function in G+p-space (in,real(ngp))
@@ -32,7 +33,7 @@ use modphonon
 !   ld3     : leading dimension (in,integer)
 !   zvclmt  : muffin-tin Coulomb potential, with the contribution from the
 !             isolated muffin-tin density precalculated and passed in
-!             (inout,complex(ld3,natmtot))
+!             (inout,complex(ld3,*))
 !   zvclir  : interstitial Coulomb potential (out,complex(*))
 ! !DESCRIPTION:
 !   Calculates the Coulomb potential of a complex charge density by solving
@@ -71,7 +72,7 @@ use modphonon
 !   which may be used for solving Poisson's equation directly
 !   $$ V^{\rm P}({\bf G})=\begin{cases}
 !     4\pi\frac{\rho^{\rm P}({\bf G})}{G^2} & G>0 \\
-!     0 & G=0 \end{cases}\;. $$
+!     0 & G=0 \end{cases} $$
 !   The usual Green's function approach is then employed to determine the
 !   potential in the muffin-tin sphere due to charge in the sphere. In other
 !   words
@@ -98,20 +99,21 @@ use modphonon
 !BOC
 implicit none
 ! arguments
-integer, intent(in) :: nr(nspecies),nri(nspecies),np(nspecies)
+integer, intent(in) :: iash,nrmt_(nspecies),nrmti_(nspecies),npmt_(nspecies)
 integer, intent(in) :: ld1
 real(8), intent(in) :: rl(ld1,-lmaxo-1:lmaxo+2,nspecies)
-integer, intent(in) :: ngdg(3),igf(*),ngp
+integer, intent(in) :: ngridg_(3),igfft_(*),ngp
 real(8), intent(in) :: gpc(ngp),gclgp(ngp)
 integer, intent(in) :: ld2
 real(8), intent(in) :: jlgprmt(0:lnpsd,ld2,nspecies)
 complex(8), intent(in) :: ylmgp(lmmaxo,ngp),sfacgp(ld2,natmtot)
 complex(8), intent(in) :: zrhoir(*)
 integer, intent(in) :: ld3
-complex(8), intent(inout) :: zvclmt(ld3,natmtot)
+complex(8), intent(inout) :: zvclmt(ld3,*)
 complex(8), intent(out) :: zvclir(*)
 ! local variables
-integer is,ia,ias,iro
+integer is,ia,ias
+integer nr,nri,iro,np
 integer l,lm,lma,lmb
 integer ig,jg,i,i0,i1
 real(8) t1,t2,t3
@@ -125,7 +127,7 @@ real(8), external :: factn2
 t1=1.d0/fourpi
 do ias=1,natmtot
   is=idxis(ias)
-  i=np(is)-lmmaxo
+  i=npmt_(is)-lmmaxo
   do l=0,lmaxo
     t2=t1*dble(2*l+1)*rmtl(l+1,is)
     lma=l**2+1; lmb=lma+2*l
@@ -133,17 +135,17 @@ do ias=1,natmtot
   end do
 end do
 ! Fourier transform density to G-space and store in zvclir
-call zcopy(ngdg(1)*ngdg(2)*ngdg(3),zrhoir,1,zvclir,1)
-call zfftifc(3,ngdg,-1,zvclir)
+call zcopy(ngridg_(1)*ngridg_(2)*ngridg_(3),zrhoir,1,zvclir,1)
+call zfftifc(3,ngridg_,-1,zvclir)
 ! subtract the multipole moments of the interstitial charge density
 do is=1,nspecies
   rl2(0:lmaxo)=rmtl(2:lmaxo+2,is)
   t1=rl2(0)*fourpi*y00
   do ia=1,natoms(is)
     ias=idxas(ia,is)
-    zlm(:)=0.d0
+    zlm(1:lmmaxo)=0.d0
     do ig=1,ngp
-      jg=igf(ig)
+      jg=igfft_(ig)
       if (gpc(ig) > epslat) then
         z1=zvclir(jg)*sfacgp(ig,ias)/gpc(ig)
         zlm(1)=zlm(1)+jlgprmt(1,ig,is)*t1*z1
@@ -157,7 +159,7 @@ do is=1,nspecies
         zlm(1)=zlm(1)+t2*zvclir(jg)
       end if
     end do
-    qlm(:,ias)=qlm(:,ias)-zlm(:)
+    qlm(1:lmmaxo,ias)=qlm(1:lmmaxo,ias)-zlm(1:lmmaxo)
   end do
 end do
 ! find the smooth pseudocharge within the muffin-tin whose multipoles are the
@@ -172,7 +174,7 @@ do ias=1,natmtot
   end do
 ! add the pseudocharge and real interstitial densities in G-space
   do ig=1,ngp
-    jg=igf(ig)
+    jg=igfft_(ig)
     if (gpc(ig) > epslat) then
       t2=gpc(ig)*rmt(is)
       t3=1.d0/t2**lnpsd
@@ -192,19 +194,22 @@ do ias=1,natmtot
 end do
 ! solve Poisson's equation in G+p-space for the pseudocharge
 do ig=1,ngp
-  jg=igf(ig)
+  jg=igfft_(ig)
   zvclir(jg)=gclgp(ig)*zvclir(jg)
 end do
 ! match potentials at muffin-tin boundary by adding homogeneous solution
 do ias=1,natmtot
   is=idxis(ias)
-  iro=nri(is)+1
+  nr=nrmt_(is)
+  nri=nrmti_(is)
+  iro=nri+1
+  np=npmt_(is)
 ! find the spherical harmonic expansion of the interstitial potential at the
 ! muffin-tin radius
-  zlm(:)=0.d0
+  zlm(1:lmmaxo)=0.d0
   do ig=1,ngp
-    z1=zvclir(igf(ig))*sfacgp(ig,ias)
-    zlm(1)=zlm(1)+jlgprmt(0,ig,is)*fourpi*y00*z1
+    z1=zvclir(igfft_(ig))*sfacgp(ig,ias)
+    zlm(1)=zlm(1)+(jlgprmt(0,ig,is)*fourpi*y00)*z1
     do l=1,lmaxo
       lma=l**2+1; lmb=lma+2*l
       z2=jlgprmt(l,ig,is)*z1
@@ -212,36 +217,35 @@ do ias=1,natmtot
     end do
   end do
 ! calculate the homogenous solution
-  i=np(is)-lmmaxo
+  i=np-lmmaxo
   do l=0,lmaxi
     t1=1.d0/rmtl(l,is)
     do lm=l**2+1,(l+1)**2
       z1=t1*(zlm(lm)-zvclmt(i+lm,ias))
-      i1=lmmaxi*(nri(is)-1)+lm
-      zhmt(lm:i1:lmmaxi)=z1*rl(1:nri(is),l,is)
+      i1=lmmaxi*(nri-1)+lm
+      zhmt(lm:i1:lmmaxi)=z1*rl(1:nri,l,is)
       i0=i1+lmmaxi
-      i1=lmmaxo*(nr(is)-iro)+i0
-      zhmt(i0:i1:lmmaxo)=z1*rl(iro:nr(is),l,is)
+      i1=lmmaxo*(nr-iro)+i0
+      zhmt(i0:i1:lmmaxo)=z1*rl(iro:nr,l,is)
     end do
   end do
   do l=lmaxi+1,lmaxo
     t1=1.d0/rmtl(l,is)
     do lm=l**2+1,(l+1)**2
       z1=t1*(zlm(lm)-zvclmt(i+lm,ias))
-      i0=lmmaxi*nri(is)+lm
-      i1=lmmaxo*(nr(is)-iro)+i0
-      zhmt(i0:i1:lmmaxo)=z1*rl(iro:nr(is),l,is)
+      i0=lmmaxi*nri+lm
+      i1=lmmaxo*(nr-iro)+i0
+      zhmt(i0:i1:lmmaxo)=z1*rl(iro:nr,l,is)
     end do
   end do
-  zvclmt(1:np(is),ias)=zvclmt(1:np(is),ias)+zhmt(1:np(is))
-! store the nuclear potential without the self-term for the phonon dynamical
-! matrix calculation
-  if (tphdyn) then
-    if (ias == iasph) zvnmt(1:np(is))=zhmt(1:np(is))
+  zvclmt(1:np,ias)=zvclmt(1:np,ias)+zhmt(1:np)
+! store the homogenous solution if required
+  if (iash > 0) then
+    if (ias == iash) zvclmt(1:np,natmtot+1)=zhmt(1:np)
   end if
 end do
 ! Fourier transform interstitial potential to real-space
-call zfftifc(3,ngdg,1,zvclir)
+call zfftifc(3,ngridg_,1,zvclir)
 end subroutine
 !EOC
 
