@@ -33,9 +33,11 @@ pure subroutine ztorflmn(lmax,n,ld,zflm,rflm)
 ! !DESCRIPTION:
 !   Converts a real function, $z_{lm}$, expanded in terms of complex spherical
 !   harmonics into a real spherical harmonic expansion, $r_{lm}$:
-!   $$ r_{lm}=\begin{cases}\frac{1}{\sqrt{2}}\Re(z_{lm}+(-1)^m z_{l-m}) & m>0 \\
-!    \frac{1}{\sqrt{2}}\Im(-z_{lm}+(-1)^m z_{l-m}) & m<0 \\
-!    \Re(z_{lm}) & m=0 \end{cases}\;. $$
+!   $$ r_{lm}=\begin{cases}
+!    \frac{1}{\sqrt{2}}{\rm Re}(z_{lm}+(-1)^m z_{l-m}) & m>0 \\
+!    \frac{1}{\sqrt{2}}{\rm Im}(-z_{lm}+(-1)^m z_{l-m}) & m<0 \\
+!    {\rm Re}(z_{lm}) & m=0
+!   \end{cases} $$
 !   See routine {\tt genrlm}.
 !
 ! !REVISION HISTORY:
@@ -58,21 +60,21 @@ do l=0,lmax
     lm1=lm1+1
     lm2=lm2-1
     if (mod(m,2) /= 0) then
-      rflm(lm1,:)=-c1*(aimag(zflm(lm1,:))+aimag(zflm(lm2,:)))
+      rflm(lm1,1:n)=-c1*(aimag(zflm(lm1,1:n))+aimag(zflm(lm2,1:n)))
     else
-      rflm(lm1,:)=c1*(aimag(zflm(lm2,:))-aimag(zflm(lm1,:)))
+      rflm(lm1,1:n)=c1*(aimag(zflm(lm2,1:n))-aimag(zflm(lm1,1:n)))
     end if
   end do
   lm1=lm1+1
   lm2=lm2-1
-  rflm(lm1,:)=dble(zflm(lm1,:))
+  rflm(lm1,1:n)=dble(zflm(lm1,1:n))
   do m=1,l
     lm1=lm1+1
     lm2=lm2-1
     if (mod(m,2) /= 0) then
-      rflm(lm1,:)=c1*(dble(zflm(lm1,:))-dble(zflm(lm2,:)))
+      rflm(lm1,1:n)=c1*(dble(zflm(lm1,1:n))-dble(zflm(lm2,1:n)))
     else
-      rflm(lm1,:)=c1*(dble(zflm(lm1,:))+dble(zflm(lm2,:)))
+      rflm(lm1,1:n)=c1*(dble(zflm(lm1,1:n))+dble(zflm(lm2,1:n)))
     end if
   end do
 end do
